@@ -75,7 +75,6 @@ $wgResourceModules += array(
 			'vector-collapsiblenav-more',
 		),
 		'dependencies' => array(
-			'mediawiki.util',
 			'jquery.client',
 			'jquery.cookie',
 			'jquery.tabIndex',
@@ -106,13 +105,6 @@ $wgResourceModules += array(
 	'ext.vector.footerCleanup' => $vectorResourceTemplate + array(
 		'scripts' => 'ext.vector.footerCleanup.js',
 		'styles' => 'ext.vector.footerCleanup.css',
-		'messages' => array (
-			'vector-footercleanup-transclusion',
-		),
-		'dependencies' => array(
-			// The message require plural support at javascript.
-			'mediawiki.jqueryMsg',
-		)
 	),
 	'ext.vector.sectionEditLinks' => $vectorResourceTemplate + array(
 		'scripts' => 'ext.vector.sectionEditLinks.js',
@@ -129,11 +121,10 @@ $wgResourceModules += array(
 			'vector-simplesearch-containing',
 		),
 		'dependencies' => array(
-			'jquery.autoEllipsis',
 			'jquery.client',
-			'jquery.placeholder',
 			'jquery.suggestions',
-			'mediawiki.legacy.mwsuggest', // to ensure we disable it in proper order
+			'jquery.autoEllipsis',
+			'jquery.placeholder',
 		),
 	),
 );
