@@ -206,7 +206,7 @@ $messages = array(
 
 'underline-always'  => 'Sabe',
 'underline-never'   => "H'an tom",
-'underline-default' => 'Penjelajah web bawaan',
+'underline-default' => 'Kulet atawa ngon peuhah web teupasang',
 
 # Font style option in Special:Preferences
 'editfont-style'     => 'Gaya seunurat komputer bak plok andam',
@@ -291,7 +291,7 @@ $messages = array(
 'newwindow'     => '(peuhah bak tingkap barô)',
 'cancel'        => 'Peubateuë',
 'moredotdotdot' => 'Lom...',
-'mypage'        => 'Ôn lôn',
+'mypage'        => 'Ôn',
 'mytalk'        => 'Marit',
 'anontalk'      => 'Peugah haba IP nyoë.',
 'navigation'    => 'Navigasi',
@@ -315,7 +315,7 @@ $messages = array(
 'vector-action-protect'          => 'Peulindông',
 'vector-action-undelete'         => 'Bateuë sampôh',
 'vector-action-unprotect'        => 'Gantoe neulindông',
-'vector-simplesearch-preference' => 'Peuudep mita saran nyang geupeusamporeuna (keu kulet Vector khong)',
+'vector-simplesearch-preference' => 'Peuudep beunteueng mita biasa (kulet Vector khong)',
 'vector-view-create'             => 'Peugöt',
 'vector-view-edit'               => 'Andam',
 'vector-view-history'            => 'Atra u likôt',
@@ -337,7 +337,7 @@ $messages = array(
 'history_short'     => 'Atra u likôt',
 'updatedmarker'     => 'geuubah yoh seunaweue keuneulheueh lon phon kon',
 'printableversion'  => 'Seunalén citak',
-'permalink'         => 'Hubông teutap',
+'permalink'         => 'Neuhubông teutap',
 'print'             => 'Rakam',
 'view'              => 'Beuet',
 'edit'              => 'Andam',
@@ -355,13 +355,13 @@ $messages = array(
 'unprotectthispage' => 'Gantoe neulindông ôn nyoë',
 'newpage'           => 'Ôn barô',
 'talkpage'          => 'Peugah haba bhah ôn nyoë',
-'talkpagelinktext'  => 'Peugah haba',
+'talkpagelinktext'  => 'Marit',
 'specialpage'       => 'Ôn kusuih',
 'personaltools'     => 'Alat droë',
 'postcomment'       => 'Beunagi baro',
 'articlepage'       => 'Eu ôn asoë',
 'talk'              => 'Peugah haba',
-'views'             => 'Leumah',
+'views'             => 'Ôn',
 'toolbox'           => 'Plôk alat',
 'userpage'          => 'Eu on ureueng nguy',
 'projectpage'       => 'Eu ôn buët',
@@ -377,9 +377,14 @@ $messages = array(
 'lastmodifiedat'    => 'Ôn nyoë keuneulheuëh geu’ubah bak $2, $1.',
 'viewcount'         => 'On nyoe ka geusaweue {{PLURAL:$1|sigo|$sigo}}.<br />',
 'protectedpage'     => 'Ôn teupeulindông',
-'jumpto'            => 'Langsông u:',
+'jumpto'            => 'Lansông u:',
 'jumptonavigation'  => 'navigasi',
 'jumptosearch'      => 'mita',
+'view-pool-error'   => "Meu'ah, server teungoh sibuk jinoe
+Le that ureueng nyang meuh'eut jak eu on nyoe
+Neupreh si'at yoh goh neubaci lom
+
+$1",
 'pool-timeout'      => 'Liwat watee preh gunci',
 'pool-queuefull'    => 'Seunapat neupreh peunoh',
 'pool-errorunknown' => 'Salah hana meukon',
@@ -406,27 +411,41 @@ $messages = array(
 
 'badaccess'        => 'Salah khut/hak tamöng',
 'badaccess-group0' => 'Droeneuh hana geupeuidin keu neupeulaku buet nyang neulakee',
+'badaccess-groups' => 'Buet nyang neulakee geupeubatah keu ureueng nguy lam {{PLURAL:$2|kawan|salah saboh nibak kawan}}: $1.',
 
-'versionrequired' => 'Peureulee MediaWiki versi $1',
+'versionrequired'     => 'Peureulee MediaWiki versi $1',
+'versionrequiredtext' => "MediaWiki versi $1 geupeureulee keu neunguy on nyoe. Neu'eu [[Special:Version|on versi]]",
 
-'retrievedfrom'       => 'Meurumpok nibak "$1"',
-'youhavenewmessages'  => 'Droëneuh   na $1 ($2).',
-'newmessageslink'     => 'peusan barô',
-'newmessagesdifflink' => 'neuubah keuneulheuëh',
-'editsection'         => 'andam',
-'editold'             => 'andam',
-'viewsourceold'       => 'Eu nè',
-'editlink'            => 'andam',
-'viewsourcelink'      => 'eu nè',
-'editsectionhint'     => 'Andam bideuëng: $1',
-'toc'                 => 'Asoë',
-'showtoc'             => 'peuleumah',
-'hidetoc'             => 'peusom',
-'site-rss-feed'       => 'Umpeuën RSS $1',
-'site-atom-feed'      => 'Umpeuën Atôm $1',
-'page-rss-feed'       => 'Umpeuën RSS "$1"',
-'page-atom-feed'      => 'Umpeuën Atom "$1"',
-'red-link-title'      => '$1 (ôn goh na)',
+'ok'                      => 'Ka göt',
+'retrievedfrom'           => 'Geurumpok nibak "$1"',
+'youhavenewmessages'      => 'Droëneuh   na $1 ($2).',
+'newmessageslink'         => 'peusan barô',
+'newmessagesdifflink'     => 'neuubah keuneulheuëh',
+'youhavenewmessagesmulti' => 'Droëneuh na padum boh peusan barô bak $1',
+'editsection'             => 'andam',
+'editold'                 => 'andam',
+'viewsourceold'           => 'Eu nè',
+'editlink'                => 'andam',
+'viewsourcelink'          => 'eu nè',
+'editsectionhint'         => 'Andam bideuëng: $1',
+'toc'                     => 'Asoë',
+'showtoc'                 => 'peuleumah',
+'hidetoc'                 => 'peusom',
+'collapsible-collapse'    => 'Peuubeut',
+'collapsible-expand'      => 'Peuluwaih',
+'thisisdeleted'           => 'Eu atawa peuriwang $1?',
+'viewdeleted'             => 'Eu $1?',
+'restorelink'             => '$1 {{PLURAL:$1|neuandam|neuandam}} nyang ka geusampoh',
+'feedlinks'               => 'Umpeuen:',
+'feed-invalid'            => 'Jeuneh neulakee umpeuen hana paih',
+'feed-unavailable'        => 'Umpeuen sindikasi hana',
+'site-rss-feed'           => 'Umpeuën RSS $1',
+'site-atom-feed'          => 'Umpeuën Atôm $1',
+'page-rss-feed'           => 'Umpeuën RSS "$1"',
+'page-atom-feed'          => 'Umpeuën Atom "$1"',
+'red-link-title'          => '$1 (ôn goh na)',
+'sort-descending'         => 'Peuurot tren',
+'sort-ascending'          => 'Peuurot ek',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'Ôn',
@@ -440,19 +459,72 @@ $messages = array(
 'nstab-help'      => 'Beunantu',
 'nstab-category'  => 'Kawan',
 
+# Main script and global functions
+'nosuchaction'      => 'Hana buet nyan',
+'nosuchactiontext'  => 'Buet nyang geulakee le URL nyan hana sah. Droeneuh kadang salah neukeutik URL, atawa neuseutot saboh neuhubong nyang hana beutoy. Hay nyoe kadang jeuet keu lageuem saboh bug bak alat leumiek nyang geunguy le {{SITENAME}}.',
+'nosuchspecialpage' => 'Hana on kusuih lagee nyan',
+'nospecialpagetext' => "<strong>Droeneuh ka neulakee on kusuih nyang hana sah.</strong>
+Dapeuta on kusuih nyang sah jeuet neu'eu bak [[Special:SpecialPages|{{int:specialpages}}]].",
+
 # General errors
-'error'              => 'Seunalah',
-'databaseerror'      => 'Kesalahan basis data',
-'missing-article'    => 'Basis data h’an jeuët jiteumèë naseukah nibak ôn nyang sipatôtjih na, nakeuh "$1" $2.
+'error'                => 'Seunalah',
+'databaseerror'        => 'Kesalahan basis data',
+'dberrortext'          => 'Na salah bak syntax neulakee basis data.
+Nyoe kadang tanda na saboh bug lam alat leumiek.
+Neulakee basis data keuneulheueh nakeuh:
+<blockquote><code>$1</code></blockquote>
+nibak function "<code>$2</code>".
+Basis data na salah "<samp>$3: $4</samp>".',
+'dberrortextcl'        => 'Na salah sintaks bak neulakee basis data.
+Neulakee basis data nyang keuneulheueh nakeuh:
+"$1"
+nibak fungsi "$2"
+Basis data geupeuhase salah "$3: $4".',
+'laggedslavemode'      => 'Peuneugah: On nyoe kadang hana neuubah baro',
+'readonly'             => 'Basis data geurok',
+'enterlockreason'      => 'Pasoe daleh neurok ngon pajan jeuet geupeuhah',
+'readonlytext'         => "Basis data hat nyoe geurok keu teunamong baro ngon geunantoe la'en, kadang keu peulara basis data rutin, lheueh nyan baro lagee biasa teuma.
+
+Ureueng uroh nyang rok nyoe geupeutaba jeuneulaih nyoe: $1",
+'missing-article'      => 'Basis data h’an jeuët jiteumèë naseukah nibak ôn nyang sipatôtjih na, nakeuh "$1" $2.
 
 Nyoë biasajih sabab hubông useuëng u geunantoë away nyang ka teusampôh.
 
 Meunyo kön nyoë sababjih, Droëneuh kadang ka neuteumèë saboh bug lam software. Neutulông peugah bhah nyoë bak salah sidroë [[Special:ListUsers/sysop|Nyang urôh]], ngön neupeugah alamat URL nyang neusaweuë.',
-'missingarticle-rev' => '(revisi#: $1)',
-'badtitle'           => 'Nan hana sah',
-'badtitletext'       => 'Nan ôn nyang neulakèë hana sah, soh, atawa nan antarabahsa atawa antarawiki nyang salah sambông.',
-'viewsource'         => 'Eu nè',
-'viewsourcetext'     => 'Droëneuh  jeuët neu’eu',
+'missingarticle-rev'   => '(revisi#: $1)',
+'missingarticle-diff'  => '(Bida: $1, $2)',
+'readonly_lag'         => 'Basis data ka geurok otomatis silawet basis data sekunder teungoh geupeusinkron ngon basis data utama',
+'internalerror'        => 'Salah bak dalam',
+'internalerror_info'   => 'Salah bak dalam: $1',
+'fileappenderrorread'  => 'H\'an jitem beuet "$1" \'oh geutamah',
+'fileappenderror'      => 'H\'an jeuet jipasoe "$1" u "$2"',
+'filecopyerror'        => 'H\'an jeuet salen beureukaih "$1" u "$2".',
+'filerenameerror'      => 'H\'an jeuet boh nan beureukaih "$1" u "$2".',
+'filedeleteerror'      => 'H\'an jeuet sampoh beureukaih "$1".',
+'directorycreateerror' => 'H\'an jeuet peugot direktori "$1".',
+'filenotfound'         => 'Beureukaih "$1" hana meurumpok.',
+'fileexistserror'      => 'H\'an jeuet geusalen u beureukaih "$1": Beureukaih ka na.',
+'unexpected'           => 'Yum hana geuharap: "$1"="$2".',
+'formerror'            => "Reuloh: H'an jeuet peu'et formulir.",
+'badarticleerror'      => "Buet nyoe h'an jeuet geupeulaku bak on nyoe.",
+'cannotdelete'         => 'On atawa beureukaih "$1" h\'an jeuet geusampoh.
+Kadang ka na soe sampoh.',
+'cannotdelete-title'   => 'H\'an jeuet sampoh on "$1"',
+'badtitle'             => 'Nan hana sah',
+'badtitletext'         => 'Nan ôn nyang neulakèë hana sah, soh, atawa nan antarabahsa atawa antarawiki nyang salah sambông.',
+'perfcached'           => 'Data di yup nyoe geucok nibak peuniyoh ngon kadang kon data baro. {{PLURAL:$1||}}$1 hase maksimum na bak beuen.',
+'perfcachedts'         => 'Data di yup nyoe geupeusom, ngon geupeubaro keuneulheueh bak $1. {{PLURAL:$1||}}$1 hase maksimal na lam beuen.',
+'querypage-no-updates' => "Beunaro keu on nyoe hat nyoe teungoh h'an jeuet.
+Data sinoe h'an geupasoe ulang.",
+'wrong_wfQuery_params' => 'Parameter salah u wfQuery()<br />
+Meunafaat: $1<br />
+Neulakee: $2',
+'viewsource'           => 'Eu nè',
+'viewsource-title'     => 'Eu ne keu $1',
+'actionthrottled'      => 'Buet geupeubataih',
+'actionthrottledtext'  => 'Sibagoe saboh seunipat lawan-spam, droeneuh geupeubataih nibak neupeulaku buet nyoe le that go lam watee paneuk, ngon droeneuh ka leubeh nibak bataih.
+Neuci lom lam padum minet.',
+'viewsourcetext'       => 'Droëneuh  jeuët neu’eu',
 
 # Login and logout pages
 'welcomecreation'         => '== Seulamat trok teuka, $1! ==
@@ -489,9 +561,9 @@ Préksa keulayi neu’ija Droëneuh.',
 'passwordtooshort'        => "Lageuëm paléng h'an haroh na {{PLURAL:$1|1 karakter|$1 karakter}}.",
 'mailmypassword'          => "Peu'ét lageuëm barô",
 'passwordremindertitle'   => 'Lageuëm seumeuntara barô keu {{SITENAME}}',
-'passwordremindertext'    => 'Salah sidroë (kadang Droëneuh, ngön alamat IP $1) geulakèë kamoë keu meukirém lageuëm rahsia nyang barô keu {{SITENAME}} ($4).
-Lageuëm rahsia keu ureuëng nguy "$2" jinoë nakeuh "$3".
-Droëneuh geupeusaran keu neutamong sigra, lheuëh nyan neugantoë lageuëm rahsia.',
+'passwordremindertext'    => 'Salah sidroë (kadang Droëneuh, ngön alamat IP $1) geulakèë lageuëm barô keu {{SITENAME}} ($4). Lageuëm si\'at keu ureuëng nguy "$2" ka geupeuna ngon ka geuato jeuet keu "$3". Meunyo nyoe nakeuh meukeusud droeneuh, droeneuh peureulee neutamong ngon neupileh lageuem baro jinoe. Lageuem siat droeneuh meung abeh lam {{PLURAL:$5|siuroe|$5 uroe}}.
+
+Meunyo ureueng la\'en nyang peugot neulakee nyoe, atawa meunyo droeneuh ka neuingat lageuem droeneuh, ngon droeneuh h\'an ek neugantoe le, droeneuh jeuet hana neupeureumeuen peusan nyoe ngon neulanjut neunguy lageuem awayneuh.',
 'noemail'                 => 'Hana alamat surat-e nyang teucatat keu ureuëng nguy "$1".',
 'passwordsent'            => 'Lageuëm barô ka geupeu\'ét u surat-e nyang geupeudapeuta keu "$1". Neutamong teuma lheuëh neuteurimong surat-e nyan.',
 'eauthentsent'            => 'Saboh surat èlèktronik keu peunyoë ka geukirém u alamat surat èlèktronik Droëneuh. Droëneuh beuneuseutöt préntah lam surat nyan keu neupeunyoë meunyo alamat nyan nakeuh beutôy atra Droëneuh. {{SITENAME}} h‘an geupeuudép surat Droëneuh meunyo langkah nyoë hana neupeulaku lom.',
@@ -644,7 +716,7 @@ Alasan-alasan nyan hana geupeureumeuen.",
 'searchprofile-images-tooltip'     => 'Mita beureukaih',
 'searchprofile-everything-tooltip' => 'Mita ban dum ôn asoë (rôh ôn marit)',
 'searchprofile-advanced-tooltip'   => 'Mita bak ruweueng nan meupat-pat',
-'search-result-size'               => '$1 ({{PLURAL:$2|1 kata|$2 kata}})',
+'search-result-size'               => '$1 ({{PLURAL:$2|1 narit|$2 narit}})',
 'search-result-category-size'      => '{{PLURAL:$1|1 anggeeta|$1 anggeeta}} ({{PLURAL:$2|1 aneuk kawan|$2 aneuk kawan}}, {{PLURAL:$3|1 beureukaih|$3 beureukaih}})',
 'search-redirect'                  => '(peuninah $1)',
 'search-section'                   => '(bagian $1)',
@@ -731,7 +803,7 @@ Surat-e droeneuh h'an geupeugah keu ureueng nyan.",
 'recentchangeslinked-to'       => 'Peuleumah neu’ubah nibak ôn-ôn nyang meusambông ngön ôn nyang geubri',
 
 # Upload
-'upload'        => 'Peutamong',
+'upload'        => 'Peutamong beureukaih',
 'uploadbtn'     => 'Peutamong beureukah',
 'uploadlogpage' => 'Log peutamöng',
 'filedesc'      => 'Ehtisa',
@@ -862,11 +934,11 @@ Teuneurang bak [$2 on teuneurangjih] geupeuleumah di yup nyoe.",
 # Special:ListGroupRights
 'listgrouprights-members' => '(dapeuta anggèëta)',
 
-# E-mail user
+# Email user
 'emailuser' => 'Surat-e ureuëng nguy',
 
 # Watchlist
-'watchlist'         => 'Dapeuta keunalön lôn',
+'watchlist'         => 'Dapeuta keunalön',
 'mywatchlist'       => 'Keunalön',
 'watchlistfor2'     => 'Keu $1 $2',
 'addedwatchtext'    => "Ôn \"[[:\$1]]\" ka geupeutamah u [[Special:Watchlist|dapeuta keunalön]] Droëneuh. Neu’ubah-neu’ubah bak masa u keuë bak ôn nyan ngön bak ôn peugah habajih, euntreuk leumah nyoë pat. Ôn nyan euntreuk geupeuleumah ''teubay'' bak [[Special:RecentChanges|dapeuta neu’ubah paléng barô]] mangat leubèh mudah leumah.",
@@ -929,9 +1001,10 @@ Droëneuh jeuët neugantoë tingkat lindông keu ôn nyoë, tapi nyan hana peung
 'undelete-search-submit' => 'Mita',
 
 # Namespace form on various pages
-'namespace'      => 'Ruweuëng nan:',
-'invert'         => 'Peubalék peuniléh',
-'blanknamespace' => '(Utama)',
+'namespace'             => 'Ruweuëng nan:',
+'invert'                => 'Peubalék peuniléh',
+'namespace_association' => 'Ruweuëng nan meuhubông',
+'blanknamespace'        => '(Keuë)',
 
 # Contributions
 'contributions'       => 'Peuneugöt',
@@ -954,7 +1027,7 @@ Droëneuh jeuët neugantoë tingkat lindông keu ôn nyoë, tapi nyan hana peung
 'sp-contributions-submit'      => 'Mita',
 
 # What links here
-'whatlinkshere'            => 'Hubông balék',
+'whatlinkshere'            => 'Neuhubông balék',
 'whatlinkshere-title'      => 'Ôn nyang na hubông u $1',
 'whatlinkshere-page'       => 'Ôn:',
 'linkshere'                => "Ôn-ôn nyoë meuhubông u '''[[:$1]]''':",
@@ -968,7 +1041,7 @@ Droëneuh jeuët neugantoë tingkat lindông keu ôn nyoë, tapi nyan hana peung
 'whatlinkshere-hideredirs' => '$1 peuninah',
 'whatlinkshere-hidetrans'  => '$1 transklusi',
 'whatlinkshere-hidelinks'  => '$1 hubông',
-'whatlinkshere-hideimages' => '$1 hubong gamba',
+'whatlinkshere-hideimages' => '$1 hubông beureukaih',
 'whatlinkshere-filters'    => 'Saréng',
 
 # Block/unblock
@@ -1032,10 +1105,10 @@ Lam masalah nyoë, meunyo neuhawa, Droëneuh jeuët neupeupinah atawa neupeugab
 'tooltip-pt-preferences'          => 'Atô',
 'tooltip-pt-watchlist'            => 'Dapeuta ôn nyang lôn kalön',
 'tooltip-pt-mycontris'            => 'Dapeuta peuneugöt Droëneuh',
-'tooltip-pt-login'                => 'Droën geupeusaran keu tamong log, bahpih nyan hana geupeuwajéb.',
+'tooltip-pt-login'                => 'Droëneuh geupadan keu tamong log, bah pih nyan hana geupeuwajéb.',
 'tooltip-pt-logout'               => 'Teubiët',
 'tooltip-ca-talk'                 => 'Peugah haba ôn asoë',
-'tooltip-ca-edit'                 => 'Andam ôn nyoë. Nguy tumbôy euë dilèë yôh goh lom keumeubah.',
+'tooltip-ca-edit'                 => 'Droëneuh jeuët neuandam ôn nyoë. Neunguy tumbôy eu dilèë yôh goh neukeubah.',
 'tooltip-ca-addsection'           => 'Puphôn beunagi barô',
 'tooltip-ca-viewsource'           => 'Ôn nyoë geupeulindông.
 Droëneuh cit jeuët neu’eu nèjih.',
@@ -1045,24 +1118,24 @@ Droëneuh cit jeuët neu’eu nèjih.',
 'tooltip-ca-move'                 => 'Peupinah ôn nyoë',
 'tooltip-ca-watch'                => 'Peutamah ôn nyoë u dapeuta kalön Droëneuh',
 'tooltip-ca-unwatch'              => 'Sampôh ôn nyoë nibak dapeuta keunalön Droëneuh',
-'tooltip-search'                  => 'Mita lam {{SITENAME}} nyoë',
+'tooltip-search'                  => 'Mita {{SITENAME}}',
 'tooltip-search-go'               => 'Mita saboh ôn ngon nan nyang peureuséh lagèë nyoë meunyo na',
 'tooltip-search-fulltext'         => 'Mita ôn nyang na asoë lagèë nyoë',
 'tooltip-p-logo'                  => 'Saweuë Ôn Keuë',
 'tooltip-n-mainpage'              => 'Jak u Ôn Keuë',
 'tooltip-n-mainpage-description'  => 'Saweuë Ôn Keuë',
-'tooltip-n-portal'                => 'Bhah buët, peuë nyang jeuët neupeulaku, pat tamita sipeuë hay',
-'tooltip-n-currentevents'         => 'Mita beurita nyang paléng barô',
+'tooltip-n-portal'                => 'Bhaih buët, peuë nyang jeuët neupeulaku, pat tamita sipeuë hay',
+'tooltip-n-currentevents'         => 'Mita haba barô',
 'tooltip-n-recentchanges'         => 'Dapeuta nyang ban meu’ubah lam wiki.',
 'tooltip-n-randompage'            => 'Peuleumah beurangkari ôn',
 'tooltip-n-help'                  => 'Bak mita bantu.',
-'tooltip-t-whatlinkshere'         => 'Dapeuta mandum ôn wiki nyang na hubông u ôn nyoë',
+'tooltip-t-whatlinkshere'         => 'Dapeuta ban dum ôn wiki nyang na neuhubông u ôn nyoë',
 'tooltip-t-recentchangeslinked'   => 'Neuubah barô ôn-ôn nyang na hubông u ôn nyoë',
 'tooltip-feed-rss'                => 'Umpeuën RSS keu ôn nyoë',
 'tooltip-feed-atom'               => 'Umpeuën Atom keu ôn nyoë',
 'tooltip-t-contributions'         => 'Eu dapeuta nyang ka geutuléh lé ureuëng nguy nyoë',
 'tooltip-t-emailuser'             => 'Kirém surat-e u ureuëng nguy nyoë',
-'tooltip-t-upload'                => 'Peutamong gamba atawa beureukah alat',
+'tooltip-t-upload'                => 'Peutamong beureukaih',
 'tooltip-t-specialpages'          => 'Dapeuta ban dum ôn kusuih',
 'tooltip-t-print'                 => 'Seunalén citak ôn nyoë',
 'tooltip-t-permalink'             => '
