@@ -113,13 +113,14 @@ $messages = array(
 'dec'           => 'दिस',
 
 # Categories related messages
-'pagecategories' => '{{PLURAL:$1|श्रेणी|श्रेणी}}',
+'pagecategories'    => '{{PLURAL:$1|श्रेणी|श्रेणी}}',
+'hidden-categories' => '{{PLURAL:$1|छुपावल गईल श्रेणी|छुपावल गईल श्रेणी}}',
 
 'about'      => 'बारे में',
 'article'    => 'सामग्री पन्ना',
 'newwindow'  => '(नया विंडो में खोलीं)',
 'cancel'     => 'निरस्त',
-'mytalk'     => 'हमार बात',
+'mytalk'     => 'राउर बात',
 'navigation' => 'परिभ्रमण',
 
 # Cologne Blue skin
@@ -144,6 +145,9 @@ $messages = array(
 'vector-view-history'     => 'इतिहास देखीं',
 'vector-view-view'        => 'पढ़ीं',
 'vector-view-viewsource'  => 'स्त्रोत देखीं',
+'actions'                 => 'क्रिया',
+'namespaces'              => 'नामस्थान',
+'variants'                => 'संस्करण',
 
 'errorpagetitle'    => 'त्रुटी',
 'returnto'          => 'जाईं $1 पर।',
@@ -213,6 +217,7 @@ $1',
 'disclaimerpage'       => 'Project:सामान्य अस्विकरण',
 'edithelp'             => 'मदद सम्पादन',
 'edithelppage'         => 'Help:सम्पादन',
+'helppage'             => 'Help:सामग्री',
 'mainpage'             => 'मुख्य पन्ना',
 'mainpage-description' => 'पहिलका पन्ना',
 'portal'               => 'सामुदायिक पन्ना',
@@ -280,6 +285,7 @@ $1',
 'yourname'                => 'प्रयोगकर्ता नाम',
 'yourpassword'            => 'गुप्त शब्द',
 'yourpasswordagain'       => 'गुप्त-शब्द पुन:डालीं:',
+'remembermypassword'      => 'इ ब्राउजर पर हमार प्रवेश जारी रहे (अधिकतम $1 {{PLURAL:$1|दिन|दिन}})',
 'login'                   => 'खाता में प्रवेश',
 'nav-login-createaccount' => 'खाता प्रवेश / खाता बनाईं',
 'loginprompt'             => '{{SITENAME}} में प्रवेश खातिर राउर कुकिज चालू होवे के चाहीं',
@@ -334,6 +340,7 @@ $1',
 'italic_sample'   => 'इटालिक पाठ्य',
 'italic_tip'      => 'इटालिक पाठ्य',
 'headline_sample' => 'शिर्षक पाठ्य',
+'headline_tip'    => 'द्वितीय-श्रेणी के शीर्षक',
 'image_sample'    => 'उदाहरण.jpg',
 'media_sample'    => 'उदाहरण.ogg',
 'media_tip'       => 'फाईल लिंक',
@@ -366,9 +373,14 @@ $1',
 'newarticletext'       => "रउआ एगो अइसन लिंक के पन्ना के अनुसरण कइले बानी जउन अभी तक उपलब्ध नइखे।
 पन्ना बनावे खातिर, नीचे के बाकस में टाईप करे के शुरु करीं (ज्यादा जानकारी खातिर देखीं [[{{MediaWiki:Helppage}}|मदद पन्ना]])।
 यदि रउआ अहिजा गलती से आ गईल बानी त, आपन ब्राउजर के '''back''' (बैक) बटन दबाईं",
+'noarticletext'        => 'ई पन्ना मे अभी कउनो सामग्री नईखे बा ।
+रउआ अन्य पन्ना में [[Special:Search/{{PAGENAME}}|ई शीर्षक के खोज]] कर सकत बानीं',
 'yourdiff'             => 'अंतर',
 'template-protected'   => '(संरक्षित)',
 
+# Parser/template warnings
+'post-expand-template-inclusion-category' => 'अइसन पृष्ठ जे पर साँचा जोडे के सीमा पार हो गइल बा',
+
 # History pages
 'revisionasof'           => '$1 के रुप में संशोधन',
 'revision-info'          => '$2 में से $1 के रुप में संशोधन',
@@ -421,7 +433,7 @@ Legend: '''({{int:cur}})''' = हाल के संशोधन के सा
 'compareselectedversions'  => 'चुनल गईल संशोधन में अन्तर देखीं',
 'showhideselectedversions' => 'चुनल गईल संशोधन दिखाईं/छुपाईं',
 'editundo'                 => 'पूर्ववत',
-'diff-multi'               => '({{PLURAL:$1|एगो मध्यम संशोधन|$1 गो मध्यम संशोधन}} नईखे दिखावल)',
+'diff-multi'               => '({{PLURAL:$2|एगो योगदानकर्ता|$2 योगदानकर्ताओं}} द्वारा {{PLURAL:$1|कियल गईल बीच के एगो|कियल गईल बीच के $1}} अवतरण नईखे दर्शावल बा।)',
 
 # Search results
 'searchresults'                    => 'खोज परिणाम',
@@ -453,6 +465,7 @@ Legend: '''({{int:cur}})''' = हाल के संशोधन के सा
 'searchprofile-project-tooltip'    => '$1 में खोजीं',
 'searchprofile-images-tooltip'     => 'फाईल खातिर खोज',
 'searchprofile-everything-tooltip' => 'सभन सामग्री में खोजीं (वार्ता पन्ना सहित)',
+'searchprofile-advanced-tooltip'   => 'विशेष नामस्थान में खोजीं',
 'search-result-size'               => '$1 ({{PLURAL:$2|1 शब्द|$2 शब्द}})',
 'search-result-score'              => 'प्रासंगिकता: $1%',
 'search-redirect'                  => '(पुन: निर्देशण $1)',
@@ -470,6 +483,7 @@ Legend: '''({{int:cur}})''' = हाल के संशोधन के सा
 'searchall'                        => 'सब',
 'showingresults'                   => "नीचे देखावल जा रहल बा {{PLURAL:$1|'''1''' परिणाम|'''$1''' परिणाम}} #'''$2''' से शुरु होवे वाला।",
 'showingresultsnum'                => "नीचे देखावल जा रहल बा {{PLURAL:$3|'''1''' परिणाम|'''$3''' परिणाम}} #'''$2''' से शुरु होवे वाला।",
+'search-nonefound'                 => 'राउर खोज मे से मेल खात कउनो परिणाम नईखे बा',
 'powersearch'                      => 'उन्नत खोज',
 'powersearch-legend'               => 'उन्नत खोज',
 'powersearch-ns'                   => 'सन्दर्भ में खोजीं',
@@ -485,7 +499,7 @@ Legend: '''({{int:cur}})''' = हाल के संशोधन के सा
 
 # Preferences page
 'preferences'    => 'वरीयता',
-'mypreferences'  => 'हमार पसन्द',
+'mypreferences'  => 'राउर पसन्द',
 'prefs-edits'    => 'सम्पादन संख्या',
 'prefsnologin'   => 'खाता में प्रवेश नईखीं कईले',
 'changepassword' => 'गुप्त शब्द बदलीं',
@@ -494,6 +508,9 @@ Legend: '''({{int:cur}})''' = हाल के संशोधन के सा
 
 # Recent changes
 'recentchanges'                     => 'तुरंत भईल परिवर्तन',
+'recentchanges-legend'              => 'हाल के परिवर्तन संबंधी विकल्प',
+'recentchanges-label-newpage'       => 'ई सम्पादन से एगो नवका पृष्ठ तैयार हो गइल बा',
+'recentchanges-label-minor'         => 'ई एगो छोटा सम्पाद बा',
 'rcshowhideminor'                   => '$1 छोट सम्पादन',
 'diff'                              => 'अन्तर',
 'hist'                              => 'इति',
@@ -513,6 +530,7 @@ Legend: '''({{int:cur}})''' = हाल के संशोधन के सा
 'upload' => 'फाईल लादीं',
 
 # File description page
+'file-anchor-link'                  => 'फ़ाइल',
 'filehist'                          => 'पन्ना के इतिहास',
 'filehist-deleteall'                => 'सब मिटाईं',
 'filehist-deleteone'                => 'मिटाईं',
@@ -525,7 +543,7 @@ Legend: '''({{int:cur}})''' = हाल के संशोधन के सा
 'filehist-filesize'                 => 'फाईल के आकार',
 'filehist-comment'                  => 'टिप्पणी',
 'filehist-missing'                  => 'गायब फाईल',
-'imagelinks'                        => 'फाईल लिंक',
+'imagelinks'                        => 'फाईल के उपयोग',
 'nolinkstoimage'                    => 'इ फाईल जोड़े कौनो फाइल लिंक नईखे।',
 'morelinkstoimage'                  => 'इ फाइल संगे जुड़ल [[Special:WhatLinksHere/$1|सब लिंक]] देखीं।',
 'sharedupload'                      => 'इ फाईल $1 से बा आ दुसर परियोजना में प्रयोग करल जा सकत बा।',
@@ -555,6 +573,7 @@ Legend: '''({{int:cur}})''' = हाल के संशोधन के सा
 
 # Miscellaneous special pages
 'nbytes'       => '$1 {{PLURAL:$1|बाईट|बाईट्स}}',
+'newpages'     => 'नवका पन्ना',
 'move'         => 'स्थान्तरण',
 'movethispage' => 'ई पन्ना के स्थांतरण करीं',
 
@@ -562,15 +581,17 @@ Legend: '''({{int:cur}})''' = हाल के संशोधन के सा
 'booksources' => 'किताबी स्त्रोत',
 
 # Special:AllPages
+'alphaindexline' => '$1 से $2',
+'allarticles'    => 'सभी पन्ना',
 'allpagessubmit' => 'जाईं',
 'allpagesprefix' => 'उपसर्ग के साथे पन्ना प्रदर्शन:',
 
-# E-mail user
+# Email user
 'emailuser' => 'ई प्रयोगकर्ता के ईमेल करीं',
 
 # Watchlist
-'watchlist'     => 'हमार ध्यानसूची',
-'mywatchlist'   => 'हमार ध्यानसूची',
+'watchlist'     => 'राउर ध्यान दियल पन्ना के सूची',
+'mywatchlist'   => 'राउर ध्यान दियल पन्ना के सूची',
 'watch'         => 'ध्यानसूची में डालीं',
 'watchthispage' => 'ई पन्ना ध्यानसूची में डालीं',
 'unwatch'       => 'ध्यानसूची से हटाईं',
@@ -582,6 +603,9 @@ Legend: '''({{int:cur}})''' = हाल के संशोधन के सा
 'enotif_newpagetext' => 'इ एगो नया पन्ना ह',
 'created'            => 'बनावल गईल',
 
+# Rollback
+'rollbacklink' => 'वापिस लीं',
+
 # Undelete
 'undeletelink' => 'देखीं/बहाल करीं',
 
@@ -593,7 +617,7 @@ Legend: '''({{int:cur}})''' = हाल के संशोधन के सा
 # Contributions
 'contributions'       => 'प्रयोगकर्ता योगदान',
 'contributions-title' => ' $1 खातिर प्रयोगकर्ता योगदान',
-'mycontris'           => 'हमार योगदान',
+'mycontris'           => 'राउर योगदान के सूची',
 'nocontribs'          => 'ई मानदंड से मिलत जुलत कौनो बदलाव ना मिलल।',
 'uctop'               => '(शीर्ष)',
 'month'               => 'महिना से (आ उ से पहिले):',
@@ -618,17 +642,18 @@ Legend: '''({{int:cur}})''' = हाल के संशोधन के सा
 'nolinkshere'              => "'''[[:$1]]''' से कौनो पन्ना नईखे जुड़ल।",
 'nolinkshere-ns'           => "चुनल गईल सन्दर्भ में '''[[:$1]]''' से कौनो पन्ना ना जुड़ेला।",
 'isredirect'               => 'पुन: निर्दिष्ट पन्ना',
-'isimage'                  => 'तस्वीर लिंक',
+'isimage'                  => 'फाईल लिंक',
 'whatlinkshere-prev'       => '{{PLURAL:$1|पिछला|पिछला $1}}',
 'whatlinkshere-next'       => '{{PLURAL:$1|अगला|अगला $1}}',
 'whatlinkshere-links'      => '← लिंक',
 'whatlinkshere-hideredirs' => '$1 पुन: निर्देशित',
 'whatlinkshere-hidelinks'  => '$1 लिंक',
-'whatlinkshere-hideimages' => '$1 तस्वीर लिंक',
+'whatlinkshere-hideimages' => '$1 फ़ाइल लिंक',
 'whatlinkshere-filters'    => 'फिल्टर',
 
 # Block/unblock
 'blockip'          => 'प्रतिबंधित प्रयोगकर्ता',
+'ipboptions'       => '२ घंटे:2 hours,१ दिन:1 day,३ दिन:3 days,१ हफ्ता:1 week,२ हफ्ते:2 weeks,१ महिना:1 month,३ महिने:3 months,६ महिने:6 months,१ साल:1 year,हमेशा खातिर:infinite',
 'blocklink'        => 'निष्क्रिय',
 'unblocklink'      => 'ताला खोलीं',
 'change-blocklink' => 'ब्लॉक बदलीं',
@@ -639,6 +664,9 @@ Legend: '''({{int:cur}})''' = हाल के संशोधन के सा
 'movepagebtn' => 'पन्ना स्थांतरण करीं',
 'revertmove'  => 'पिछलका स्थिति',
 
+# Export
+'export' => 'पन्ना निर्यात करीं',
+
 # Thumbnails
 'thumbnail-more' => 'बढ़ाईं',
 'filemissing'    => 'फाईल गायब',
@@ -647,8 +675,9 @@ Legend: '''({{int:cur}})''' = हाल के संशोधन के सा
 'tooltip-pt-userpage'            => 'राउर प्रयोगकर्ता पन्ना',
 'tooltip-pt-mytalk'              => 'राउर वार्ता पन्ना',
 'tooltip-pt-preferences'         => 'राउर पसन्द',
+'tooltip-pt-watchlist'           => 'राउर ध्यान दियल पन्ना के सूची',
 'tooltip-pt-mycontris'           => 'राउर योगदान के सूची',
-'tooltip-pt-login'               => 'रउआ के खाता प्रवेश खातिर प्रोत्साहित करल जा रहल बा, बाँकि ई अनिवार्य नईखे',
+'tooltip-pt-login'               => 'रउआ के खाता प्रवेश खातिर प्रोत्साहित करल जा रहल बा, बाकि ई अनिवार्य नईखे',
 'tooltip-pt-anonlogin'           => 'रउआ के खाता प्रवेश खातिर प्रोत्साहित करल जा रहल बा, बाँकि ई अनिवार्य नईखे',
 'tooltip-pt-logout'              => 'खाता से बाहर',
 'tooltip-ca-talk'                => 'सामग्री पन्ना के बारे में बात-चीत',
@@ -674,13 +703,20 @@ Legend: '''({{int:cur}})''' = हाल के संशोधन के सा
 'tooltip-n-help'                 => 'जगह पता लगावे खातिर',
 'tooltip-t-whatlinkshere'        => 'अहिजा लिंक होखे वाला सब विकि पन्ना के सूची',
 'tooltip-t-recentchangeslinked'  => 'ई पन्ना से जुड़ल पन्नवन पर तुरंत भईल परिवर्तन',
+'tooltip-feed-atom'              => 'ई पन्ना खातिर अणु फ़ीड',
 'tooltip-t-upload'               => 'फाईल लादीं (अपलोड )',
 'tooltip-t-specialpages'         => 'ख़ाश पन्नवन के सूची',
 'tooltip-t-print'                => 'ई पन्ना के छापे लायक संस्करण।',
 'tooltip-t-permalink'            => 'ई पन्ना के संसोधन खातिर स्थायी लिंक।',
 'tooltip-ca-nstab-main'          => 'सामग्री पन्ना देखीं',
 'tooltip-ca-nstab-special'       => 'ई एगो ख़ाश पन्ना ह, रउआ ई पन्ना के सम्पादन नईखीं कर सकत',
+'tooltip-ca-nstab-image'         => 'संचिका के पन्ना देखीं',
+'tooltip-ca-nstab-template'      => 'टेम्प्लेट देखीं',
+'tooltip-ca-nstab-category'      => 'श्रेणी के पन्ना देखीं',
 'tooltip-save'                   => 'आपन बदलाव के सुरक्षित करीं',
+'tooltip-preview'                => 'आपन द्वारा कियल गइल बदलाव के देखीं, संजोये से पहले ईका इस्तेमाल करीं!',
+'tooltip-rollback'               => '"वापिस लीं" ई पन्ना के पिछ्ला योगदाता के बदलाव एकही चटके मे गायब कर देवेला',
+'tooltip-summary'                => 'एगो संक्षिप्त सारांश दर्ज करीं',
 
 # Media information
 'file-nohires'         => ' उच्च गुणवत्ता उपलब्ध नईखे।',
@@ -721,7 +757,7 @@ Legend: '''({{int:cur}})''' = हाल के संशोधन के सा
 'monthsall'     => 'सब',
 'limitall'      => 'सब',
 
-# E-mail address confirmation
+# Email address confirmation
 'confirmemail' => 'इ-मेल पता कन्फर्म करीं',
 
 # Special:SpecialPages
