@@ -9,6 +9,7 @@
  *
  * @author Freeyak
  * @author Jason (on bo.wikipedia.org)
+ * @author YeshiTuhden
  */
 
 $digitTransformTable = array(
@@ -232,6 +233,7 @@ $messages = array(
 'disclaimerpage'       => 'Project:སྤྱིའི་དགག་བྱ།',
 'edithelp'             => 'རྩོམ་སྒྲིག་རོགས་རམ།',
 'edithelppage'         => 'Help:རྩོམ་སྒྲིག',
+'helppage'             => 'Help:ནང་དོན་',
 'mainpage'             => 'གཙོ་ངོས།',
 'mainpage-description' => 'གཙོ་ངོས།',
 'policy-url'           => 'Project: སྒྲིག་གཞི།',
@@ -368,35 +370,37 @@ $messages = array(
 'hr_tip'          => 'ཐད་ཐིག ༼ཆུད་ཟོས་མེད་པར།༽',
 
 # Edit pages
-'summary'            => 'བསྡུས་དོན།:',
-'subject'            => 'འགོ་བརྗོད།',
-'minoredit'          => 'འདི་ནི་རྩོམ་སྒྲིག་ཕལ་བ་ཞིག་ཡིན།',
-'watchthis'          => 'དྲ་ངོས་འདི་ལ་གཟིགས།',
-'savearticle'        => 'ཤོག་ངོས་ཉར་བ།',
-'preview'            => 'སྔོན་ལྟ།',
-'showpreview'        => 'སྔོན་ལྟ་སྟོན་ཅིག',
-'showlivepreview'    => 'ད་ཡོད་སྔོན་ལྟ།',
-'showdiff'           => 'བཟོས་བཅོས་སྟོན།',
-'anoneditwarning'    => "'''གསལ་བརྡ།''' ཁྱེད་ཐོ་འཛུལ་བྱས་མི་འདུག ཁྱེད་ཀྱི་ IP ཁ་བྱང་ཤོག་ངོས་འདིའི་རྩོམ་སྒྲིག་ལོ་རྒྱུས་སུ་ཉར་ཚགས་བྱས་པར་འགྱུར།",
-'anonpreviewwarning' => '༼ཁྱེད་རང་ཐོ་འཛུལ་བྱས་མི་འདུག ཉར་ཚགས་ཀྱིས་ཁྱེད་ཀྱི་ IP ཁ་བྱང་ཤོག་ངོས་འདིའི་རྩོམ་སྒྲིག་ལོ་རྒྱུས་སུ་ཉར་ཚགས་བྱས་པར་འགྱུར།༽',
-'summary-preview'    => 'བསྡུས་དོན་སྔོན་ལྟ།',
-'subject-preview'    => 'བརྗོད་གཞི་དང་འགོ་བརྗོད་སྔོན་ལྟ།',
-'blockedtitle'       => 'སྤྱོད་མི་བཀག་ཟིན།',
-'blockednoreason'    => 'རྒྱུ་མཚན་བྱིན་མི་འདུག',
-'whitelistedittext'  => 'ཤོག་ངོས་རྩོམ་སྒྲིག་བྱེད་པར་ངེས་པར་དུ་$1བྱ་དགོས།',
-'loginreqtitle'      => 'ནང་འཛུལ་བྱ་དགོས།',
-'loginreqlink'       => 'ནང་འཛུལ་',
-'loginreqpagetext'   => 'ཤོག་ངོས་གཞན་རྣམས་ལྟ་བར་ངེས་པར་དུ་$1བྱ་དགོས།',
-'accmailtitle'       => 'ལམ་ཡིག་བཏང་ཟིན།',
-'newarticle'         => '(གསར་བ)',
-'previewnote'        => '༼འདི་ནི་སྔོན་ལྟ་ཙམ་ཡིན་པ་མ་བརྗེད།༽ ཁྱེད་ཀྱི་བཟོ་བཅོས་ད་དུང་ཉར་ཚགས་བྱས་མི་འདུག',
-'editing'            => '$1རྩོམ་སྒྲིག་བྱེད་བཞིན་པ།',
-'editingsection'     => ' $1 (སྡེ་ཚན) ལ་རྩོམ་སྒྲིག་བྱེད་བཞིན་པ།',
-'yourtext'           => 'ཁྱོད་ཀྱི་ཡིག་འབྲུ།',
-'yourdiff'           => 'མི་འདྲ་ས།',
-'templatesused'      => 'ཤོག་ངོས་འདིར་སྤྱད་པའི་ {{PLURAL:$1|དཔེ་པང་།|དཔེ་པང་།}}',
-'template-protected' => 'སྲུང་སྐྱོབ་འོག་ཡོད་པ།',
-'nocreate-loggedin'  => 'ཤོག་ངོས་གསར་བཟོའི་ཆོག་མཆན་མི་འདུག',
+'summary'                    => 'བསྡུས་དོན།:',
+'subject'                    => 'འགོ་བརྗོད།',
+'minoredit'                  => 'འདི་ནི་རྩོམ་སྒྲིག་ཕལ་བ་ཞིག་ཡིན།',
+'watchthis'                  => 'དྲ་ངོས་འདི་ལ་གཟིགས།',
+'savearticle'                => 'ཤོག་ངོས་ཉར་བ།',
+'preview'                    => 'སྔོན་ལྟ།',
+'showpreview'                => 'སྔོན་ལྟ་སྟོན་ཅིག',
+'showlivepreview'            => 'ད་ཡོད་སྔོན་ལྟ།',
+'showdiff'                   => 'བཟོས་བཅོས་སྟོན།',
+'anoneditwarning'            => "'''གསལ་བརྡ།''' ཁྱེད་ཐོ་འཛུལ་བྱས་མི་འདུག ཁྱེད་ཀྱི་ IP ཁ་བྱང་ཤོག་ངོས་འདིའི་རྩོམ་སྒྲིག་ལོ་རྒྱུས་སུ་ཉར་ཚགས་བྱས་པར་འགྱུར།",
+'anonpreviewwarning'         => '༼ཁྱེད་རང་ཐོ་འཛུལ་བྱས་མི་འདུག ཉར་ཚགས་ཀྱིས་ཁྱེད་ཀྱི་ IP ཁ་བྱང་ཤོག་ངོས་འདིའི་རྩོམ་སྒྲིག་ལོ་རྒྱུས་སུ་ཉར་ཚགས་བྱས་པར་འགྱུར།༽',
+'summary-preview'            => 'བསྡུས་དོན་སྔོན་ལྟ།',
+'subject-preview'            => 'བརྗོད་གཞི་དང་འགོ་བརྗོད་སྔོན་ལྟ།',
+'blockedtitle'               => 'སྤྱོད་མི་བཀག་ཟིན།',
+'blockednoreason'            => 'རྒྱུ་མཚན་བྱིན་མི་འདུག',
+'whitelistedittext'          => 'ཤོག་ངོས་རྩོམ་སྒྲིག་བྱེད་པར་ངེས་པར་དུ་$1བྱ་དགོས།',
+'loginreqtitle'              => 'ནང་འཛུལ་བྱ་དགོས།',
+'loginreqlink'               => 'ནང་འཛུལ་',
+'loginreqpagetext'           => 'ཤོག་ངོས་གཞན་རྣམས་ལྟ་བར་ངེས་པར་དུ་$1བྱ་དགོས།',
+'accmailtitle'               => 'ལམ་ཡིག་བཏང་ཟིན།',
+'newarticle'                 => '(གསར་བ)',
+'previewnote'                => '༼འདི་ནི་སྔོན་ལྟ་ཙམ་ཡིན་པ་མ་བརྗེད།༽ ཁྱེད་ཀྱི་བཟོ་བཅོས་ད་དུང་ཉར་ཚགས་བྱས་མི་འདུག',
+'editing'                    => '$1རྩོམ་སྒྲིག་བྱེད་བཞིན་པ།',
+'editingsection'             => ' $1 (སྡེ་ཚན) ལ་རྩོམ་སྒྲིག་བྱེད་བཞིན་པ།',
+'yourtext'                   => 'ཁྱོད་ཀྱི་ཡིག་འབྲུ།',
+'yourdiff'                   => 'མི་འདྲ་ས།',
+'templatesused'              => 'ཤོག་ངོས་འདིར་སྤྱད་པའི་ {{PLURAL:$1|དཔེ་པང་།|དཔེ་པང་།}}',
+'template-protected'         => 'སྲུང་སྐྱོབ་འོག་ཡོད་པ།',
+'nocreate-loggedin'          => 'ཤོག་ངོས་གསར་བཟོའི་ཆོག་མཆན་མི་འདུག',
+'recreate-moveddeleted-warn' => "'''ཉེན་བརྡ་:རང་གིས་སུབ་ཚར་བའི་ཤོག་ལེ་ཞིག་བསྐྱར་བཟོ་བྱེད་ཀྱི་འདུག་ '''
+ཁྱེད་རང་གལ་སྲིད་མུ་མཐུད་ཤོག་ལེ་འདི་བཟོ་ཅོས་བྱེད་འདོད་ན་སྟབས་བདེ་ཞིག་ལ་ང་ཚོས་སུབ་བཟིན་པའི་ཤོག་ལེ་འདིར་ཉར་ཡོད།",
 
 # History pages
 'viewpagelogs'           => 'ཤོག་ངོས་འདིའི་ཉིན་ཐོ་ལ་ལྟ་བ།',
@@ -436,38 +440,44 @@ $messages = array(
 'editundo' => 'ཕྱིར་འཐེན།',
 
 # Search results
-'searchresults'                  => 'བཙལ་བའི་རྙེད་དོན།',
-'searchresults-title'            => ' $1 བཙལ་བའི་འབྲས་བུ།',
-'searchresulttext'               => '{{SITENAME}} སྐོར་ལ་རྒྱས་བར་[[{{MediaWiki:Helppage}}|{{int:help}}]]. ལ་ལྟ་རོགས།',
-'searchsubtitle'                 => 'ཁྱེད་ཀྱིས་\'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|all pages starting with "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|all pages that link to "$1"]])བཙལ་འདུག',
-'searchsubtitleinvalid'          => "ཁྱེད་ཀྱིས་'''$1'''བཙལ་འདུག",
-'notitlematches'                 => 'ཤོག་ངོས་འགོ་བརྗོད་མཚུངས་པ་མི་འདུག',
-'notextmatches'                  => 'ཤོག་ངོས་ཡིག་འབྲུ་མཚུངས་པ་མི་འདུག',
-'prevn'                          => 'སྔོན་མ་{{PLURAL:$1|$1}}',
-'nextn'                          => 'རྗེས་མ་{{PLURAL:$1|$1}}',
-'viewprevnext'                   => '($1 {{int:pipe-separator}} $2) ($3)ལ་ལྟ་བ།',
-'searchmenu-legend'              => 'འཚོལ་ཞིབ་འདེམས་ཚན།',
-'searchprofile-articles-tooltip' => '$1ནང་དུ་འཚོལ་བ།',
-'searchprofile-project-tooltip'  => '$1ནང་དུ་འཚོལ་བ།',
-'searchprofile-images-tooltip'   => 'ཡིག་ཆ་འཚོལ་བ།',
-'search-result-size'             => '$1({{PLURAL:$2|1 word|$2 words}})',
-'search-redirect'                => '($1རིམ་འགྲེམ།)',
-'search-section'                 => '(ཚན་པ $1)',
-'search-suggest'                 => '$1 ལ་ཟེར་བ་ཡིན་ནམ།',
-'search-interwiki-caption'       => 'སྲིང་མོའི་ལས་འཆར།',
-'search-interwiki-default'       => '$1ལས་རྙེད་པ།',
-'search-interwiki-more'          => '（དེ་ལས་མང་བ།）',
-'search-mwsuggest-enabled'       => 'གྲོས་འཆར་དང་བཅས།',
-'search-mwsuggest-disabled'      => 'གྲོས་འཆར་མི་དགོས།',
-'search-relatedarticle'          => 'འབྲེལ་ཡོད།',
-'searchall'                      => 'ཚང་མ།',
-'powersearch'                    => 'ཞིབ་ཏུ་འཚོལ་བ།',
-'powersearch-legend'             => 'ཞིབ་ཏུ་འཚོལ་བ།',
-'powersearch-ns'                 => 'མིང་གནས་ནང་འཚོལ་བ།',
-'powersearch-redir'              => 'ཁ་ཕྱོགས་གསར་བཟོ་སྟོན་པ།',
-'powersearch-field'              => 'བཙལ་བྱ།',
-'powersearch-toggleall'          => 'ཚང་མ།',
-'powersearch-togglenone'         => 'མེད།',
+'searchresults'                    => 'བཙལ་བའི་རྙེད་དོན།',
+'searchresults-title'              => ' $1 བཙལ་བའི་འབྲས་བུ།',
+'searchresulttext'                 => '{{SITENAME}} སྐོར་ལ་རྒྱས་བར་[[{{MediaWiki:Helppage}}|{{int:help}}]]. ལ་ལྟ་རོགས།',
+'searchsubtitle'                   => 'ཁྱེད་ཀྱིས་\'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|all pages starting with "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|all pages that link to "$1"]])བཙལ་འདུག',
+'searchsubtitleinvalid'            => "ཁྱེད་ཀྱིས་'''$1'''བཙལ་འདུག",
+'notitlematches'                   => 'ཤོག་ངོས་འགོ་བརྗོད་མཚུངས་པ་མི་འདུག',
+'notextmatches'                    => 'ཤོག་ངོས་ཡིག་འབྲུ་མཚུངས་པ་མི་འདུག',
+'prevn'                            => 'སྔོན་མ་{{PLURAL:$1|$1}}',
+'nextn'                            => 'རྗེས་མ་{{PLURAL:$1|$1}}',
+'viewprevnext'                     => '($1 {{int:pipe-separator}} $2) ($3)ལ་ལྟ་བ།',
+'searchmenu-legend'                => 'འཚོལ་ཞིབ་འདེམས་ཚན།',
+'searchmenu-new'                   => 'ལྦེ་ཁེ་སྟེང་ལ་ཤོག་ལེ་ [[:$1]]བཟོས།',
+'searchprofile-project'            => 'རོགས་རམ་དང་འཆར་གཞིའི་ཤོག་ངོས་',
+'searchprofile-everything'         => 'ཚང་མ་',
+'searchprofile-advanced'           => 'མཐོ་རིམ་',
+'searchprofile-articles-tooltip'   => '$1ནང་དུ་འཚོལ་བ།',
+'searchprofile-project-tooltip'    => '$1ནང་དུ་འཚོལ་བ།',
+'searchprofile-images-tooltip'     => 'ཡིག་ཆ་འཚོལ་བ།',
+'searchprofile-everything-tooltip' => 'བརྗོད་དོན་ཚང་མ་འཚོལ་གཞིབ་བྱེད་(གྲོས་མེས་ཤོག་ངོས་ཡང་འཚུད་པ་)',
+'search-result-size'               => '$1({{PLURAL:$2|1 word|$2 words}})',
+'search-redirect'                  => '($1རིམ་འགྲེམ།)',
+'search-section'                   => '(ཚན་པ $1)',
+'search-suggest'                   => '$1 ལ་ཟེར་བ་ཡིན་ནམ།',
+'search-interwiki-caption'         => 'སྲིང་མོའི་ལས་འཆར།',
+'search-interwiki-default'         => '$1ལས་རྙེད་པ།',
+'search-interwiki-more'            => '（དེ་ལས་མང་བ།）',
+'search-mwsuggest-enabled'         => 'གྲོས་འཆར་དང་བཅས།',
+'search-mwsuggest-disabled'        => 'གྲོས་འཆར་མི་དགོས།',
+'search-relatedarticle'            => 'འབྲེལ་ཡོད།',
+'searchall'                        => 'ཚང་མ།',
+'search-nonefound'                 => 'ཁྱེད་ཀྱི་འདྲི་ཞིབ་དང་མཐུན་པའི་ལན་མི་འདུག་',
+'powersearch'                      => 'ཞིབ་ཏུ་འཚོལ་བ།',
+'powersearch-legend'               => 'ཞིབ་ཏུ་འཚོལ་བ།',
+'powersearch-ns'                   => 'མིང་གནས་ནང་འཚོལ་བ།',
+'powersearch-redir'                => 'ཁ་ཕྱོགས་གསར་བཟོ་སྟོན་པ།',
+'powersearch-field'                => 'བཙལ་བྱ།',
+'powersearch-toggleall'            => 'ཚང་མ།',
+'powersearch-togglenone'           => 'མེད།',
 
 # Preferences page
 'mypreferences'             => 'ངའི་ལེགས་སྒྲིག',
@@ -675,7 +685,7 @@ $messages = array(
 # Special:ListGroupRights
 'listgrouprights-members' => 'ཁོངས་མིའི་ཐོ་ཡིག',
 
-# E-mail user
+# Email user
 'emailuser'    => 'སྤྱོད་མི་འདིར་གློག་འཕྲིན་སྐུར་བ།',
 'emailmessage' => 'སྐད་ཆ།',
 
@@ -735,6 +745,7 @@ $messages = array(
 
 # Undelete
 'undeletelink'           => 'ལྟ་བ། / བསྐྱར་འདྲེན།',
+'undeleteviewlink'       => 'ལྟ་བ་',
 'undelete-search-submit' => 'འཚོལ།',
 
 # Namespace form on various pages
@@ -787,7 +798,8 @@ $messages = array(
 'export' => 'ཤོག་ངོས་ཕྱི་འདྲེན།',
 
 # Namespace 8 related
-'allmessages' => 'མ་ལག་གི་སྐད་ཆ།',
+'allmessages'     => 'མ་ལག་གི་སྐད་ཆ།',
+'allmessagesname' => 'མིང་',
 
 # Thumbnails
 'thumbnail-more' => 'ཆེ་རུ་གཏོང་བ།',
@@ -842,6 +854,7 @@ $messages = array(
 'tooltip-save'                   => 'བཟོ་བཅོས་ཉར་ཚགས་བྱོས།',
 'tooltip-preview'                => 'ཉར་ཚགས་ཀྱི་སྔོན་དུ་བཟོ་བཅོས་ལ་བསྐྱར་ཞིབ་གནང་རོགས།',
 'tooltip-diff'                   => 'གང་ལ་བཟོ་བཅོས་བྱས་པའི་ཡིག་འབྲུ་སྟོན་པ།',
+'tooltip-summary'                => 'ཕྱོགས་བསྡོམས་ཐུང་ངུ་ཞིག་འབྲིས་',
 
 # Browsing diffs
 'previousdiff' => '← རྩོམ་སྒྲིག་རྙིང་བ།',
