@@ -1,5 +1,5 @@
 <?php
-/** Friulian (Furlan)
+/** Friulian (furlan)
  *
  * See MessagesQqq.php for message documentation incl. usage of parameters
  * To improve a translation please visit http://translatewiki.net
@@ -11,6 +11,7 @@
  * @author Kaganer
  * @author Klenje
  * @author MF-Warburg
+ * @author Reedy
  * @author Urhixidur
  * @author לערי ריינהארט
  */
@@ -229,7 +230,7 @@ $messages = array(
 'cancel'        => 'Scancele',
 'moredotdotdot' => 'Plui...',
 'mypage'        => 'Mê pagjine',
-'mytalk'        => 'Mês discussions',
+'mytalk'        => 'Discussions',
 'anontalk'      => 'Discussion par chest IP',
 'navigation'    => 'somari',
 'and'           => '&#32;e',
@@ -555,7 +556,8 @@ Tu puedis [[Special:Search/{{PAGENAME}}|cirî chest titul]] in altris pagjinis o
 'clearyourcache'                   => "'''Ocjo: dopo vê salvât, tu podaressis scugnî netâ la cache dal to sgarfadôr par viodi i cambiaments.''' Par '''Mozilla / Firefox / Safari''': frache ''Torne a cjamâ'' tignint jù ancje il tast des maiusculis, o se no frache ''Ctrl-F5'' o ''Ctrl-R'' (''Command-R'' su Mac); par '''Konqueror''': frache ''Reload'' o il tast ''F5''; par '''Opera''' al pues jessi necessari disvuedâ dal dut la cache doprant il menù ''Tools → Preferencis''; par '''Internet Explorer:''' ten fracât il tast ''Ctrl'' cuant che tu cjalcjis su ''Aggiorna'' o frache ''Ctrl-F5''.",
 'updated'                          => '(Inzornât)',
 'note'                             => "'''Note:'''",
-'previewnote'                      => "'''Visiti che cheste e je dome une anteprime, e no je stade ancjemò salvade!'''",
+'previewnote'                      => "'''Visiti che cheste e je dome une anteprime.'''
+I tiei cambiaments no son stâts ancjemò salvâts!",
 'editing'                          => 'Cambiament di $1',
 'editingsection'                   => 'Cambiament di $1 (sezion)',
 'editingcomment'                   => 'Cambiament di $1 (gnove sezion)',
@@ -721,7 +723,7 @@ Leiende: (cur) = difarencis cun la version atuâl, (prec) = difarencis cun la ve
 
 # Preferences page
 'preferences'                 => 'Preferencis',
-'mypreferences'               => 'mês preferencis',
+'mypreferences'               => 'Preferencis',
 'prefs-edits'                 => 'Numar di cambiaments fats:',
 'prefsnologin'                => 'No tu sês jentrât',
 'changepassword'              => 'Gambie peraule clâf',
@@ -940,7 +942,7 @@ Par includi une figure intune pagjine, dopre un leam inte form
 'filehist-dimensions'       => 'Dimensions',
 'filehist-filesize'         => 'Dimension dal file',
 'filehist-comment'          => 'Coment',
-'imagelinks'                => 'Leams ae figure',
+'imagelinks'                => 'Ûs dal file',
 'linkstoimage'              => '{{PLURAL:$1|La pagjine ca sot e je leade|Lis $1 pagjinis ca sot a son leadis}} a cheste figure:',
 'nolinkstoimage'            => 'No son pagjinis leadis a chest file.',
 'sharedupload'              => 'Chest file al è ven di $1 e al pues jessi doprât di altris progjets.',
@@ -1047,7 +1049,7 @@ La descrizion su la sô [$2 pagjine di descrizion] e je mostrade ca sot.',
 'protectedtitles'         => 'Titui protezûts',
 'listusers'               => 'Liste dai utents',
 'usereditcount'           => '$1 {{PLURAL:$1|contribût|contribûts}}',
-'usercreated'             => 'Creât ai $1 a lis $2',
+'usercreated'             => '{{GENDER:$3|Creât|Creade}} ai $1 a lis $2',
 'newpages'                => 'Gnovis pagjinis',
 'newpages-username'       => 'Non utent:',
 'ancientpages'            => 'Pagjinis plui vecjis',
@@ -1130,7 +1132,7 @@ Cjale ancje lis [[Special:WantedCategories|categoriis desideradis]].',
 'listgrouprights-rights'  => 'Dirits',
 'listgrouprights-members' => '(liste dai membris)',
 
-# E-mail user
+# Email user
 'emailuser'       => 'Messaç di pueste a chest utent',
 'emailpage'       => 'Mande un messaç di pueste eletroniche al utent',
 'defemailsubject' => 'Messaç di {{SITENAME}}',
@@ -1148,7 +1150,7 @@ Cjale ancje lis [[Special:WantedCategories|categoriis desideradis]].',
 
 # Watchlist
 'watchlist'            => 'Tignûts di voli',
-'mywatchlist'          => 'Tignûts di voli',
+'mywatchlist'          => 'Tignudis di voli',
 'watchlistfor2'        => 'Par $1 $2',
 'nowatchlist'          => 'Nissun element al è tignût di voli.',
 'watchnologin'         => 'No tu sês jentrât',
@@ -1264,7 +1266,7 @@ Tu puedis cambiâ il nivel di protezion di cheste pagjine, ma chest nol varà ef
 # Contributions
 'contributions'       => 'Contribûts dal utent',
 'contributions-title' => 'Contribûts di $1',
-'mycontris'           => 'Miei contribûts',
+'mycontris'           => 'Contribûts',
 'contribsub2'         => 'Par $1 ($2)',
 'nocontribs'          => 'Nissun cambiament che al rispiete chescj criteris cjatât.',
 'uctop'               => ' (su)',
@@ -1299,7 +1301,7 @@ Tu puedis cambiâ il nivel di protezion di cheste pagjine, ma chest nol varà ef
 'whatlinkshere-hideredirs' => '$1 re-indreçaments',
 'whatlinkshere-hidetrans'  => '$1 inclusions',
 'whatlinkshere-hidelinks'  => '$1 leams',
-'whatlinkshere-hideimages' => '$1 leams da figuris',
+'whatlinkshere-hideimages' => '$1 leams di files',
 'whatlinkshere-filters'    => 'Filtris',
 
 # Block/unblock
@@ -1351,7 +1353,7 @@ tu âs di cognossi lis conseguencis prime di lâ indevant.",
 In chescj câs, tu varâs di movi o unî a man lis informazions contignudis te pagjine di discussion, se tu lu desideris.",
 'movearticle'             => 'Môf la vôs',
 'movenologin'             => 'No tu sês jentrât',
-'movenologintext'         => 'Tu âs di jessi un utent regjistrât e <a href="{{localurl:Special:UserLogin}}">jentrât</a> par movi une pagjine.',
+'movenologintext'         => 'Tu âs di jessi un utent regjistrât e [[Special:UserLogin|jentrât]] par movi une pagjine.',
 'movenotallowed'          => 'No tu âs i permès che a coventin par movi lis pagjinis.',
 'newtitle'                => 'Al gnûf titul',
 'move-watch'              => 'Ten di voli cheste pagjine',
@@ -1576,7 +1578,7 @@ Se il file al è stât cambiât rispiet al so stât origjinâl, cualchi informaz
 'namespacesall' => 'ducj',
 'monthsall'     => 'ducj',
 
-# E-mail address confirmation
+# Email address confirmation
 'confirmemail'           => 'Conferme direzione di pueste',
 'confirmemail_noemail'   => 'No tu âs metût une direzion di pueste eletroniche valide intes tôs [[Special:Preferences|preferencis]].',
 'confirmemail_text'      => 'Cheste wiki ti domande di validÂ la to direzion di pueste eletroniche prime di doprâ lis funzions di email. Ative il boton ca sot par inviâ un codiç di conferme ae to direzion. Chest messaç al includarà un leam cuntun codiç; cjame il leam tal to sgarfadôr par confermâ la validitât de tô direzion.',
