@@ -236,10 +236,11 @@ $messages = array(
 'jumptonavigation'  => 'رہنمائی',
 'jumptosearch'      => 'تلاش',
 'view-pool-error'   => 'معذرت: تمام سرورا موجودہ وختہ اِضافی بوجھ شیر.
-بہت زیادہ صارفین موجودہ وختہ ھیہ صفحو لاڑینیان 
+بو زیادہ صارفین موجودہ وختہ ھیہ صفحو لاڑینیان 
 برائے مہربانی! صفحو لوڑیکو بچے دوبارہ کوشش کوریکاری پروشٹی پھوکرو انتظار کورے.
 
 $1',
+'pool-errorunknown' => 'نامعلوم خطا',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => 'تعارف {{SITENAME}}',
@@ -271,6 +272,7 @@ $1',
 [[Special:Version|version page]]',
 
 'ok'                      => 'ٹھیک شیر',
+'pagetitle'               => '$1 - {{SITENAME}}',
 'pagetitle-view-mainpage' => '{{SITENAME}}',
 'retrievedfrom'           => '‘‘$1’’ نقل کاردو',
 'youhavenewmessages'      => 'تہ بچے ای $1 شیر۔ ($2)',
@@ -278,6 +280,7 @@ $1',
 'newmessagesdifflink'     => 'تـجـدیـد مـاقـبل آخـراری فـرق',
 'youhavenewmessagesmulti' => 'ء$1 تہ بچے نوغ نوغ پیغامات شینی',
 'editsection'             => 'ترمیم',
+'editsection-brackets'    => '[$1]',
 'editold'                 => 'ترمیم',
 'viewsourceold'           => 'مآخذو لوڑے',
 'editlink'                => 'تدوین کورے',
@@ -286,6 +289,8 @@ $1',
 'toc'                     => 'فہرست',
 'showtoc'                 => 'پشاوے',
 'hidetoc'                 => 'کھوشتاوے',
+'collapsible-collapse'    => 'خاتمہ/Collapse',
+'collapsible-expand'      => 'فراخ کورے',
 'thisisdeleted'           => 'لوڑے  یا بحال کورے $1',
 'viewdeleted'             => 'لوڑے $1؟',
 'restorelink'             => '{{PLURAL:$1|ای ترمیم حذف ہوی|$1 ترامیم حذف ہونی}}',
@@ -293,6 +298,8 @@ $1',
 'site-atom-feed'          => '$1 اٹوم فیڈ',
 'page-rss-feed'           => '$1 آر ایس ایس فیڈ',
 'page-atom-feed'          => '$1 آٹوم فیڈ',
+'feed-atom'               => 'اٹوم',
+'feed-rss'                => 'آر ایس ایس',
 'red-link-title'          => '
 $1 (صفحہ موجود نیکی)',
 
@@ -395,7 +402,7 @@ MySQL جوابِ خطاء پرائے "$3: $4"',
 'yourname'                   => 'اسمِ رکنیت',
 'yourpassword'               => 'کلمۂ شناخت(پاسورڈ)',
 'yourpasswordagain'          => 'کلمۂ شناخت(پاسورڈو)دوبارہ نیویشے',
-'remembermypassword'         => '!!Rachitrali!!مہ یاد لاکھے (کم از کم $1 {{PLURAL:$1|بس|بس}})',
+'remembermypassword'         => 'ھیہ براوزیرا مہ داخلِ نوشتگی معلوماتن یاد لاکھے (زیاتاری زیات $1 {{PLURAL:$1|بس|بسان}} بچے)',
 'yourdomainname'             => 'تہ ڈومین',
 'externaldberror'            => 'یا تھے توثیقی ڈیٹابیسا خطا واقع بیتی شیر یا تتے بیریو کھاتو بتاریخ کوریکو اِجازت نیکی',
 'login'                      => 'داخل بوس',
@@ -482,7 +489,12 @@ MySQL جوابِ خطاء پرائے "$3: $4"',
 'resetpass-temp-password'   => 'عارضی پاسورڈ:',
 
 # Special:PasswordReset
-'passwordreset' => 'پاسورڈو ری سیٹ کورے',
+'passwordreset'          => 'پاسورڈو ری سیٹ کورے',
+'passwordreset-username' => 'ممبارو نم',
+
+# Special:ChangeEmail
+'changeemail-none'   => '(نو)',
+'changeemail-cancel' => 'کھینسل',
 
 # Edit page toolbar
 'bold_sample'     => 'بوسک متن',
@@ -559,6 +571,14 @@ MySQL جوابِ خطاء پرائے "$3: $4"',
 'moveddeleted-notice'              => 'ھیہ ای حذف شدہ صفحہ شیر.
 صفحو نوشتۂ حذف شدگی و منتقلی ذیلا بطورِ حوالہ دیونو بویان.',
 
+# Parser/template warnings
+'post-expand-template-inclusion-warning'  => "'''خبردار:''' سانچو سایز بو لوٹ شیر.
+بعضی سانچہ شامل نو بونی.",
+'post-expand-template-inclusion-category' => 'ھش صفحات کہ ھتیرا ٹمپلیٹ یعنی سانچو ناپ لوٹ بیتی شیر۔',
+'post-expand-template-argument-warning'   => "'''خبردار:''' ھیہ صفحا ای سانچہ(ٹمپلیٹ) مشقولگی دیونو بیتی شیر وا ھمو سایز بولوٹ شیر۔
+ھمی لوان نیزونو بیتی شیر",
+'post-expand-template-argument-category'  => 'ھش صفحات کہ ھتیرا بوغینو بیرو سانچان یعنی(ٹمپلیٹان) لو شینی۔',
+
 # History pages
 'viewpagelogs'           => 'ھیہ صفحہو بچے نوشتہ جاتن لوڑے',
 'currentrev-asof'        => 'حالیہ نظرثانی بمطابق $1',
@@ -568,6 +588,7 @@ MySQL جوابِ خطاء پرائے "$3: $4"',
 'nextrevision'           => '→پروشٹیو اعادہ',
 'currentrevisionlink'    => 'حالیہ نظرثانی',
 'cur'                    => 'رائج',
+'next'                   => 'پروشٹیو',
 'last'                   => 'سابقہ',
 'histlegend'             => "انتخاب: مختلف نسخان موازنہ کوریکو بچے ، پیامی خانان نشان زد کوری موڑا دیرو بٹنا کلک کورے۔
 
@@ -578,12 +599,16 @@ MySQL جوابِ خطاء پرائے "$3: $4"',
 'history-show-deleted'   => 'صرفی حذف شدہ',
 'histfirst'              => 'قدیم ترین',
 'histlast'               => 'تازہ ترین',
+'historyempty'           => '(خالی)',
 
 # Revision feed
 'history-feed-item-nocomment' => '$1 تا $2',
 
 # Revision deletion
 'rev-delundel'           => 'پشاوے/کھوشتاوے',
+'rev-showdeleted'        => 'پشاوے',
+'revdelete-radio-set'    => 'Yes/دی',
+'revdelete-radio-unset'  => 'نو',
 'revdel-restore'         => 'ظاہریتو تبدیل کورے',
 'revdel-restore-deleted' => 'حذف شدہ رویژنز',
 'revdel-restore-visible' => 'ویزیبل رویژنز',
@@ -647,22 +672,25 @@ MySQL جوابِ خطاء پرائے "$3: $4"',
 'powersearch-ns'                   => 'جائے ناما تلاش:',
 'powersearch-redir'                => 'فہرستِ رجوع مکرر',
 'powersearch-field'                => 'تلاش برائے',
+'powersearch-toggleall'            => 'سف',
 
 # Preferences page
-'preferences'             => 'ترجیحات',
-'mypreferences'           => 'مہ ترجیہات',
-'youremail'               => 'بشلی کغاز',
-'username'                => 'ممبارو نم',
-'uid'                     => 'ممبارو لمبار:',
-'prefs-memberingroups'    => '{{PLURAL:$1|گروہ|گروہاں}} رُکن:',
-'yourrealname'            => '* اصلی نم',
-'yournick'                => 'دسخط',
-'badsig'                  => "ناقص خام دسخط.
+'preferences'                  => 'ترجیحات',
+'mypreferences'                => 'مہ ترجیہات',
+'skin-preview'                 => 'نمائش',
+'youremail'                    => 'بشلی کغاز',
+'username'                     => 'ممبارو نم',
+'uid'                          => 'ممبارو لمبار:',
+'prefs-memberingroups'         => '{{PLURAL:$1|گروہ|گروہاں}} رُکن:',
+'prefs-registration-date-time' => '$1',
+'yourrealname'                 => '* اصلی نم',
+'yournick'                     => 'دسخط',
+'badsig'                       => "ناقص خام دسخط.
 HTML tags لوڑے.',",
-'badsiglength'            => 'تہ دسخط کافی درونگار شیر.
+'badsiglength'                 => 'تہ دسخط کافی درونگار شیر.
 ھیہ $1 {{PLURAL:$1|حرف|حروفاری}} زیات نو بیلک.',
-'prefs-help-email'        => 'برقی ڈاکو پتہ اختیاری شیر لیکن ھیہ ھتے وختہ مفید ثابت بوی کیاوتکی تو تان پاسورڈو کی روخڅیتاو',
-'prefs-help-email-others' => 'تو ھمو دی منتخب کوریکو بوس  کہ خور صارفین تہ تبادلۂ خیالو صفحا ای ربطو ذریعا تتے بشلی کغاز یعنی برقی ڈاک انځینی.
+'prefs-help-email'             => 'برقی ڈاکو پتہ اختیاری شیر لیکن ھیہ ھتے وختہ مفید ثابت بوی کیاوتکی تو تان پاسورڈو کی روخڅیتاو',
+'prefs-help-email-others'      => 'تو ھمو دی منتخب کوریکو بوس  کہ خور صارفین تہ تبادلۂ خیالو صفحا ای ربطو ذریعا تتے بشلی کغاز یعنی برقی ڈاک انځینی.
 کیاوتکہ دیگر صارفین تہ سوم رابطہ  کورونیان تھے تہ برقی ڈاکو پتہ افشا کورونو نو بوی',
 
 # Groups
@@ -683,42 +711,44 @@ HTML tags لوڑے.',",
 'action-edit' => 'ھیہ صفحا ایڈیٹنگ کورے',
 
 # Recent changes
-'nchanges'                       => '$1 {{PLURAL:$1|تبدیلی|تبدیلیاں}}',
-'recentchanges'                  => 'حالیہ تبدیلی',
-'recentchanges-legend'           => 'حالیہ تبدیلیان اختیارات',
-'recentchangestext'              => 'ھیہ صفحا کھوار ویکیپیڈیا باک تازہ تریں تبدیلیان مشاہدہ کورے',
-'recentchanges-feed-description' => 'کھوارا ترجمہ',
-'recentchanges-label-newpage'    => 'ھیہ ترمیم نوغ صفحہ تخلیق آریر',
-'recentchanges-label-minor'      => 'ھیہ ای معمولی ترمیم شیر',
-'recentchanges-label-bot'        => 'ھیہ ایڈیٹو خود کار بوٹو زریعا انجام دیونو ہوی',
-'rcnote'                         => "درج ذیل گزشتہ {{PLURAL:$2|بس|'''$2''' انوسا}} باک {{PLURAL:$1|'''ای''' تبدیلی شیر|آخری '''$1''' تبدیلی شینی}}، $5، $4.",
-'rcnotefrom'                     => "ھیہ موڑا '''$2''' کورونو بیرو تبدیلیان تفصیلات شینی ('''$1''' تبدیلیان پشینو بونیان)۔",
-'rclistfrom'                     => '$1 نوغ تبدیلیاں پشیک شروع کورے',
-'rcshowhideminor'                => ' معمولی ترامیم $1',
-'rcshowhidebots'                 => 'خودکار صارف $1',
-'rcshowhideliu'                  => 'داخل بیرو صارف $1',
-'rcshowhideanons'                => 'گمنام صارف $1',
-'rcshowhidepatr'                 => '$1 لوڑونو بیرو لکھائی',
-'rcshowhidemine'                 => 'ذاتی ترامیم $1',
-'rclinks'                        => 'آخری $2 آنوسو بیرو $1 تبدیلیان مشاہدہ کورے<br />$3',
-'diff'                           => 'فرق',
-'hist'                           => 'تاریخچہ',
-'hide'                           => 'مو پشاوے',
-'show'                           => 'ویریغ کورے',
-'minoreditletter'                => 'م',
-'newpageletter'                  => 'نوغ',
-'boteditletter'                  => 'خودکار',
-'rc-enhanced-expand'             => 'تفصیلاتن پشاوے (JavaScript ضرورت بوی)',
-'rc-enhanced-hide'               => 'تفصیلاتن کھوشتاوے',
+'nchanges'                        => '$1 {{PLURAL:$1|تبدیلی|تبدیلیاں}}',
+'recentchanges'                   => 'حالیہ تبدیلی',
+'recentchanges-legend'            => 'حالیہ تبدیلیان اختیارات',
+'recentchangestext'               => 'ھیہ صفحا کھوار ویکیپیڈیا باک تازہ تریں تبدیلیان مشاہدہ کورے',
+'recentchanges-feed-description'  => 'کھوارا ترجمہ',
+'recentchanges-label-newpage'     => 'ھیہ ترمیم نوغ صفحہ تخلیق آریر',
+'recentchanges-label-minor'       => 'ھیہ ای معمولی ترمیم شیر',
+'recentchanges-label-bot'         => 'ھیہ ایڈیٹو خود کار بوٹو زریعا انجام دیونو ہوی',
+'recentchanges-label-unpatrolled' => 'ھیہ ترمیمو ھمونیہ پت مراجعت(Patrolled) کورونو نو بیتی شیر',
+'rcnote'                          => "درج ذیل گزشتہ {{PLURAL:$2|بس|'''$2''' انوسا}} باک {{PLURAL:$1|'''ای''' تبدیلی شیر|آخری '''$1''' تبدیلی شینی}}، $5، $4.",
+'rcnotefrom'                      => "ھیہ موڑا '''$2''' کورونو بیرو تبدیلیان تفصیلات شینی ('''$1''' تبدیلیان پشینو بونیان)۔",
+'rclistfrom'                      => '$1 نوغ تبدیلیاں پشیک شروع کورے',
+'rcshowhideminor'                 => ' معمولی ترامیم $1',
+'rcshowhidebots'                  => 'خودکار صارف $1',
+'rcshowhideliu'                   => 'داخل بیرو صارف $1',
+'rcshowhideanons'                 => 'گمنام صارف $1',
+'rcshowhidepatr'                  => '$1 لوڑونو بیرو لکھائی',
+'rcshowhidemine'                  => 'ذاتی ترامیم $1',
+'rclinks'                         => 'آخری $2 آنوسو بیرو $1 تبدیلیان مشاہدہ کورے<br />$3',
+'diff'                            => 'فرق',
+'hist'                            => 'تاریخچہ',
+'hide'                            => 'مو پشاوے',
+'show'                            => 'ویریغ کورے',
+'minoreditletter'                 => 'م',
+'newpageletter'                   => 'نوغ',
+'boteditletter'                   => 'خودکار',
+'rc-enhanced-expand'              => 'تفصیلاتن پشاوے (JavaScript ضرورت بوی)',
+'rc-enhanced-hide'                => 'تفصیلاتن کھوشتاوے',
 
 # Recent changes linked
-'recentchangeslinked'         => 'متعلقہ تبدیلی',
-'recentchangeslinked-toolbox' => 'موقعی تبدیلی',
-'recentchangeslinked-title'   => 'متعلقہ تبدیلی "$1"',
-'recentchangeslinked-summary' => "ھیہ ھتے تبدیلیان لسٹ شیر کہ ھیتان پھوک مدا پروشٹی ساوزینو بیتی شینی وا ھے صفحان سوم جستہ خور کیہ صفحہ چوکی شینی یا کیہ خاص زمرہ جاتو ممبرانن سوم چوکی شینی<br />
+'recentchangeslinked'          => 'متعلقہ تبدیلی',
+'recentchangeslinked-toolbox'  => 'موقعی تبدیلی',
+'recentchangeslinked-title'    => 'متعلقہ تبدیلی "$1"',
+'recentchangeslinked-noresult' => 'ھمی صفحا موجودہ وختہ کیہ تبدیلی نیکی۔',
+'recentchangeslinked-summary'  => "ھیہ ھتے تبدیلیان لسٹ شیر کہ ھیتان پھوک مدا پروشٹی ساوزینو بیتی شینی وا ھے صفحان سوم جستہ خور کیہ صفحہ چوکی شینی یا کیہ خاص زمرہ جاتو ممبرانن سوم چوکی شینی<br />
 ساوزیرو [[Special:Watchlist|موڑا صفحہ]] '''بولڈ''' شینی",
-'recentchangeslinked-page'    => 'کھوار ویکیپیڈیو منصوبو صفحو لوڑے',
-'recentchangeslinked-to'      => 'کھلولاو بیرو صفحو بجایا ھمو سوم چوکیرو صفحو نوغ تبدیلیان پشاوے',
+'recentchangeslinked-page'     => 'کھوار ویکیپیڈیو منصوبو صفحو لوڑے',
+'recentchangeslinked-to'       => 'کھولاو بیرو صفحو بجایا ھمو سوم چوکیرو صفحو نوغ تبدیلیان پشاوے',
 
 # Upload
 'upload'        => 'فائل انځاوے',
@@ -745,6 +775,8 @@ HTML tags لوڑے.',",
 'imagelinks'                => 'مسلو روابط',
 'linkstoimage'              => 'ھیہ مسلو سوم درج ذیل {{PLURAL:$1|صفحہ مربوط شیر|$1 صفحات مربوط شینی}}',
 'nolinkstoimage'            => 'ھیہ کھوار ویکیپیڈیا ھش کیہ صفحات نیکی کہ ھتیت ھیہ مسل (فائلو) متعلقہ شینی',
+'sharedupload-desc-here'    => 'ھیہ فائل $1 موژاری شیر وا ھیہ خور پرجیکٹہ استعمال بویان۔
+مزید معلومات ھمو [$2 فائل مشقولگی صفحہا]  دیونو بیتی شیر',
 'uploadnewversion-linktext' => 'ھیہ مسلو نوغ ورژنو اپلوڈ کورے',
 
 # Random page
@@ -753,6 +785,8 @@ HTML tags لوڑے.',",
 # Statistics
 'statistics' => 'اعداد و شمار',
 
+'disambiguationspage' => 'سانچہ: ڈسایمبگ',
+
 # Miscellaneous special pages
 'nbytes'               => '$1 {{PLURAL:$1|بایٹ|بایٹس}}',
 'nmembers'             => '$1 {{PLURAL:$1|ممبار|ممباران}}',
@@ -825,7 +859,7 @@ HTML tags لوڑے.',",
 # Special:ListGroupRights
 'listgrouprights-members' => 'ممبارانن فھرست',
 
-# E-mail user
+# Email user
 'emailuser' => 'ممباروت بشلی کغاز انڅاوے',
 
 # Watchlist
@@ -928,6 +962,7 @@ HTML tags لوڑے.',",
 
 # Block/unblock
 'blockip'                  => 'داخلہ ممنوع براۓ صارف',
+'ipboptions'               => '2 گھنٹہ:2 hours,1 آنوس:1 day,3 بس:3 days,1 ہفتہ:1 week,2 ہفتہ:2 weeks,1 مس:1 month,3 مس:3 months,6 مس:6 months,1 سال:1 year,لامحدود:infinite',
 'ipblocklist'              => 'داخلہ ممنوع براۓ صارف',
 'blocklink'                => 'پاوبندی لیگاوے',
 'unblocklink'              => 'پاوبندی ختم',
@@ -1059,6 +1094,8 @@ HTML tags لوڑے.',",
 * gpslongitude
 * gpsaltitude',
 
+'exif-dc-date' => 'تاریخ',
+
 # External editor support
 'edit-externally'      => 'ھیہ مسلو ایڈیٹ کورے',
 'edit-externally-help' => '(See the [//www.mediawiki.org/wiki/Manual:External_editors setup instructions] for more information)
@@ -1069,6 +1106,9 @@ HTML tags لوڑے.',",
 'namespacesall' => 'تھمامو',
 'monthsall'     => 'سف',
 
+# action=purge
+'confirm_purge_button' => 'OK/ٹھیک شیر',
+
 # Table pager
 'table_pager_first' => 'آویلو صفحہ',
 
@@ -1077,10 +1117,35 @@ HTML tags لوڑے.',",
 'watchlisttools-edit' => 'لوڑے یا واچ لسٹہ ترمیم کورے',
 'watchlisttools-raw'  => 'نوغ واچ لسٹان ایڈیٹ کورے',
 
+# Core parser functions
+'duplicate-defaultsort' => '\'\'\'خبردار:\'\'\' ڈیفالٹ تاڑٰ(نغڑی) "$2" پروشٹیو ڈیفالٹ تاڑا "$1" لیگی شیر۔',
+
+# Special:FilePath
+'filepath-page'   => 'فایل',
+'filepath-submit' => 'Go/بوغے',
+
 # Special:SpecialPages
 'specialpages' => 'اسپیشل صفحہ',
 
+# External image whitelist
+'external_image_whitelist' => ' #ھیہ لاینو ھموش تان شیکو لاکے کیچہ کہ ھیہ شیر<pre>
+#موڑا ریگولر لوان دیور((صرف ھتیتان کیاغ ھمیتان موژی شینی //) //) 
+#بیریو ھوٹوان آر ایلان سوم ھمیتان میچ کورنو بوی
+# کیاغ کہ میچ ھونی ھیتان ھوٹوان سوم پشینو بوی بصورت دیگر ھیتان لنک کیاغ کی شینی ھتیتان پشینو بوی
+#لاین کیاغ کی شروع بویان  # کومنٹ جوشونو بوی۔
+#ھیہ کیس سینسیٹو شیر۔
+
+#لینو سورا ریجیکس فریگمنٹو لاکھے. ھیہ لاینو ھموش تان شیکو لاکے کیچہ کہ ھیہ شیر۔</pre>',
+
 # Special:Tags
-'tag-filter' => '[[Special:Tags|Tag]] filter:',
+'tag-filter'        => '[[Special:Tags|Tag]] filter:',
+'tag-filter-submit' => 'فلٹر',
+'tags-title'        => 'Tags/ٹیگز',
+
+# Special:ComparePages
+'compare-page1' => 'صفحہ 1',
+
+# Feedback
+'feedback-message' => 'پیغام',
 
 );
