@@ -7,6 +7,7 @@
  * @ingroup Language
  * @file
  *
+ * @author Erdemaslancan
  * @author Mirzali
  */
 
@@ -14,63 +15,63 @@ $fallback = 'tr';
 
 $messages = array(
 # User preference toggles
-'tog-underline'               => 'Bınê girey de xete bonce:',
+'tog-underline'               => 'Bınê girey de xete bıonce:',
 'tog-highlightbroken'         => 'Gireunê thalu {a href="" class="new"}nia{/a} (alternatif: nia{a
 href="" class="internal"}?{/a}) basne.',
 'tog-justify'                 => 'Paragrafu ayar ke',
-'tog-hideminor'               => 'Vurnaisunê senıku pela vurnaisunê peyênu de wedare',
-'tog-hidepatrolled'           => 'Vurnaisunê qontrolkerdu pela vurnaisê peyêni de wedare',
+'tog-hideminor'               => 'Vurnayisunê senıku pela vurnayisunê peyênu de wedare',
+'tog-hidepatrolled'           => 'Vurnayisunê qontrolkerdu pela vurnayisê peyêni de wedare',
 'tog-newpageshidepatrolled'   => 'Pelunê qontrolkerdu lista pelunê newu de wedare',
-'tog-extendwatchlist'         => 'Lista şêrkerdene hira bıke ke vurnaişi pêro basê, teyna tewr peyêni nê',
-'tog-usenewrc'                => 'Vurnaisunê peyênunê hirakerdiu bıgurene (JavaScript lazımo)',
+'tog-extendwatchlist'         => 'Lista şêrkerdene hira bıke ke vurnayişi pêro bıasê, teyna tewr peyêni nê',
+'tog-usenewrc'                => 'Pele be vurnayisunê grube de vurnayisê peyêni u lista şêrkerdişi (JavaScript lazımo)',
 'tog-numberheadings'          => 'Sernustu be ho numra cı sane',
-'tog-showtoolbar'             => 'Gozagunê hacetunê vurnaişi basne (JavaScript lazımo)',
-'tog-editondblclick'          => 'Pê dı rey teqnaene pele sero bıguriye (JavaScript lazımo)',
-'tog-editsection'             => 'Vurnaena qısımi ebe gireunê [bıvurne] ra feal ke',
-'tog-editsectiononrightclick' => 'Qısımu be teqnaena serrêze ra ebe gozaga raste bıvurne (JavaScript lazımo)',
-'tog-showtoc'                 => 'Tabloê tedeesteu basne (de pelunê be hirê sernustu ra jêdêri de)',
-'tog-rememberpassword'        => 'Parola mı nê cıcêraoği de bia ho viri (serba tewr jêde $1 {{PLURAL:$1|roze|rozu}}).',
-'tog-watchcreations'          => 'Pelê ke mı afernê, lista mına şêrkerdişi ke',
-'tog-watchdefault'            => 'Pelê ke mı vurnê, lista mına şêrkerdişi ke',
-'tog-watchmoves'              => 'Pelê ke mı kırısnê, lista mına şêrkerdişi ke',
-'tog-watchdeletion'           => 'Pelê ke mı esterıtê, lista mına şêrkerdişi ke',
-'tog-minordefault'            => 'Vurnaisunê ho pêrune ‘vurnaiso qızkek’ nisan bıde',
-'tog-previewontop'            => 'Verqayti pela nustene ser de basne',
-'tog-previewonfirst'          => 'Vurnaiso verên de verqayti tım basne',
-'tog-nocache'                 => 'Pelunê cıcêraoği mia ho viri',
-'tog-enotifwatchlistpages'    => 'Pela ke ez şêr kenune eke vurnê mı rê e-poste bırusne',
-'tog-enotifusertalkpages'     => 'Pela mına hurênaişi ke vurnê mı rê e-poste bırusne',
-'tog-enotifminoredits'        => 'Vurnaisunê qızkeku de ki mı rê e-poste bırusne',
-'tog-enotifrevealaddr'        => 'Adresa e-postê mı postê xeberu de basne',
-'tog-shownumberswatching'     => 'Amorê karberunê şêrkerdoğu basne',
-'tog-oldsig'                  => 'Verqaytê imza mewcude:',
-'tog-fancysig'                => 'İmza rê mamelê wikimeqaley bıke (bê gireo otomatik)',
-'tog-externaleditor'          => 'Editorê teberi standart bıgurene (teyna serba ekspertuno, komputerê sıma de ayarê xısuşiy lazımê. [//www.mediawiki.org/wiki/Manual:External_editors Melumato jêdêr.])',
+'tog-showtoolbar'             => 'Gozagunê hacetunê vurnayişi bıasne (JavaScript lazımo)',
+'tog-editondblclick'          => 'Pê dı rey teqnayene pele sero bıguriye (JavaScript lazımo)',
+'tog-editsection'             => 'Vurnayena qısımi ebe gireyunê [bıvurne] ra feal ke',
+'tog-editsectiononrightclick' => 'Qısımu be teqnayena serrêze ra ebe gozaga raste bıvurne (JavaScript lazımo)',
+'tog-showtoc'                 => 'Tablowê tedeestewu bıasne (de pelunê be hirê sernustu ra jêdêri de)',
+'tog-rememberpassword'        => 'Parola mı nê cıcêrawoği de bia ho viri (serba tewr jêde $1 {{PLURAL:$1|roze|rozu}}).',
+'tog-watchcreations'          => 'Pelê ke mı afernê u dosyê ke mı bar kerdê lista mına şêrkerdişi ke',
+'tog-watchdefault'            => 'Pel u dosyê ke mı vurnê lista mına şêrkerdişi ke',
+'tog-watchmoves'              => 'Pel u dosyê ke mı kırısnê lista mına şêrkerdişi ke',
+'tog-watchdeletion'           => 'Pel u dosyê ke mı esterıtê, lista mına şêrkerdişi ke',
+'tog-minordefault'            => 'Vurnayisunê ho pêrune ‘vurnayiso qızkek’ nisan bıde',
+'tog-previewontop'            => 'Verqayti pela nustene ser de bıasne',
+'tog-previewonfirst'          => 'Vurnayiso verên de verqayti tım bıasne',
+'tog-nocache'                 => 'Pelunê cıfeteliyawoği mia ho viri',
+'tog-enotifwatchlistpages'    => 'Zû pele ya ki dosyawa ke lista mına şêrkerdişi de vurnê mı rê e-poste bırusne',
+'tog-enotifusertalkpages'     => 'Pela mına hurênayişi ke vurnê mı rê e-poste bırusne',
+'tog-enotifminoredits'        => 'Vurnayisunê qızkekunê pelun u dosyu de ki mı rê e-poste bırusne',
+'tog-enotifrevealaddr'        => 'Adresa e-postê mı postê xeberu de bıasne',
+'tog-shownumberswatching'     => 'Amorê karberunê şêrkerdoğu bıasne',
+'tog-oldsig'                  => 'İmza mewcude:',
+'tog-fancysig'                => 'İmza rê mamelê wikimeqaley bıke (bê girewo otomatik)',
+'tog-externaleditor'          => 'Editorê teberi standart bıgurene (teyna serba ekspertuno, komputerê sıma de ayarê xusışiy lazımê. [//www.mediawiki.org/wiki/Manual:External_editors Melumato jêdêr.])',
 'tog-externaldiff'            => 'Têversanaene pê programê teberi vıraze (teyna serba ekspertuno, komputerê sıma de ayarê xısuşiy lazımê. [//www.mediawiki.org/wiki/Manual:External_editors Melumato jêdêr.])',
 'tog-showjumplinks'           => 'Girê "so"y feal ke',
-'tog-uselivepreview'          => 'Verqayto cınde bıgurene (JavaScript) (hona cerrebnaene dero)',
+'tog-uselivepreview'          => 'Verqayto cande bıgurene (JavaScript) (hona cerrebnayene dero)',
 'tog-forceeditsummary'        => 'Mı ke xulasa kerde cı vira, hay be mı ser de',
-'tog-watchlisthideown'        => 'Vurnaisunê mı lista mına şêrkerdişi de wedare',
-'tog-watchlisthidebots'       => 'Vurnaisunê boti lista mına şêrkerdişi de wedare',
-'tog-watchlisthideminor'      => 'Vurnaisunê qızkeku lista mına şêrkerdişi de wedare',
-'tog-watchlisthideliu'        => 'Lista şêrkerdişi ra vurnaisunê karberunê cıkotu wedare',
-'tog-watchlisthideanons'      => 'Lista şêrkerdişi ra vurnaisunê karberunê anonimu wedare',
-'tog-watchlisthidepatrolled'  => 'Lista şêrkerdişi ra vurnaisunê qontrolkerdu wedare',
+'tog-watchlisthideown'        => 'Vurnayisunê mı lista mına şêrkerdişi de wedare',
+'tog-watchlisthidebots'       => 'Vurnayisunê boti lista mına şêrkerdişi de wedare',
+'tog-watchlisthideminor'      => 'Vurnayisunê qızkeku lista mına şêrkerdişi de wedare',
+'tog-watchlisthideliu'        => 'Lista şêrkerdişi ra vurnayisunê karberunê cıkotu wedare',
+'tog-watchlisthideanons'      => 'Lista şêrkerdişi ra vurnayisunê karberunê anonimu wedare',
+'tog-watchlisthidepatrolled'  => 'Lista şêrkerdişi ra vurnayisunê qontrolkerdu wedare',
 'tog-ccmeonemails'            => 'E-postunê ke ez karberunê binu rê rusnenu, mı rê kopya inu bırusne',
-'tog-diffonly'                => 'Qıyasê versiyonu de tek ferqu basne, pela butıne nê',
-'tog-showhiddencats'          => 'Kategoriunê dızdêni basne',
+'tog-diffonly'                => 'Qıyasê versiyonu de tek ferqu bıasne, pela butıne nê',
+'tog-showhiddencats'          => 'Kategoriyunê dızdêni bıasne',
 'tog-norollbackdiff'          => 'Peyserardene ra dıme ferqi caverde',
 
 'underline-always'  => 'Tım',
 'underline-never'   => 'Qet',
-'underline-default' => 'Qerar cıcêraoği dest dero',
+'underline-default' => 'Cild ya ki cıfeteliyayoğo hesebiyaye',
 
 # Font style option in Special:Preferences
-'editfont-style'     => 'Warê vurnaena tipê nustey:',
-'editfont-default'   => 'Fereziya cıfeteliyaoği',
-'editfont-monospace' => 'Tipê nustê sabıtcaguretoği',
-'editfont-sansserif' => 'Tipê nustê Sans-serifi',
-'editfont-serif'     => 'Tipê nustê Serifi',
+'editfont-style'     => 'Warê vurnayena terzê nustey:',
+'editfont-default'   => 'Fereziya cıfeteliyawoği',
+'editfont-monospace' => 'Terzê nustê sabıtcaguretoği',
+'editfont-sansserif' => 'Babetê Sans-serifi',
+'editfont-serif'     => 'Babetê serifi',
 
 # Dates
 'sunday'        => 'Bazar',
@@ -83,7 +84,7 @@ href="" class="internal"}?{/a}) basne.',
 'sun'           => 'Baz',
 'mon'           => 'Dıs',
 'tue'           => 'Şês',
-'wed'           => 'Çar',
+'wed'           => 'Çrs',
 'thu'           => 'Pho',
 'fri'           => 'Yen',
 'sat'           => 'Sem',
@@ -148,7 +149,7 @@ href="" class="internal"}?{/a}) basne.',
 'about'         => 'Heqa',
 'article'       => 'Pela tedeesteyu',
 'newwindow'     => '(zerrê pençerê dê newey de beno ra)',
-'cancel'        => 'Texelnaene',
+'cancel'        => 'Bıtexelne',
 'moredotdotdot' => 'Jêde...',
 'mypage'        => 'Pela mı',
 'mytalk'        => 'Hurênayişê mı',
@@ -392,9 +393,9 @@ Kerem kerê, deqêna oncia bıcerrebnê.",
 'protectedpagetext'    => 'Na pele vurnaisu rê qapan biya.',
 'viewsourcetext'       => 'Sıma şikinê çımê na pele bıvênê u kopya kerê:',
 'protectedinterface'   => "Na pele ''software'' rê meqalunê caunê bırnau dana, u qapana ke suıstımalu rê engel bo.",
-'editinginterface'     => "'''Teme:''' Sıma hao jü pela ke serba ''software'' meqalunê caunê bırnau dana, vurnenê.
+'editinginterface'     => "Teme:''' Sıma hawo jü pela ke serba nustê meqalunê caunê bırnau dana, vurnenê.
 Vurnaisê na pele karberunê binu rê serpela karberi kena ke bıasno.
-Serba çarnais, yardımê [//translatewiki.net/wiki/Main_Page?setlang=kiu translatewiki.net]yê procê dos-kerdene rê diqet kerê.",
+Serba çarnaişi, yardımê [//translatewiki.net/wiki/Main_Page?setlang=kiu translatewiki.net]i ra procêdoskerdene rê diqet kerê.",
 'sqlhidden'            => '(Persê SQLi nımıteo)',
 'cascadeprotected'     => 'Na pele esterıtene ra sıtar biya, çıke na zerrê {{PLURAL:$1|pela ke|pelunê ke}} dera/derê be "cascading" opsiyoni kılit biya, $2 de bena ra.',
 'namespaceprotected'   => "'''$1''' ''namespace'' de desturê sıma be vurnaisê pelu çino.",
@@ -418,7 +419,7 @@ Vurnaena [[Special:Preferences|melumatanê {{SITENAME}}]] ho vira mekerê.',
 'yourname'                 => 'Namê karberi:',
 'yourpassword'             => 'Parola:',
 'yourpasswordagain'        => 'Parola tekrar ke:',
-'remembermypassword'       => 'Cıkotena mı na komputeri de bia ho viri ($1 {{PLURAL:$1|roze|rozu}} ra seba zu zêdêrêni)',
+'remembermypassword'       => 'Cıkotena mı na komputeri de bia ho viri (seba tewr jêde $1 {{PLURAL:$1|roze|rozu}})',
 'securelogin-stick-https'  => 'Cıkotene ra dıme HTTPS rê giredae bımane',
 'yourdomainname'           => 'Bandıra sıma:',
 'externaldberror'          => 'Cıfeteliyaisê naskerdene de ya xeta esta ya ki tebera vırastena hesabê sıma rê destur çino.',
@@ -435,6 +436,7 @@ Vurnaena [[Special:Preferences|melumatanê {{SITENAME}}]] ho vira mekerê.',
 'createaccount'            => 'Hesab vıraze',
 'gotaccount'               => "Hesabê sıma ke esto? '''$1'''.",
 'gotaccountlink'           => 'Cı kuye',
+'userlogin-resetlink'      => 'Melumatê cıkewtışi xo vira kerdê?',
 'createaccountmail'        => 'e-poste sera',
 'createaccountreason'      => 'Sebeb:',
 'badretype'                => 'Parola sıma nêvêrena.',
@@ -551,16 +553,16 @@ Kerem ke, tı ke wazena na pele vırazê/bıvurnê, qontrol ke.',
 Dosyunê ebe namê .css u .js'y de herfa hurdiye bıgurêne, mesela hurêndia {{ns:user}}:Foo/Vector.css'i de {{ns:user}}:Foo/vector.css bınuse.",
 'updated'                          => '(Bi rozane)',
 'note'                             => "'''Not:'''",
-'previewnote'                      => "'''Bıfıkıriye ke no teyna jü verqayto.'''
-Vurnaişê to hona qeyd nêbiyê!",
-'editing'                          => 'Tıya $1 vurnena',
+'previewnote'                      => "Teme! ena teyna verqeyda.'''
+Vurnayışê tu hama qeyd nıbiyo!",
+'editing'                          => '$1 Vurnayis',
 'editingsection'                   => 'Vurnaena $1 (qısım)',
 'editingcomment'                   => '$1 vurnino (qısımo newe)',
 'editconflict'                     => 'Têverabiyaena vurnaişi: $1',
 'yourtext'                         => 'Metnê to',
 'storedversion'                    => 'Metıno qeydkerde',
 'yourdiff'                         => 'Ferqi',
-'copyrightwarning'                 => "Diqet ke, iştırakê ke benê be pela {{SITENAME}}i, pêro bınê $2 de rakerde vêrenê (serba daêna melumati qaytê $1 ke).
+'copyrightwarning'                 => "Diqet ke, iştıraqê ke benê be pela {{SITENAME}}i, pêro bınê $2 de rakerde vêrenê (serba daêna melumati qaytê $1 ke).
 İştırakunê ho, eke nêwazena wa terefê binu ra bıvuriyê ya ki caunê binu ra vıla bê, o taw ita menuse.<br />
 Zobina ki ebe ita nustene ra sond wena ke nê iştıraki terefê to ra nuşiyê, ya çımê do rakerdey ra ya ki çımê do serbest ra kopya biyê.
 '''Gurêo ke ebe telifheqiye ra sevekiyo bê destur ita darde meke!'''",
@@ -571,18 +573,26 @@ Zobina ki ebe ita nustene ra sond wena ke nê iştıraki terefê to ra nuşiyê,
 'hiddencategories'                 => 'Na pele mensuba {{PLURAL:$1|1 kategoriya nımıtiya|$1 kategoriunê nımıtuna}}:',
 'permissionserrors'                => 'Xetê desturi',
 'permissionserrorstext-withaction' => 'Desturê to be $2 çino, serba {{PLURAL:$1|na sebebi|nê sebebu}} ra:',
+'recreate-moveddeleted-warn'       => "'''Hişyari: no pel o ke şıma vırazeni vere cû vırazyayo.'''
+
+Diqet bıkeri no vurnayişê şıma re gerek esto:",
+'moveddeleted-notice'              => 'Ma ena pele wederna.
+Qe referansi logê wedernayışi bın de mocnayiya.',
 'edit-conflict'                    => 'Têverabiyaena vurnaişi.',
 
 # Parser/template warnings
 'post-expand-template-inclusion-warning'  => "'''Teme''': Zerrekê şabloni zaf gırso.
 Taê şabloni ilawe nêbenê.",
 'post-expand-template-inclusion-category' => 'Pelê ke tede gırşênia şabloni serde sono',
+'post-expand-template-argument-warning'   => 'Hişyari: No pel de tewr tay yew şablono herayi esto.',
+'post-expand-template-argument-category'  => 'Pelê ke şablonê eyi qebul niye',
 
 # History pages
 'viewpagelogs'           => 'Qeydê ke na pele ra alaqedarê, inu bıasne',
 'currentrev'             => 'Çımraviarnaoğo rozane',
 'currentrev-asof'        => '$1 ra gore pele be halo nıkaên',
 'revisionasof'           => 'Halê roca $1ine',
+'revision-info'          => 'Tesdiq kerdışê roca $1ine be terefê $2',
 'previousrevision'       => '← Halo khanêr',
 'nextrevision'           => 'Tekrardiyaiso newêr →',
 'currentrevisionlink'    => 'Halo nıkaên',
@@ -632,7 +642,7 @@ Beno ke [{{fullurl:{{#Special:Log}}/delete|page={{FULLPAGENAMEE}}}} deletion log
 Sıma be idarekerênia ho ra şikinê hona [$1 nê ferqi bıvênê], eke wazenê dewam kerê.",
 'rev-delundel'                => 'bıasne/wedare',
 'rev-showdeleted'             => 'bıasne',
-'revisiondelete'              => 'Çımraviarnaisu bıestere/peyser bia',
+'revisiondelete'              => 'Çımraviarnaisu bestere/peyser bia',
 'revdelete-nooldid-title'     => 'Çımraviarnaena waştiye nêvêrena',
 'revdelete-nooldid-text'      => 'Sıma vırastena nê fonksiyoni rê ya jü çımraviarnaena waştiye diyar nêkerdo, çımraviarnaena diyarkerdiye çına, ya ki sıma wazenê ke çımraviarnaena nıkaêne bınımnê.',
 'revdelete-nologtype-title'   => 'Qet qeydê cı nêdiya',
@@ -679,7 +689,7 @@ Eke şertê ilawekerdey ke niyê ro, idarekerê bini {{SITENAME}} de nêşikinê
 'revertmerge' => 'Cia ke',
 
 # Diffs
-'history-title'           => 'Viartê pelga "$1"ine',
+'history-title'           => 'Rewizyonê $1:',
 'difference'              => 'Ferqê wertê vurnaisu',
 'lineno'                  => 'Rêza $1i:',
 'compareselectedversions' => 'Varyantunê weçinıtun têver sane',
@@ -700,6 +710,7 @@ Eke şertê ilawekerdey ke niyê ro, idarekerê bini {{SITENAME}} de nêşikinê
 'nextn-title'                      => 'Peyên $1 {{PLURAL:$1|netice|neticey}}',
 'shown-title'                      => 'Zu pele rê $1 {{PLURAL:$1|netice|neticu}} basne',
 'viewprevnext'                     => 'Bıvêne ($1 {{int:pipe-separator}} $2) ($3)',
+'searchmenu-exists'                => "''Ena 'Wikipediya de ser \"[[:\$1]]\" yew pel esto'''",
 'searchmenu-new'                   => "'''Nê wiki de pela \"[[:\$1]]\" baferne!'''",
 'searchhelp-url'                   => 'Help:Tedeestey',
 'searchprofile-articles'           => 'Pelê tedeesteu',
@@ -712,7 +723,7 @@ Eke şertê ilawekerdey ke niyê ro, idarekerê bini {{SITENAME}} de nêşikinê
 'searchprofile-images-tooltip'     => 'Dosya bıfeteliye',
 'searchprofile-everything-tooltip' => 'Zerreki pêro sae ke (pelunê hurênaişi daxıl)',
 'searchprofile-advanced-tooltip'   => 'Caunê namunê xısusiu de cıfeteliye',
-'search-result-size'               => '$1 ({{PLURAL:$2|1 çekuye|$2 çekuy}})',
+'search-result-size'               => '$1 ({{PLURAL:$2|1 kelime|$2 kelimey}})',
 'search-result-category-size'      => '{{PLURAL:$1|1 eza|$1 ezey}} ({{PLURAL:$2|1 kategoriya bınêne|$2 kategoriyê bınêni}}, {{PLURAL:$3|1 dosya|$3 dosyey}})',
 'search-redirect'                  => '(hetêcıraberdene $1)',
 'search-section'                   => '(qısımo $1)',
@@ -763,7 +774,7 @@ Diqet kerê, beno ke tedeestê {{SITENAME}} uza endi rozane niyê.",
 'prefs-datetime'            => 'Tarix u zeman',
 'prefs-personal'            => 'Dosya karberi',
 'prefs-rc'                  => 'Vurnaisê peyêni',
-'prefs-watchlist'           => 'Lista şêr-kerdişi',
+'prefs-watchlist'           => 'Lista şêrkerdene',
 'prefs-watchlist-days'      => 'Rozê ke lista şêr-kerdişi de asenê:',
 'prefs-watchlist-edits'     => 'Miqdarê tewr jêdêr vurnaisuno ke lista şêr-kerdişia hirakerdiye derê:',
 'prefs-misc'                => 'Ğelet',
@@ -820,6 +831,9 @@ Gunê $1 {{PLURAL:$1|herfe|herfun}} ra senık bo.',
 'email'                     => 'E-poste',
 'prefs-help-realname'       => 'Namo rastıkên serbesto.
 Sıma ke ney bıgurenê, karê sıma de no namdarêni dano.',
+'prefs-help-email'          => 'Dayışê adresa e-postey keyfiyo, labelê seba eyarê parola lazıma, wexto ke şıma naye xo vira kerê.',
+'prefs-help-email-others'   => 'Şıma şenê weçinê ke ê bini be yew gırey pela şımaya karberi ya zi pela werênayışi sera şıma de ebe e-poste irtıbat kewê.
+Kaberê bini ke şıma de kewti irtıbat, adresa e-postey şıma eşkera nêbena.',
 'prefs-help-email-required' => 'Adresa emaili lazıma.',
 'prefs-signature'           => 'İmza',
 'prefs-diffs'               => 'Ferqi',
@@ -854,12 +868,12 @@ Sıma ke ney bıgurenê, karê sıma de no namdarêni dano.',
 'grouppage-bureaucrat' => '{{ns:project}}:Burokrati',
 
 # Rights
-'right-read'     => 'Pelu bıwane',
+'right-read'     => 'Pelan bıwane',
 'right-edit'     => 'Pelu bıvurne',
 'right-move'     => 'Pelu bere',
 'right-movefile' => 'Dosyu bere',
 'right-upload'   => 'Dosyu bar ke',
-'right-delete'   => 'Pelu bıestere',
+'right-delete'   => 'Pelu bestere',
 'right-undelete' => 'Esterıtena na pele peyser bıcê',
 
 # User rights log
@@ -877,28 +891,29 @@ Sıma ke ney bıgurenê, karê sıma de no namdarêni dano.',
 'action-move'          => 'na pele bere',
 'action-movefile'      => 'na dosya bere',
 'action-upload'        => 'na dosya bar ke',
-'action-delete'        => 'na pele bıestere',
+'action-delete'        => 'na pele bestere',
 'action-undelete'      => 'na pele meestere',
 
 # Recent changes
 'nchanges'                        => '$1 {{PLURAL:$1|tedil|tedili}}',
 'recentchanges'                   => 'Vurnaisê peyêni',
 'recentchanges-legend'            => 'Alternatifê vurnaisunê peyênu',
-'recentchangestext'               => 'Na weiyekerdena wiki de vurnaisê tewrpeyêne ke biyê ine teqib ke.',
+'recentchangestext'               => 'Vurnaisê çulpeyênê ke na pela wiki de biyê, ine teqib ke.',
 'recentchanges-feed-description'  => 'Na weiyekerdena wiki de vurnaisê tewrpeyêne ke biyê ine teqib ke.',
 'recentchanges-label-newpage'     => 'Nê vurnaişi pelê da newiye afernê.',
 'recentchanges-label-minor'       => 'No zu vurnaiso qıckeko',
 'recentchanges-label-bot'         => 'No vurnais terefê zu boti ra bi',
 'recentchanges-label-unpatrolled' => 'No vurnais hona çım ra ranêvêrdo',
 'rcnote'                          => "Cêr {{PLURAL:$1|'''1''' vurnaiso peyên|'''$1''' vurnaisê peyêni}} be {{PLURAL:$2|roza peyêne|'''$2''' rozunê peyênunê}} $5, $4 ra estê.",
+'rcnotefrom'                      => "Cêr de vurnayîşê esto ke '''$2''' ra raver  (heta '''$1''' mucnayiyo).",
 'rclistfrom'                      => '$1 ra hata nıka vurnaisunê newu bıasne',
 'rcshowhideminor'                 => '$1 vurnaisê qızkeki',
-'rcshowhidebots'                  => 'botê $1i',
-'rcshowhideliu'                   => '$1 karberê qeydbiyaey',
+'rcshowhidebots'                  => 'Botu $1',
+'rcshowhideliu'                   => 'Karberunê qeydbiyayu $1',
 'rcshowhideanons'                 => '$1 karberê anonimi',
 'rcshowhidepatr'                  => 'Vurnayışê cıyê vênıtey $1',
-'rcshowhidemine'                  => '$1 vurnaisê mı',
-'rclinks'                         => '$1 vurnaisunê peyênunê $2 rozunê<br />$3 peyênun bıasne',
+'rcshowhidemine'                  => 'Vurnayisanê mı $1',
+'rclinks'                         => 'Peyniya $2 rozu de $1 vurnayisu bıasne <br />$3',
 'diff'                            => 'ferq',
 'hist'                            => 'ver',
 'hide'                            => 'Bınımne',
@@ -910,13 +925,14 @@ Sıma ke ney bıgurenê, karê sıma de no namdarêni dano.',
 'rc-enhanced-hide'                => 'Tefsilatu bınımne',
 
 # Recent changes linked
-'recentchangeslinked'         => 'Ney sero vurnaene',
-'recentchangeslinked-toolbox' => 'Ney sero vurnaene',
-'recentchangeslinked-title'   => 'Heqa "$1"i de vurnais',
-'recentchangeslinked-summary' => "Lista cêrêne, pela bêlikerdiye rê (ya ki karberunê kategoriya bêlikerdiye rê) pelunê girêdaoğu de lista de vurnaisê peyênuna.
+'recentchangeslinked'          => 'Ney sero vurnayene',
+'recentchangeslinked-toolbox'  => 'Ney sero vurnayene',
+'recentchangeslinked-title'    => 'Heqa "$1"i de vurnais',
+'recentchangeslinked-noresult' => 'Pelanê ke link biye ey vurnayîşî çino.',
+'recentchangeslinked-summary'  => "Lista cêrêne, pela bêlikerdiye rê (ya ki karberunê kategoriya bêlikerdiye rê) pelunê girêdaoğu de lista de vurnaisê peyênuna.
 [[Special:Watchlist|Lista sımawa şêrkedişi de]] peli be nusto '''qolınd''' bêli kerdê.",
-'recentchangeslinked-page'    => 'Namê pele:',
-'recentchangeslinked-to'      => 'Hurêndia pela ke yena daene, vurnaisunê pelunê ke dae ra girêdaiyê, inu bıasne',
+'recentchangeslinked-page'     => 'Namê pele:',
+'recentchangeslinked-to'       => 'Hurêndia pela ke yena daene, vurnaisunê pelunê ke dae ra girêdaiyê, inu bıasne',
 
 # Upload
 'upload'                     => 'Dosya bar ke',
@@ -936,6 +952,7 @@ Sıma ke ney bıgurenê, karê sıma de no namdarêni dano.',
 'filestatus'                 => 'Halê heqa telifi:',
 'filesource'                 => 'Çıme:',
 'uploadedfiles'              => 'Dosyê barkerdey',
+'empty-file'                 => 'Dosya ke ti şawit veng biy.',
 'savefile'                   => 'Dosya qeyd ke',
 'uploadedimage'              => '"[[$1]]" bar bi',
 'upload-source'              => 'Dosya çımey',
@@ -943,7 +960,7 @@ Sıma ke ney bıgurenê, karê sıma de no namdarêni dano.',
 'watchthisupload'            => 'Na dosya de şêr ke',
 
 'license'        => 'Lisans:',
-'license-header' => 'Lisanskerdene',
+'license-header' => 'Lisansdais',
 
 # Special:ListFiles
 'imgfile'               => 'dosya',
@@ -960,8 +977,8 @@ Sıma ke ney bıgurenê, karê sıma de no namdarêni dano.',
 'file-anchor-link'          => 'Dosya',
 'filehist'                  => 'Tarixê dosya',
 'filehist-help'             => "Serba diyaena viartê dosya tarixê ke qısımê tarix/zeman'i derê inu bıteqne.",
-'filehist-deleteall'        => 'Pêrune bıestere',
-'filehist-deleteone'        => 'bıestere',
+'filehist-deleteall'        => 'Pêrune bestere',
+'filehist-deleteone'        => 'bestere',
 'filehist-revert'           => 'raçarne',
 'filehist-current'          => 'nıkaên',
 'filehist-datetime'         => 'Tarix/Dem',
@@ -975,6 +992,7 @@ Sıma ke ney bıgurenê, karê sıma de no namdarêni dano.',
 'filehist-missing'          => 'Dosya vindbiyaiya',
 'imagelinks'                => 'Gurenaisê dosya',
 'linkstoimage'              => 'Ano {{PLURAL:$1|girê pele|$1 girê pelu}} be na dosya:',
+'nolinkstoimage'            => 'Pelanê ser ena dosyayê link biyê çin o.',
 'sharedupload'              => 'Na dosya depoê $1 rawa u beno ke procunê binu de gurenina.',
 'sharedupload-desc-here'    => 'Beno ke depoê na dosya $1 ra be terefê procunê bınu ra gurenino.
 Cêr [$2 pela arezekerdena dosya de] arezekerdene asnina.',
@@ -988,10 +1006,10 @@ Cêr [$2 pela arezekerdena dosya de] arezekerdene asnina.',
 'filerevert-submit'  => 'Raçarne',
 
 # File deletion
-'filedelete'                  => 'Bıestere $1',
-'filedelete-legend'           => 'Dosya bıestere',
+'filedelete'                  => 'Bestere $1',
+'filedelete-legend'           => 'Dosya bestere',
 'filedelete-comment'          => 'Sebeb:',
-'filedelete-submit'           => 'Bıestere',
+'filedelete-submit'           => 'Bestere',
 'filedelete-otherreason'      => 'Sebebo bin/ilaweki:',
 'filedelete-reason-otherlist' => 'Sebebo bin',
 'filedelete-edit-reasonlist'  => 'Sebebunê esterıtene bıvurne',
@@ -1015,7 +1033,7 @@ Cêr [$2 pela arezekerdena dosya de] arezekerdene asnina.',
 'disambiguationspage' => 'Template:vuriyaisê maney',
 
 'brokenredirects-edit'   => 'bıvurne',
-'brokenredirects-delete' => 'bıestere',
+'brokenredirects-delete' => 'bestere',
 
 'withoutinterwiki-legend' => 'Verbend',
 'withoutinterwiki-submit' => 'Bıasne',
@@ -1032,7 +1050,7 @@ Cêr [$2 pela arezekerdena dosya de] arezekerdene asnina.',
 'shortpages'         => 'Pelê kılmi',
 'longpages'          => 'Pelê dergi',
 'listusers'          => 'Lista karberi',
-'usercreated'        => 'roca $1 de $2 de vıraciya',
+'usercreated'        => '$2 de $1 {{GENDER:$3|viraziya}}',
 'newpages'           => 'Pelê newey',
 'newpages-username'  => 'Namê karberi:',
 'ancientpages'       => 'Pelê khanêri',
@@ -1047,7 +1065,7 @@ Cêr [$2 pela arezekerdena dosya de] arezekerdene asnina.',
 'booksources-go'            => 'So',
 
 # Special:Log
-'specialloguserlabel'  => 'Karber:',
+'specialloguserlabel'  => 'Kerdoğ:',
 'speciallogtitlelabel' => 'Sernuste:',
 'log'                  => 'Qeydi',
 
@@ -1093,7 +1111,7 @@ Cêr [$2 pela arezekerdena dosya de] arezekerdene asnina.',
 'listgrouprights-addgroup-all'    => 'Heme grubu ilawe ke',
 'listgrouprights-removegroup-all' => 'Heme grubu wedare',
 
-# E-mail user
+# Email user
 'emailuser'    => 'Nê karberi rê e-poste bırusne',
 'emailpage'    => 'Karberi rê e-poste bırusne',
 'emailfrom'    => 'Kami ra:',
@@ -1103,8 +1121,8 @@ Cêr [$2 pela arezekerdena dosya de] arezekerdene asnina.',
 'emailsend'    => 'Bırusne',
 
 # Watchlist
-'watchlist'         => 'Pela mına şêrkerdene',
-'mywatchlist'       => 'Lista mına şêrkerdışi',
+'watchlist'         => 'Lista şêrkerdene',
+'mywatchlist'       => 'Lista şêrkerdışi',
 'watchlistfor2'     => 'Serba $1 ($2)',
 'addedwatchtext'    => "Pela \"[[:\$1]]\"i ilawe biye be [[Special:Watchlist|pela şêrkerdişi]].
 Nara dıme, vurnaisê na pele u pela hurênaisê dawa alaqedare ita bena lista, u pele [[Special:RecentChanges|lista vurnaisunê peyênu]] de '''qolınd''' asena ke cı ra asan weçiniyo.",
@@ -1123,8 +1141,8 @@ Nara dıme, vurnaisê na pele u pela hurênaisê dawa alaqedare ita bena lista,
 'changed' => 'vuriya',
 
 # Delete
-'deletepage'            => 'Pele bıestere',
-'delete-legend'         => 'Bıestere',
+'deletepage'            => 'Pele bestere',
+'delete-legend'         => 'Bestere',
 'confirmdeletetext'     => 'Tı hawo kena ke jü pele be tarixê dae pêro bıne ra bıesterê.
 Eke ferqê neticê na kerdene de bena u no kar be gorê [[{{MediaWiki:Policy-url}}|qeydunê esterıtene]] beno, wa gurêy tesdiq ke.',
 'actioncomplete'        => 'Kar bi temam',
@@ -1155,7 +1173,7 @@ Tı şikina sewiya sevekiyaena na pele bıvurnê, hema yê nae sevekiyaena qedem
 'protect-default'             => 'Destur bıde be karberu pêrune',
 'protect-fallback'            => 'Desturê "$1"i lazımo',
 'protect-level-autoconfirmed' => 'Karberunê newun u qeydnêbiyaoğu kilıt ke',
-'protect-level-sysop'         => 'Teyna idarekeri',
+'protect-level-sysop'         => 'Teyna idarekeru rê izıne bıde',
 'protect-summary-cascade'     => 'qedemein',
 'protect-expiring'            => 'tarixê qediyaene $1 (UTC)',
 'protect-expiring-local'      => '$1 de qedino',
@@ -1197,18 +1215,19 @@ Tı şikina sewiya sevekiyaena na pele bıvurnê, hema yê nae sevekiyaena qedem
 'undeletereset'             => 'Vaz be',
 'undeleteinvert'            => 'Weçinıtey ters bıçarne',
 'undeletecomment'           => 'Sebeb:',
+'undelete-header'           => 'Peleyê ke veror de besterneyayê êna bıvinê: [[Special:Log/delete|qeydê esterneya]].',
 'undelete-search-submit'    => 'Cıfeteliye',
 'undelete-show-file-submit' => 'Heya',
 
 # Namespace form on various pages
 'namespace'      => 'Caê namey:',
-'invert'         => 'Weçinıtu ra qêri bıasne',
+'invert'         => 'Weçinıtiso peyserki',
 'blanknamespace' => '(Ser)',
 
 # Contributions
 'contributions'       => 'İştırakê karberi',
 'contributions-title' => '$1 de iştırakê karberi',
-'mycontris'           => 'İştırakê mı',
+'mycontris'           => 'İştıraqi',
 'contribsub2'         => 'Serba $1 ($2)',
 'uctop'               => '(ser)',
 'month'               => 'Asme ra (u ravêr):',
@@ -1221,6 +1240,7 @@ Tı şikina sewiya sevekiyaena na pele bıvurnê, hema yê nae sevekiyaena qedem
 'sp-contributions-talk'     => 'hurênais',
 'sp-contributions-search'   => 'Ebe iştıraku cı feteliye',
 'sp-contributions-username' => 'IP ya ki karber:',
+'sp-contributions-toponly'  => 'Tenya rewizyonanê tewr peyniyan bimocne',
 'sp-contributions-submit'   => 'Cı feteliye',
 
 # What links here
@@ -1238,7 +1258,7 @@ Tı şikina sewiya sevekiyaena na pele bıvurnê, hema yê nae sevekiyaena qedem
 'whatlinkshere-hideredirs' => 'peyser sono $1',
 'whatlinkshere-hidetrans'  => 'İlawekerdê çaprazi $1',
 'whatlinkshere-hidelinks'  => '$1 girey',
-'whatlinkshere-hideimages' => 'girê resmu $1',
+'whatlinkshere-hideimages' => 'Girê dosya $1',
 'whatlinkshere-filters'    => 'Filtrey',
 
 # Block/unblock
@@ -1263,7 +1283,7 @@ Tı şikina sewiya sevekiyaena na pele bıvurnê, hema yê nae sevekiyaena qedem
 'blocklink'                       => 'kilıt ke',
 'unblocklink'                     => 'ra ke',
 'change-blocklink'                => 'mani bıvurne',
-'contribslink'                    => 'iştıraki',
+'contribslink'                    => 'iştıraqi',
 'emaillink'                       => 'e-poste bırusne',
 'autoblocker'                     => 'Sıma otomatikmen kılit biy, çıke adresa sımawa \'\'IP\'\'y terefê "[[User:$1|$1]]" gurenina.
 Sebebê kılit-biyaena $1\'i: "$2"o',
@@ -1351,7 +1371,7 @@ Kerem ke, qeydkerdene ra ver gozaga verqayti bıgurene.',
 Tı şikina çımunê dae bıvênê',
 'tooltip-ca-history'              => 'Versiyonê verênê na pele',
 'tooltip-ca-protect'              => 'Na pele bısevekne',
-'tooltip-ca-delete'               => 'Na pele bıestere',
+'tooltip-ca-delete'               => 'Na pele bestere',
 'tooltip-ca-move'                 => 'Namê na pele bıvurne',
 'tooltip-ca-watch'                => 'Na pele bıcê lista huya şêrkerdene',
 'tooltip-ca-unwatch'              => 'Na pele lista huya şêrkerdene ra wedare',
@@ -1389,7 +1409,7 @@ Tı şikina çımunê dae bıvênê',
 'tooltip-minoredit'               => 'Ney jê vurnaiso qıc isaret ke',
 'tooltip-save'                    => 'Vurnaisunê ho qeyd ke',
 'tooltip-preview'                 => 'Kerem ke, vurnaisunê ho qeyd-kerdene ra ravêr be verqayt bıasne!',
-'tooltip-diff'                    => 'Kamci vurnaişi ke to meqale de kerdê, naine bıasne.',
+'tooltip-diff'                    => 'Kamci vurnayışi ke to meqale de kerdê, ninan basne.',
 'tooltip-compareselectedversions' => 'Ferqunê wertê ni dı nımınunê weçinıtu bıvêne.',
 'tooltip-watch'                   => 'Na pele lista huya şêrkerdişi ser ke',
 'tooltip-recreate'                => 'Na pele esterıte bo ki, nae oncia bıaferne',
@@ -1508,6 +1528,9 @@ Eke dosya de peydêna vuriyais biyo ki, beno ke taê melumati gorê vurnaisê ne
 'watchlisttools-edit' => 'Lista şêrkerdene bıvêne u vıraze',
 'watchlisttools-raw'  => 'Lista şêrkerdena xame vıraze',
 
+# Core parser functions
+'duplicate-defaultsort' => '\'\'\'Teme:\'\'\' Tuşê default sort "$2" sero tuşê default sort "$1"î ra şino.',
+
 # Special:FilePath
 'filepath-page'   => 'Dosya:',
 'filepath-submit' => 'So',
@@ -1527,7 +1550,7 @@ Eke dosya de peydêna vuriyais biyo ki, beno ke taê melumati gorê vurnaisê ne
 'specialpages-group-media'       => 'Raporê medya u bar-kerdey',
 'specialpages-group-users'       => 'Karber u heqi',
 'specialpages-group-highuse'     => 'Pelê jêdêr gurenaey',
-'specialpages-group-pages'       => 'Lista pelun',
+'specialpages-group-pages'       => 'Listê pelun',
 'specialpages-group-pagetools'   => 'Hacetê pele',
 'specialpages-group-wiki'        => "Daê ''Wiki''y u haceti",
 'specialpages-group-redirects'   => 'Newe-vırastena pelunê xususiyun',
@@ -1536,6 +1559,16 @@ Eke dosya de peydêna vuriyais biyo ki, beno ke taê melumati gorê vurnaisê ne
 # Special:BlankPage
 'blankpage' => 'Pela thale',
 
+# External image whitelist
+'external_image_whitelist' => '  #no satır zey xo verde/raverde<pre>
+#parçeyê ifadeya rêzbiyayeyani (têna zerreyê ıney de // ) u çıtayo/çiyo zi mende cêr de têare kerê.
+#ney URL ya (hotlink) resmê teberi de hemcıta benî.
+#Ê yê ke hemcıt (eşleşmek-hemçift) biyê zey resımi asenî, eqsê hal de zi zey gıreyê resmi aseno.
+satır ê ke pê ney # # destpêkenê zey mışore/mıjore muamele vineno.
+#herfa gırd û qıci ferq nêkeno
+
+#parçeyê ifadeya rêzbiyayeyani bıerzê serê ney satıri. no satır zey xo verde/raverde </pre>',
+
 # Special:Tags
 'tag-filter' => 'Parzünê [[Special:Tags|etiket]]i:',
 
