@@ -11,6 +11,7 @@
  * @author Andrijko Z.
  * @author Aslan4ik
  * @author Cekli829
+ * @author Lezgia
  * @author MF-Warburg
  * @author Migraghvi
  * @author Namik
@@ -24,29 +25,29 @@ $fallback = 'ru';
 
 $messages = array(
 # User preference toggles
-'tog-underline'               => 'ЭлячIунрин кIаникай цIар чIугун',
+'tog-underline'               => 'ЭлячӀунрин кӀаникай цӀар чӀугун',
 'tog-justify'                 => 'Ччинин гьяркьуьвилихъ текст дуьзрун',
-'tog-hideminor'               => 'Мукьвара хьайи дегишвилера авай гъвечIи дуьзар хъувунар чуьнуьхун',
+'tog-hideminor'               => 'Мукьвара хьайи дегишвилера авай гъвечӀи дуьзар хъувунар чуьнуьхун',
 'tog-hidepatrolled'           => 'Мукьвара хьайи дегишвилера авай къаравулвал авунвай дуьзар хъувунар чуьнуьхун',
-'tog-newpageshidepatrolled'   => 'ЦIийи ччинрин сиягьда къаравулвал авунвай ччинар чуьнуьхун',
+'tog-newpageshidepatrolled'   => 'ЦӀийи ччинрин сиягьда къаравулвал авунвай ччинар чуьнуьхун',
 'tog-extendwatchlist'         => 'ЧӀехи сиягь килигунин, кутазвай вири дегишунар, амма са эхирбур туш',
-'tog-usenewrc'                => 'Мукьвара хьайи масакIавилерин ччина ва вилив хуьнин сиягьда  дуьзар хъувунар кIеретIриз ччара авун. (JavaScript герекзава)',
+'tog-usenewrc'                => 'Мукьвара хьайи масакӀавилерин ччина ва вилив хуьнин сиягьда дуьзар хъувунар кӀеретӀриз ччара авун. (JavaScript герекзава)',
 'tog-numberheadings'          => 'Кьилин цӀарариз автоматдаказ номерар эцигун',
 'tog-showtoolbar'             => 'Дуьзар хъувунин алатрин кьвати къалура (JavaScript)',
-'tog-editondblclick'          => 'Ччинар кьве тIампIуналди дуьзар хъувун (JavaScript герекзава)',
-'tog-editsection'             => 'Пай [дуьзар хъувун] патал элячIун къалура',
-'tog-editsectiononrightclick' => 'Пайдин кьилинцIардиз эрчIи патан тIампI авуна пайдин дуьзар хъувуниз мумкинвал гун (JavaScript герекзава)',
+'tog-editondblclick'          => 'Ччинар кьве тӀампӀуналди дуьзар хъувун (JavaScript герекзава)',
+'tog-editsection'             => 'Пай [дуьзар хъувун] патал элячӀун къалура',
+'tog-editsectiononrightclick' => 'Пайдин кьилинцӀардиз эрчӀи патан тӀампӀ авуна пайдин дуьзар хъувуниз мумкинвал гун (JavaScript герекзава)',
 'tog-showtoc'                 => 'Къенеавайбурун сиягь къалурун (3-й гзаф кьилинцӀарар авай ччинар патал)',
-'tog-rememberpassword'        => 'И браузерда зи логин рикlел хуьхь (лап гзаф $1 {{PLURAL:$1|югъ|йикъар}})',
-'tog-watchcreations'          => 'За туькIуьрнавай ччинар зи гуьзетунин сиягьдиз алава авун',
+'tog-rememberpassword'        => 'И браузерда зи логин рикӀел хуьхь (лап гзаф $1 {{PLURAL:$1|югъ|йикъар}})',
+'tog-watchcreations'          => 'За туькӀуьрнавай ччинар зи гуьзетунин сиягьдиз алава авун',
 'tog-watchdefault'            => 'За дуьзар хъувунвай ччинар зи гуьзетунин сиягьдиз алава авун',
-'tog-watchmoves'              => 'За тIвар эхцигай ччинар зи гуьзетунин сиягьдиз алава авун',
+'tog-watchmoves'              => 'За тӀвар эхцигай ччинар зи гуьзетунин сиягьдиз алава авун',
 'tog-watchdeletion'           => 'За алуднавай ччинар зи гуьзетунин сиягьдиз алава авун',
-'tog-minordefault'            => 'Авайвилелди, вири дуьзар хъувунар гъвечIи дуьзар хъувунар хьиз лишан авун',
-'tog-previewontop'            => 'Сифтедин килигун дуьзар хъувундин дакIардин вилик эцига',
-'tog-previewonfirst'          => 'Дуьзар хъувундиз эгечIайла сифтедин килигун къалурун',
-'tog-enotifwatchlistpages'    => 'Зи гуьзетунин ччин масакIа хьайила заз эмейл ракъура.',
-'tog-enotifusertalkpages'     => 'КЬилди жуван веревирдрин ччина хьанвай дегишвилерикай э-почтадиз чар ракъурун.',
+'tog-minordefault'            => 'Авайвилелди, вири дуьзар хъувунар гъвечӀи дуьзар хъувунар хьиз лишан авун',
+'tog-previewontop'            => 'Сифтедин килигун дуьзар хъувундин дакӀардин вилик эцига',
+'tog-previewonfirst'          => 'Дуьзар хъувундиз эгечӀайла сифтедин килигун къалурун',
+'tog-enotifwatchlistpages'    => 'Зи гуьзетунин ччин масакӀа хьайила заз эмейл ракъура.',
+'tog-enotifusertalkpages'     => 'Кьилди жуван веревирдрин ччина хьанвай дегишвилерикай э-почтадиз чар ракъурун.',
 'tog-oldsig'                  => 'Алай къул:',
 'tog-showhiddencats'          => 'Чуьнуьхай категорияр къалурун',
 
@@ -58,8 +59,8 @@ $messages = array(
 'editfont-style'     => 'Дуьзар хъувунин чкадин шрифтдин жуьре',
 'editfont-default'   => 'Браузердин низамарунрикай шрифт',
 'editfont-monospace' => 'Моногьяркьуьвилер авай шрифт',
-'editfont-sansserif' => 'КЬацI авачир шрифт',
-'editfont-serif'     => 'КьацI авай кхьин',
+'editfont-sansserif' => 'КьацӀ авачир шрифт',
+'editfont-serif'     => 'КьацӀ авай кхьин',
 
 # Dates
 'sunday'        => 'Гьяд',
@@ -76,65 +77,65 @@ $messages = array(
 'thu'           => 'Xем',
 'fri'           => 'Жум',
 'sat'           => 'Киш',
-'january'       => 'гьер (январь)',
-'february'      => 'эхен (февраль)',
-'march'         => 'ибне (март)',
-'april'         => 'нава (апрель)',
-'may_long'      => 'тӀул (май)',
-'june'          => 'кьамуг (июнь)',
-'july'          => 'чиле (июль)',
-'august'        => 'пахун (август)',
-'september'     => 'мара (сентябрь)',
-'october'       => 'баскӀум (октябрь)',
-'november'      => 'цӀехуьл (ноябрь)',
-'december'      => 'фундукӀ (декабрь)',
-'january-gen'   => 'гьер (январдиз)',
-'february-gen'  => 'эхен (февралдиз)',
-'march-gen'     => 'ибне (мартдиз)',
-'april-gen'     => 'нава (апрелдиз)',
-'may-gen'       => 'тӀул (майдиз)',
-'june-gen'      => 'кьамуг (июндиз)',
-'july-gen'      => 'чиле (июлдиз)',
-'august-gen'    => 'пахун (августдиз)',
-'september-gen' => 'мара (сентябрдиз)',
-'october-gen'   => 'баскӀум (октябрдиз)',
-'november-gen'  => 'цӀехуьл (ноябрдиз)',
-'december-gen'  => 'фундукӀ (декабрдиз)',
-'jan'           => 'гьер (январь)',
-'feb'           => 'эхен (февраль)',
-'mar'           => 'ибне (март)',
-'apr'           => 'нава (апрель)',
-'may'           => 'тӀул (май)',
-'jun'           => 'кьамуг (июнь)',
-'jul'           => 'чиле (июль)',
-'aug'           => 'пахун (август)',
-'sep'           => 'мара (сентябрь)',
-'oct'           => 'баскӀум (октябрь)',
-'nov'           => 'цӀехуьл (ноябрь)',
-'dec'           => 'фандукl (декабрь)',
+'january'       => 'январь',
+'february'      => 'февраль',
+'march'         => 'март',
+'april'         => 'апрель',
+'may_long'      => 'май',
+'june'          => 'июнь',
+'july'          => 'июль',
+'august'        => 'август',
+'september'     => 'сентябрь',
+'october'       => 'октябрь',
+'november'      => 'ноябрь',
+'december'      => 'декабрь',
+'january-gen'   => 'январь',
+'february-gen'  => 'февраль',
+'march-gen'     => 'март',
+'april-gen'     => 'апрель',
+'may-gen'       => 'май',
+'june-gen'      => 'июнь',
+'july-gen'      => 'июль',
+'august-gen'    => 'август',
+'september-gen' => 'сентябрь',
+'october-gen'   => 'октябрь',
+'november-gen'  => 'ноябрь',
+'december-gen'  => 'декабрь',
+'jan'           => 'янв',
+'feb'           => 'фев',
+'mar'           => 'мар',
+'apr'           => 'апр',
+'may'           => 'май',
+'jun'           => 'июн',
+'jul'           => 'июл',
+'aug'           => 'авг',
+'sep'           => 'сен',
+'oct'           => 'окт',
+'nov'           => 'ноя',
+'dec'           => 'дек',
 
 # Categories related messages
-'pagecategories'                 => '{{PLURAL:$1|Категория|Категории}}',
+'pagecategories'                 => '{{PLURAL:$1|Категория|Категорияр}}',
 'category_header'                => '"$1" категориядин ччинар',
 'subcategories'                  => 'агъакатегорияр',
-'category-media-header'          => '"$1" категоридин медиа',
-'category-empty'                 => "''Алай чIава и категория ичIи я.\"",
-'hidden-categories'              => '{{PLURAL:$1|Чуьнуьхай категория |Чуьнуьхай категорияр }}',
+'category-media-header'          => '"$1" категориядин медиа',
+'category-empty'                 => "''Алай чӀава и категория ичӀи я.\"",
+'hidden-categories'              => '{{PLURAL:$1|Чуьнуьхай категория|Чуьнуьхай категорияр}}',
 'hidden-category-category'       => 'Чуьнуьхай категорияр',
-'category-subcat-count'          => '{{PLURAL:$2|И категорияда анжах гуьгъуьна авай подкатегория ава.|$2-кай {{PLURAL:$1|подкатегория|$1 подкатегория}} къалурнава }}',
-'category-subcat-count-limited'  => 'И категорияда {{PLURAL:$1|$1 агъакатегория|$1 агъакатегорияр|$1 подкатегорий}} ава.',
+'category-subcat-count'          => '{{PLURAL:$2|И категорияда анжах гуьгъуьна авай подкатегория ава.|$2-кай {{PLURAL:$1|агъакатегория|$1 агъакатегорияр}} къалурнава }}',
+'category-subcat-count-limited'  => 'И категорияда {{PLURAL:$1|агъакатегория|$1 агъакатегорияр}} ава.',
 'category-article-count'         => '{{PLURAL:$2|И категорияда анжах гуьгъуьна авайди ччин ава |$2-кай къалурнавай {{PLURAL:$1|ччин|$1 ччин}} гьа а категориядин ччин я}}',
-'category-article-count-limited' => 'И категорияда {{PLURAL:$1|$1 ччин}} ава.',
+'category-article-count-limited' => 'И категорияда {{PLURAL:$1|ччин|$1 ччин}} ава.',
 'category-file-count'            => '{{PLURAL:$2|И категорияда анжах гуьгъуьна авайди файл ава |$2-кай къалурнавай {{PLURAL:$1|файл|$1 файлар}} гьа а категориядин файл я}}',
-'category-file-count-limited'    => 'И категорияда {{PLURAL:$1|$1 файл}} ава.',
-'listingcontinuesabbrev'         => '(кьатI)',
+'category-file-count-limited'    => 'И категорияда {{PLURAL:$1|файл|$1 файлар}} ава.',
+'listingcontinuesabbrev'         => '(кьатӀ)',
 'index-category'                 => 'Индексавунвай ччинар',
 'noindex-category'               => 'Индекстежезвай ччин',
-'broken-file-category'           => 'ЧIуру файлдин элячIунар авай ччинар',
+'broken-file-category'           => 'ЧӀуру файлдин элячӀунар авай ччинар',
 
 'about'         => 'Гьакъиндай',
 'article'       => 'Макъала',
-'newwindow'     => '(цlийи дакlарда ахъа жезва)',
+'newwindow'     => '(цӀийи дакӀарда ахъа жезва)',
 'cancel'        => 'Гьич авун',
 'moredotdotdot' => 'Мад...',
 'mypage'        => 'Зин чар',
@@ -150,61 +151,61 @@ $messages = array(
 'qbpageoptions'  => 'Ччинин низамарунар',
 'qbpageinfo'     => 'Ччиникай малумат',
 'qbmyoptions'    => 'Зи ччинар',
-'qbspecialpages' => 'Кьетlен хъувун',
+'qbspecialpages' => 'КьетӀен хъувун',
 'faq'            => 'Фад-фад гузвай жузунар (ФГЖ)',
 'faqpage'        => 'Project:ФГС',
 
 # Vector skin
 'vector-action-addsection'       => 'Тема алава авун',
 'vector-action-delete'           => 'Алудун',
-'vector-action-move'             => 'ТIвар эхцигун',
+'vector-action-move'             => 'ТӀвар эхцигун',
 'vector-action-protect'          => 'Хуьн',
-'vector-action-undelete'         => 'ТуькIуьр хъувун',
+'vector-action-undelete'         => 'ТуькӀуьр хъувун',
 'vector-action-unprotect'        => 'Хуьн дегишарун',
-'vector-simplesearch-preference' => 'Гегьенш жагъурунин рикIел гъун кутун (кьилди "Вектор" акунар патал)',
-'vector-view-create'             => 'Туькlуьрун',
-'vector-view-edit'               => 'Расун',
+'vector-simplesearch-preference' => 'Гегьенш жагъурунин рикӀел гъун кутун (кьилди «Вектор» акунар патал)',
+'vector-view-create'             => 'ТуькӀуьрун',
+'vector-view-edit'               => 'Дуьзарин',
 'vector-view-history'            => 'Тарихдиз килигун',
-'vector-view-view'               => 'Кlелун',
+'vector-view-view'               => 'КӀелун',
 'vector-view-viewsource'         => 'Чешме къалурун',
 'actions'                        => 'Крар',
-'namespaces'                     => 'Тlварарин генгвилер',
+'namespaces'                     => 'ТӀварарин генгвилер',
 'variants'                       => 'Жуьреяр',
 
-'errorpagetitle'    => 'ГъалатI',
+'errorpagetitle'    => 'ГъалатӀ',
 'returnto'          => '$1 ччиниз элкъвена хтун',
 'tagline'           => '{{SITENAME}} Cайтдихъай',
 'help'              => 'Куьмек',
 'search'            => 'Жугъурун',
 'searchbutton'      => 'Жагъурун',
-'go'                => 'ЭлячIун',
-'searcharticle'     => 'ЭлячIун',
+'go'                => 'ЭлячӀун',
+'searcharticle'     => 'ЭлячӀун',
 'history'           => 'Ччинин тарих',
 'history_short'     => 'Тарих',
-'updatedmarker'     => 'Зи эхиримжи гьахьун гуьгуьнлай цIийи авунва',
+'updatedmarker'     => 'Зи эхиримжи гьахьун гуьгуьнлай цӀийи авунва',
 'printableversion'  => 'Басма авун патал жуьре',
-'permalink'         => 'Гьамишан элячIун',
+'permalink'         => 'Гьамишан элячӀун',
 'print'             => 'Басма авун',
 'view'              => 'Килигун',
 'edit'              => 'Дуьзар хъувун',
-'create'            => 'Туькlуьрун',
+'create'            => 'ТуькӀуьрун',
 'editthispage'      => 'И ччин дуьзар хъувун',
-'create-this-page'  => 'И ччин туькIуьрун',
+'create-this-page'  => 'И ччин туькӀуьрун',
 'delete'            => 'Алудун',
 'deletethispage'    => 'И ччин алудун',
-'undelete_short'    => '$1 {{PLURAL:$1|дуьзар хъувун|дуьзар хъувунар}} туьхкIуьрун',
+'undelete_short'    => '$1 {{PLURAL:$1|дуьзар хъувун|дуьзар хъувунар}} туьхкӀуьрун',
 'viewdeleted_short' => '{{PLURAL:$1|дуьзар хъувуниз|$1 дуьзар хъувунриз}} килигун',
 'protect'           => 'Xуьн',
-'protect_change'    => 'масакIа авун',
+'protect_change'    => 'масакӀа авун',
 'protectthispage'   => 'И ччин блокарун',
 'unprotect'         => 'Хуьн дегишарун',
 'unprotectthispage' => 'И ччинин хуьн дегишарун',
-'newpage'           => 'ЦIийи ччин',
+'newpage'           => 'ЦӀийи ччин',
 'talkpage'          => 'И ччин веревирдун',
 'talkpagelinktext'  => 'Рахун',
 'specialpage'       => 'Куьмекчи ччин',
 'personaltools'     => 'Кьилди вичин алатар',
-'postcomment'       => 'ЦIйий пай',
+'postcomment'       => 'ЦӀйий пай',
 'articlepage'       => 'Къене авайбурун ччиндиз килигун',
 'talk'              => 'Веревирд авун',
 'views'             => 'Килигунар',
@@ -217,22 +218,22 @@ $messages = array(
 'viewhelppage'      => 'Куьмекдин ччиниз килигун',
 'categorypage'      => 'Категориядин ччиниз килигун',
 'viewtalkpage'      => 'Веревирдриз килигун',
-'otherlanguages'    => 'Маса чIаларал',
+'otherlanguages'    => 'Маса чӀаларал',
 'redirectedfrom'    => '($1-кай рахкъурнава )',
 'redirectpagesub'   => 'Рахкъурунин ччин',
-'lastmodifiedat'    => 'Ччинин эхиримжи масакIа хьун:  $1,  $2',
+'lastmodifiedat'    => 'Ччинин эхиримжи масакӀа хьун:  $1,  $2',
 'protectedpage'     => 'Хвенвай ччин',
-'jumpto'            => 'ЭлячIун иниз:',
-'jumptonavigation'  => 'Навигаци',
+'jumpto'            => 'ЭлячӀун иниз:',
+'jumptonavigation'  => 'Навигация',
 'jumptosearch'      => 'Жугъурун',
-'pool-queuefull'    => 'ТIалабар кIватзавайди ацIа я',
-'pool-errorunknown' => 'Малумтушир гъалатI',
+'pool-queuefull'    => 'ТӀалабар кӀватзавайди ацӀа я',
+'pool-errorunknown' => 'Малумтушир гъалатӀ',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => ' {{SITENAME}}кай',
 'aboutpage'            => 'Project:Гьакъиндай',
-'copyright'            => 'КЪене авайбур $1 жугъуриз жеда.',
-'copyrightpage'        => '{{ns:project}}: Автордин ихтияр',
+'copyright'            => 'Къене авайбур $1 жугъуриз жеда.',
+'copyrightpage'        => '{{ns:project}}:Автордин ихтияр',
 'currentevents'        => 'Алай вакъиаяр',
 'currentevents-url'    => 'Project:Алай вакъиаяр',
 'disclaimers'          => 'Жавабдарвал хивяй акъудун',
@@ -243,20 +244,20 @@ $messages = array(
 'mainpage'             => 'Кьилин ччин',
 'mainpage-description' => 'Кьилин ччин',
 'policy-url'           => 'Project:Къайдаяр',
-'portal'               => 'КIапIалдин портал',
-'portal-url'           => 'Project:КIапIалдин портал',
+'portal'               => 'КӀапӀалдин портал',
+'portal-url'           => 'Project:КӀапӀалдин портал',
 'privacy'              => 'Чинебанвилин сиясат',
 'privacypage'          => 'Project:Чинебанвилин политика',
 
-'badaccess' => 'ГЬатунин гъалатlдин',
+'badaccess' => 'Гьатунин гъалатӀдин',
 
 'ok'                      => 'ОК',
 'retrievedfrom'           => 'Чешне "$1" я',
-'youhavenewmessages'      => 'Квез  $1 ($2) атанва.',
-'newmessageslink'         => 'цlийи чарар',
-'newmessagesdifflink'     => 'Эхиримжи масакIавилер',
-'youhavenewmessagesmulti' => '"$1"-да квез цIийи чарар атанва.',
-'editsection'             => 'Расун',
+'youhavenewmessages'      => 'Квез $1 ($2) атанва.',
+'newmessageslink'         => 'цӀийи чарар',
+'newmessagesdifflink'     => 'Эхиримжи масакӀавилер',
+'youhavenewmessagesmulti' => '"$1"-да квез цӀийи чарар атанва.',
+'editsection'             => 'Дуьзар хъувун',
 'editold'                 => 'Дуьзар хъувун',
 'viewsourceold'           => 'сифте кьилин коддиз килига',
 'editlink'                => 'Дуьзар хъувун',
@@ -267,20 +268,20 @@ $messages = array(
 'hidetoc'                 => 'чуьнуьхун',
 'collapsible-collapse'    => 'Алчудрун',
 'collapsible-expand'      => 'Гегьеншрун',
-'thisisdeleted'           => '$1 килигун ва я туькIуьр хъувун?',
+'thisisdeleted'           => '$1 килигун ва я туькӀуьр хъувун?',
 'viewdeleted'             => '$1 килигун?',
 'feedlinks'               => 'Хулан жуьре',
 'site-rss-feed'           => '$1 — RSS-зул',
-'site-atom-feed'          => '$1 -  атом-зул',
-'page-rss-feed'           => '"$1" РСС Xуьрек',
+'site-atom-feed'          => '$1 - атом-зул',
+'page-rss-feed'           => '"$1" RSS Xуьрек',
 'page-atom-feed'          => '"$1" Атом-зул',
 'red-link-title'          => '$1 (ихьтин ччин авайди туш)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'Ччин',
 'nstab-user'      => 'Уртахдин ччин',
-'nstab-media'     => 'Медия ччин',
-'nstab-special'   => 'Куьмекчи ччин',
+'nstab-media'     => 'Медиа ччин',
+'nstab-special'   => 'Квимекдин ччин',
 'nstab-project'   => 'Проектдин ччин',
 'nstab-image'     => 'Файл',
 'nstab-mediawiki' => 'Малумат',
@@ -293,67 +294,69 @@ $messages = array(
 'nosuchspecialpage' => 'Ихьтин куьмекчи ччин авайд ттуш',
 
 # General errors
-'error'              => 'Гъалатl',
-'databaseerror'      => 'Ганайбурун базадин гъалатI',
-'missing-article'    => 'Малуматрин базада, квез герек авай "$1" $2 тIвар алай ччиндин текст жагъанвач
+'error'              => 'ГъалатӀ',
+'databaseerror'      => 'Ганайбурун базадин гъалатӀ',
+'missing-article'    => 'Малуматрин базада, квез герек авай "$1" $2 тӀвар алай ччиндин текст жагъанвач
 
-Ихьтин гьал адет яз алуднавай ччинин масакIавилерин тарихдиз цlуру  рекьяй элячlайла арадал къвезва.
+Ихьтин гьал адет яз алуднавай ччинин масакӀавилерин тарихдиз цӀуру рекьяй элячӀайла арадал къвезва.
 
-Себеб ам туштlа, виридалайни мумкин тирди куьне программада гъалатl жугъурун я
-Тавакъу ийида, URL  къалурна адакай   [[Special:ListUsers/sysop|администратордиз]] хабар це.',
+Себеб ам туштӀа, виридалайни мумкин тирди куьне программада гъалатӀ жугъурун я
+Тавакъу ийида, URL къалурна адакай [[Special:ListUsers/sysop|администратордиз]] хабар це.',
 'missingarticle-rev' => '(жуьре#: $1)',
-'internalerror'      => 'КЪенепатан гъалатI',
-'internalerror_info' => 'КЪенепатан гъалатI $1',
-'filerenameerror'    => '«$1» файл  «$2» -з тIвар эхцигиз жезвач..',
+'internalerror'      => 'Къенепатан гъалатӀ',
+'internalerror_info' => 'Къенепатан гъалатI $1',
+'filecopyerror'      => '«$1» файл «$2» -з тӀвар эхцигиз жезвач.',
+'filerenameerror'    => '«$1» файл «$2» -з тӀвар эхцигиз жезвач.',
 'badarticleerror'    => 'И ччина и кар кьилиз акъудиз мумкин ттуш.',
-'cannotdelete-title' => ' "$1" ччин алудиз жезвач',
-'badtitle'           => 'Ииже текъвер тIвар',
-'badtitletext'       => 'ТIалабзавай ччин  я вичел амал алачир я,  я  ичIи я,  ва я чIаларарадин ва я викиарадин кьилин цlарар чlурукlа къалурнава. Мумкин я, кьилин цlарара сад ва я адалай гзаф рехъ гун виже текъвер символар кардик кутунвайди я.',
+'cannotdelete-title' => '"$1" ччин алудиз жезвач',
+'badtitle'           => 'Ииже текъвер тӀвар',
+'badtitletext'       => 'ТӀалабзавай ччин я вичел амал алачир я, ичӀи я, ва я чӀаларарадин ва я викиарадин кьилин цӀарар чӀурукӀа къалурнава. Мумкин я, кьилин цӀарара сад ва я адалай гзаф рехъ гун виже текъвер символар кардик кутунвайди я.',
 'viewsource'         => 'Килигун',
 'viewsource-title'   => '$1 патал чешмедиз килигун',
 'actionthrottled'    => 'Фадвилин сергьятар',
 
 # Virus scanner
+'virus-scanfailed'     => 'Сканди гъалатӀ (кулег$1)',
 'virus-unknownscanner' => 'Малумтушир антивирус',
 
 # Login and logout pages
-'yourname'                => 'Уртахдин тlвар',
+'yourname'                => 'Уртахдин тӀвар',
 'yourpassword'            => 'Парол',
 'yourpasswordagain'       => 'Парол кхьин хъувун:',
-'remembermypassword'      => 'И браузерда зи логин рикlел хуьхь (лап гзаф $1 {{PLURAL:$1|югъ|йикъар}})',
+'remembermypassword'      => 'И браузерда зи логин рикӀел хуьхь (лап гзаф $1 {{PLURAL:$1|югъ|йикъар}})',
 'yourdomainname'          => 'Куь домен',
 'login'                   => 'Гьахьун',
-'nav-login-createaccount' => 'Гьахьун/аккаунт туькlуьрун',
-'loginprompt'             => 'Системадиз гьахьун патал "куки" -яр куькlуьрна кIанзава',
-'userlogin'               => 'ГЬахьун/аккаунт туькlуьрун',
+'nav-login-createaccount' => 'Гьахьун/аккаунт туькӀуьрун',
+'loginprompt'             => 'Системадиз гьахьун патал "куки" -яр куькӀуьрна кӀанзава',
+'userlogin'               => 'Гьахьун/аккаунт туькӀуьрун',
 'userloginnocreate'       => 'Гьахьун',
-'logout'                  => 'ЭкъечIун',
-'userlogout'              => 'ЭкъечIун',
+'logout'                  => 'ЭкъечӀун',
+'userlogout'              => 'ЭкъечӀун',
 'notloggedin'             => 'Куьн гьахьнавач',
 'nologin'                 => 'Квез аккаунт авачни? $1.',
-'nologinlink'             => 'Аккаунт туькlуьрун',
-'createaccount'           => 'Аккаунт туькlуьрун',
+'nologinlink'             => 'Аккаунт туькӀуьрун',
+'createaccount'           => 'Аккаунт туькӀуьрун',
 'gotaccount'              => 'Квез аккаунт авани?$1',
 'gotaccountlink'          => 'Гьахьун',
-'userlogin-resetlink'     => 'Гьахьунин куьлуь-шуьлуьяр рикlел алатнани?',
+'userlogin-resetlink'     => 'Гьахьунин куьлуь-шуьлуьяр рикӀел алатнани?',
 'createaccountmail'       => 'Э-чар галаз',
 'createaccountreason'     => 'Себеб:',
-'loginerror'              => 'ГЬахьунин гъалатI',
-'createaccounterror'      => 'И аккаунт туькIуьриз мумкин ттуш: $1',
+'loginerror'              => 'Гьахьунин гъалатӀ',
+'createaccounterror'      => 'И аккаунт туькӀуьриз мумкин ттуш: $1',
 'loginsuccesstitle'       => 'Агалкьунралди гьахьун',
-'wrongpasswordempty'      => 'Тавакъу ийида, ичIи тушир парол ттур.',
-'mailmypassword'          => 'ЦIийи парол Э-мейлдиз къачун',
-'mailerror'               => 'Чар ракъурунин гъалатI: $1',
+'wrongpasswordempty'      => 'Тавакъу ийида, ичӀи тушир парол ттур.',
+'mailmypassword'          => 'ЦӀийи парол э-мейлдиз къачун',
+'mailerror'               => 'Чар ракъурунин гъалатӀ: $1',
 'emailconfirmlink'        => 'Куь электрон почтунин адрес тестикьун.',
-'accountcreated'          => 'Аккаунт туькIуьрнава',
-'usernamehasherror'       => 'Уртахдин тIвар "диез"дин лишан квачиз хьана кIанзава',
-'loginlanguagelabel'      => 'ЧIал: $1',
+'accountcreated'          => 'Аккаунт туькӀуьрнава',
+'usernamehasherror'       => 'Уртахдин тӀвар "диез"дин лишан квачиз хьана кӀанзава',
+'loginlanguagelabel'      => 'ЧӀал: $1',
 
 # Change password dialog
 'resetpass'                 => 'Куьлег дегишарун',
 'resetpass_header'          => 'Аккаунтдин парол дегишун',
-'oldpassword'               => 'ЦIуру парол:',
-'newpassword'               => 'ЦIийи парол:',
+'oldpassword'               => 'ЦӀуру парол:',
+'newpassword'               => 'ЦӀийи парол:',
 'retypenew'                 => 'Парол кхьин хъувун:',
 'resetpass_submit'          => 'Парол эцигун ва гьахьун',
 'resetpass_forbidden'       => 'Парол дегишиз мумкин ттуш',
@@ -523,7 +526,7 @@ $messages = array(
 'revertmerge' => 'Ччара авун',
 
 # Diffs
-'history-title'           => '$1  -  масакIавилерин тарих',
+'history-title'           => '$1 - масакӀавилерин тарих',
 'difference'              => '(Жуьрейрин арада тафаватар)',
 'lineno'                  => 'ЦIар $1:',
 'compareselectedversions' => 'Хкягъай жуьреяр гекъигун',
@@ -600,7 +603,7 @@ $messages = array(
 'prefs-edits'               => 'Дьузар хъувунрин кьадар',
 'prefsnologin'              => 'Куьне гьахьнавач',
 'changepassword'            => 'Парол дегишарун',
-'prefs-skin'                => 'КЪайдадиз ттунин тема',
+'prefs-skin'                => 'Къайдадиз ттунин тема',
 'skin-preview'              => 'Сифтедин килигун',
 'datedefault'               => 'Туькlуьрмир',
 'prefs-beta'                => 'Бета-мумкинвилер',
@@ -616,7 +619,7 @@ $messages = array(
 'prefs-changeemail'         => 'Э-почта дегишарун',
 'prefs-setemail'            => 'Э-почта эцигна туькIуьрун',
 'prefs-email'               => 'E-mail туькlуьрунин кьадарар',
-'prefs-rendering'           => 'КЪецепатан  акунар',
+'prefs-rendering'           => 'Къецепатан акунар',
 'saveprefs'                 => 'Хуьн',
 'resetprefs'                => 'Хуьн тавунвай дегишвилер алудун',
 'restoreprefs'              => 'Авайл хьиз кьунвай низамарунар туькIуьр хъувун',
@@ -750,7 +753,7 @@ $messages = array(
 'recentchangeslinked-toolbox'  => 'Галкlанвай масакIавилер',
 'recentchangeslinked-title'    => '"$1" галаз галкlанавай масакIавилер',
 'recentchangeslinked-noresult' => 'Ганвай чlава галкlанавай ччинра са масакIавални хьанвайд туш',
-'recentchangeslinked-summary'  => 'Им къалурай ччиниз (ва я къалурай категориядиз гьатзавай ччинриз) элячIзавай ччинра мукьвара хьайи масакIавилерин сиягь я. Куь [[Special:Watchlist| вилив хуьнин сиягь ]]диз гьатзавай  ччинар яцlу шрифтдал къалурнава.',
+'recentchangeslinked-summary'  => 'Им къалурай ччиниз (ва я къалурай категориядиз гьатзавай ччинриз) элячӀзавай ччинра мукьвара хьайи масакӀавилерин сиягь я. Куь [[Special:Watchlist|вилив хуьнин сиягь диз]] гьатзавай ччинар яцӀу шрифтдал къалурнава.',
 'recentchangeslinked-page'     => 'Ччинин тlвар:',
 'recentchangeslinked-to'       => 'Аксина, къалурай ччиниз элячlзавай ччинра масакIавилер къалура',
 
@@ -865,7 +868,7 @@ $messages = array(
 'disambiguationspage' => 'Template:гзафманавал',
 
 'brokenredirects-edit'   => 'дегишарун',
-'brokenredirects-delete' => 'къакъудун',
+'brokenredirects-delete' => 'алудун',
 
 'withoutinterwiki-submit' => 'КЪалурун',
 
@@ -879,7 +882,7 @@ $messages = array(
 'protectedpages'    => 'Хвенвай ччинар',
 'listusers'         => 'Уртахрин сиягь',
 'usercreated'       => '{{GENDER:$3|Created}} идав $1 идал $2',
-'newpages'          => 'ЦIийи ччинар',
+'newpages'          => 'ЦӀийи ччинар',
 'newpages-username' => 'Иштиракчидин тlвар',
 'ancientpages'      => 'виридалайни цIуру ччинар',
 'move'              => 'ТIвар эхцигун',
@@ -928,7 +931,7 @@ $messages = array(
 'listgrouprights-group'   => 'КIеретI',
 'listgrouprights-members' => '(уьзвийрин сиягь)',
 
-# E-mail user
+# Email user
 'emailuser'           => 'Уртахдиз чар кхьихь',
 'emailusername'       => 'Уртахдин тlвар:',
 'emailusernamesubmit' => 'Ракъурун',
@@ -940,7 +943,7 @@ $messages = array(
 
 # Watchlist
 'watchlist'         => 'Зи вилив хуьнин сиягь',
-'mywatchlist'       => 'Зи вилив хюнин сиягь',
+'mywatchlist'       => 'Вилив хуьнин сиягь',
 'watchlistfor2'     => '$1 $2 патал',
 'addedwatchtext'    => "Чар \"[[:\$1]]\" тун хъувунай куьн [[Special:Watchlist|watchlist]].                                                                                                             Къвезмай дегишунар и чарчел ва галкlанавай чарчихъ ихтилатар жеда инна, ахъатдава \"сакlус яцlу''''' инна [[Special:RecentChanges|list of recent changes]] гьам кьизил авун.",
 'removedwatchtext'  => 'Чар "[[:$1]]" Идай чlурнай [[Special:Watchlist|ахтармишунин цlарар]].',
@@ -1027,7 +1030,7 @@ $messages = array(
 # Contributions
 'contributions'       => 'Уртахди кутур крар',
 'contributions-title' => '$1 уртахди кутур крар',
-'mycontris'           => 'За кутур кар',
+'mycontris'           => 'Кутур кар',
 'contribsub2'         => '($1)-ин кутур пай  ($2)',
 'uctop'               => '(вини кьил)',
 'month'               => ' Вацралай (ва адалай вилик)',
@@ -1058,7 +1061,7 @@ $messages = array(
 'whatlinkshere-hideredirs' => '$1 рахкъурунар',
 'whatlinkshere-hidetrans'  => '$1 кутунар',
 'whatlinkshere-hidelinks'  => '$1 элячlунар',
-'whatlinkshere-hideimages' => '$1 шикилриз элячIунар',
+'whatlinkshere-hideimages' => '$1 фаjлрин элачlунар',
 'whatlinkshere-filters'    => 'Куьзунагар',
 
 # Block/unblock
@@ -1184,7 +1187,7 @@ $messages = array(
 'tooltip-diff'                    => 'Сифте кьилин текстдиз талукь тир куьне авунвай масакIавилер къалурун',
 'tooltip-compareselectedversions' => 'И ччинин кьве хкягъай жуьрейрин арада авай тафаватдиз килигун',
 'tooltip-watch'                   => 'И ччин куь вилив хуьнин сиягьдиз алава авун',
-'tooltip-rollback'                => '« КЬулухъди чIугун »  и ччиндиз эхиримжи кар кутазвайди патай  авунвай дуьзар хъувунар са т!ампуналди  paxкурзава',
+'tooltip-rollback'                => '«Кьулухъди чӀугун» и ччиндиз эхиримжи кар кутазвайди патай авунвай дуьзар хъувунар са тӀампуналди paxкурзава',
 'tooltip-undo'                    => '«Гьич авун»  авунвай дуьзар хъувун paxкурзава ва сифтедин килигунин режимда  дуьзар хъувундин форма ахъа йийзва. Им нетижадиз себеб алава йийз мумкинвал гузва',
 'tooltip-summary'                 => 'Куьруь нетижа гьадрун',
 
@@ -1205,7 +1208,7 @@ $messages = array(
 'file-info-size' => '$1 × $2 пикселар, файлдин кьадар: $3, MIME жуьре: $4',
 'file-nohires'   => 'Идалайни хъсан ери авайд туш',
 'svg-long-desc'  => 'SVG файл, номилдаказ $1 $2 × пикселяр, файлдин кьадар: $3',
-'show-big-image' => 'Цlарафа хвена тунвай жергедай',
+'show-big-image' => 'ЦӀарафа хвена тунвай жергедай',
 
 # Bad image list
 'bad_image_list' => 'Формат гьихьтинди хьана кlанда:
