@@ -7,6 +7,8 @@
  * @ingroup Language
  * @file
  *
+ * @author Andrijko Z.
+ * @author Erdemaslancan
  * @author Ohpuu
  * @author Warbola
  */
@@ -252,7 +254,7 @@ agā [{{fullurl:{{FULLPAGENAME}}|action=edit}} sīe līed īž lūodõ]</span>.'
 Sa võid [[Special:Search/{{PAGENAME}}|vȯtšõ pēļizkēra frāzõ]] mūšti lēḑist,
 <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} vȯtšõ tämstõ log failidi],
 agā [{{fullurl:{{FULLPAGENAME}}|action=edit}} sīe līed īž lūodõ]</span>.',
-'previewnote'                      => "''' Algid undõgid, ku se um setku jedmõl-vaņtlimi!'''
+'previewnote'                      => "'''Algid undõgid, ku se um setku jedmõl-vaņtlimi!'''
 Sin redigīerimizt äb ūo vel sa-gläbdõd !",
 'editing'                          => 'Redigīerimiz pǟl um $1',
 'editingsection'                   => 'Redigīerimiz pǟl um $1 sektsij līedst',
@@ -306,7 +308,7 @@ Legend: '''({{int:cur}})''' = vaiţīd līdzinţõmizõks lǟndz redaktsijõks,,
 'revertmerge' => 'Kīeld jarā kubbõ vieddimi',
 
 # Diffs
-'history-title'           => 'Līed "$1" mõitõkst istōrij',
+'history-title'           => 'Līed mõitõkst istōrij "$1"',
 'difference'              => '(Vaiţīd redaktsijõd vail)',
 'lineno'                  => 'Rīnda $1:',
 'compareselectedversions' => 'Līdzinţ vēļdõt redaktsijḑi',
@@ -496,7 +498,7 @@ Legend: '''({{int:cur}})''' = vaiţīd līdzinţõmizõks lǟndz redaktsijõks,,
 # Special:ListGroupRights
 'listgrouprights-members' => '(nõtkõmd nimkēra)',
 
-# E-mail user
+# Email user
 'emailuser' => 'Sōtõgid sīen kȭlbatijizõn e-kēra',
 
 # Watchlist
