@@ -10,7 +10,9 @@
  * @author Bombola
  * @author Dato deutschland
  * @author Dawid Deutschland
+ * @author Erdemaslancan
  * @author Ibero-kolxi
+ * @author Reedy
  * @author The Evil IP address
  */
 
@@ -111,8 +113,11 @@ $messages = array(
 'qbspecialpages' => 'Doxmeli sayfape',
 
 # Vector skin
-'vector-action-delete' => 'Jili',
-'vector-view-edit'     => 'Doktiri',
+'vector-action-delete'  => 'Jili',
+'vector-action-protect' => 'İçvi',
+'vector-view-create'    => 'dokʼidi',
+'vector-view-edit'      => 'Doktiri',
+'variants'              => "Variant'epe",
 
 'errorpagetitle'   => 'Çilata',
 'returnto'         => '$1 butʼkʼaşa goikti.',
@@ -168,7 +173,7 @@ $messages = array(
 
 'ok'                      => 'HO',
 'retrievedfrom'           => '"$1" adresişen eizdinu',
-'youhavenewmessages'      => 'Ağani <u>$1</u> giğun. ($2)',
+'youhavenewmessages'      => 'Ağani $1 giğun. ($2)',
 'newmessageslink'         => 'ağani mesajepe',
 'newmessagesdifflink'     => 'çodinaşi oktiroba',
 'youhavenewmessagesmulti' => "$1's ağne mesajepe giğun",
@@ -219,6 +224,7 @@ Dudicoxopes oxmaruşi yasaği na ren ar, varna daha dido kʼarakʼtʼeri uğun.'
 'userlogout'              => 'Siteşen Kogamaxti',
 'nologin'                 => "Hesabi va giğuni? '''$1'''",
 'nologinlink'             => 'Hesabi dokʼidi.',
+'gotaccountlink'          => 'Sitʼeşa amaxti',
 'mailmypassword'          => 'Ağne pʼarola-çkimi moncğoni',
 
 # Change password dialog
@@ -268,7 +274,7 @@ varna am butʼkʼa [{{fullurl:{{FULLPAGENAME}}|action=edit}} gaktirinen]</span>.
 paktʼiş doloxe ren (detayepe şeni $1's o3ʼkʼedi).
 Na qʼvi meşvelaşa başka makʼaturepeşkʼelen pʼatʼi mutxanepe ixvenen varna xemoşletinerot do uoçodinurot başka svapeşa niçinen, aya kʼabuli qʼvi varna am sitʼe şeni mutu mo ikip!<br />
 Edo amuş metʼi, ak mxuciş meçamu ginonna, meşvelape ti-skani kʼala oçʼaruşi re, varna ofi3ialurişa gon3ʼkʼimeri na ren ar kʼaynağişen (odudeşen) varna başka oxoşkveri kʼaynağepeşen (odudepeşen) na ezdi kʼabuli oxvenuşi re.<br />
-'''<center>DOXMELİ HAKʼEPETE NA İŞİNAXENAN XANDAPE AK MO UKʼATEPT!</center>'''",
+'''DOXMELİ HAKʼEPETE NA İŞİNAXENAN XANDAPE AK MO UKʼATEPT!'''",
 'templatesused'                    => 'Am butʼkʼas na ixmarinen {{PLURAL:$1|şabloni|şablonepe}}:',
 'templatesusedpreview'             => 'Am "Evvelişen i3ʼkʼedi" fonkʼsionis na ixmarinen {{PLURAL:$1|şabloni|şablonepe}}:',
 'template-protected'               => '(oçvu)',
@@ -302,7 +308,7 @@ Oxo3ʼonapape: (a3ʼineri) = a3ʼineri versiyoni kʼala na ren farkʼi,
 'revertmerge' => 'Artikʼartişen okʼo3ʼkʼi',
 
 # Diffs
-'history-title'           => '"$1" butʼkʼaşi tarixi',
+'history-title'           => 'Butʼkʼaşi tarixi "$1"',
 'difference'              => '(Versiyonepeşi farkʼepe)',
 'lineno'                  => '$1. satʼiri:',
 'compareselectedversions' => 'Na goşiğen versiyonepe okʼo3ʼiri',
@@ -328,6 +334,7 @@ Oxo3ʼonapape: (a3ʼineri) = a3ʼineri versiyoni kʼala na ren farkʼi,
 'search-interwiki-more'     => '(çkva)',
 'search-mwsuggest-enabled'  => 'okʼvandupete',
 'search-mwsuggest-disabled' => 'okʼvandu varen',
+'searchall'                 => 'mteli',
 'nonefound'                 => "'''Notʼi''': Xvala, namtini svacoxope maartani oqʼopinot igoren.
 Ogoruşi dudis '''all:''' pʼrefiksi okʼatute doloçʼareli na ren iri şeyi (oğarğaluşi butʼkʼape, şablonepe, doçkva şeyepeti iqʼvasen) mgori varna pʼrefiksi oqʼopinot na igoren svacoxo ixmarit.",
 'powersearch'               => 'Mordineri ogoru',
@@ -406,7 +413,10 @@ Ogoruşi dudis '''all:''' pʼrefiksi okʼatute doloçʼareli na ren iri şeyi (o
 'uploadlogpage' => 'Dosya oncğonu kʼayitʼepe',
 'uploadedimage' => 'Siteşa na incğonen resimi: "[[$1]]"',
 
+'license-header' => 'Lisans',
+
 # File description page
+'file-anchor-link'          => 'Dosya',
 'filehist'                  => 'Dosyaşi tarixi',
 'filehist-help'             => 'Dosyaşi tarixi oz*iru şeni Ndğa/Ora burme-muşis na renan tarixepes o3ʼkʼedi.',
 'filehist-deleteall'        => 'mteli jili',
@@ -460,13 +470,12 @@ Ogoruşi dudis '''all:''' pʼrefiksi okʼatute doloçʼareli na ren iri şeyi (o
 'linksearch' => 'Galeni kʼontaktʼepe',
 
 # Special:Log/newusers
-'newuserlogpage'          => 'Ağani maxmareş kʼayitʼepe',
-'newuserlog-create-entry' => 'Ağani maxmare',
+'newuserlogpage' => 'Ağani maxmareş kʼayitʼepe',
 
 # Special:ListGroupRights
 'listgrouprights-members' => '(makʼaturepeşi listʼe)',
 
-# E-mail user
+# Email user
 'emailuser' => 'Maxmares e-maili oncğoni',
 
 # Watchlist
@@ -498,7 +507,6 @@ Am dulyaşen na yeçkindasen zararepe giçkinna do am dulya [[{{MediaWiki:Policy
 'actioncomplete'        => 'Aksiyoni içodinu.',
 'deletedtext'           => '"$1" nijilu.
 Xolosi oras jileri na renanpe oz*iru şeni: $2.',
-'deletedarticle'        => '"[[$1]]" aya nijilu',
 'dellogpage'            => 'Ojiluşi kʼayitʼepe',
 'deletecomment'         => 'Muşen:',
 'deleteotherreason'     => 'Majurani/ilave sebebi:',
@@ -533,7 +541,6 @@ Am butʼkʼaşi oçvuşi sinori gaktirinen; ama am oktiroba, kʼademoni oçvalu
 
 # Undelete
 'undeletelink'              => 'i3ʼkʼedi/komoiği',
-'undeletedarticle'          => '[[$1]] goiktu.',
 'undelete-search-submit'    => 'Mgori',
 'undelete-show-file-submit' => 'Ho',
 
@@ -553,6 +560,7 @@ Am butʼkʼaşi oçvuşi sinori gaktirinen; ama am oktiroba, kʼademoni oçvalu
 
 'sp-contributions-newbies'  => 'Xvala ağani maxmarepeşi meşvelape ko3ʼiri',
 'sp-contributions-blocklog' => 'Bloğiş kʼayitʼi',
+'sp-contributions-talk'     => 'Mesaji',
 'sp-contributions-search'   => 'Meşvelape mgori',
 'sp-contributions-username' => 'IP varna maxmare:',
 'sp-contributions-submit'   => 'Mgori',
@@ -576,7 +584,7 @@ Am butʼkʼaşi oçvuşi sinori gaktirinen; ama am oktiroba, kʼademoni oçvalu
 # Block/unblock
 'blockip'                  => 'Maxmares bloği qʼvi',
 'ipboptions'               => '2 saatʼi:2 hours,1 ndğa:1 day,3 ndğa:3 days,1 doloni:1 week,2 doloni:2 weeks,1 tuta:1 month,3 tuta:3 months,6 tuta:6 months,1 3ʼana:1 year,pʼanda:infinite',
-'ipblocklist'              => 'Bloği xveneri na renan IP adresepe do maxmareş coxope',
+'ipblocklist'              => 'Bloği do maxmareş',
 'blocklink'                => 'bloği qʼvi',
 'unblocklink'              => 'bloği kezdi',
 'change-blocklink'         => 'bloği doktiri',
@@ -613,8 +621,6 @@ Mu iqʼven başka coxo doçʼari.',
 'talkexists'       => "'''Butʼkʼa dido kʼai itirinu, mara oğarğaluşi butʼkʼa var itirinu çunki na itirinasen coxos zate ar butʼkʼa rtʼu. Mu iqʼven butʼkʼaşi doloçʼareli nç'arape majurani butʼkʼaşa ti-skani kʼala itirini.'''",
 'movedto'          => 'itirinu:',
 'movetalk'         => 'Korenna, "oğarğaluşi" butʼkʼa muşiti mendiği.',
-'1movedto2'        => '[[$1]] butʼkʼa muşişi ağani coxo: [[$2]]',
-'1movedto2_redir'  => '[[$1]] stʼatʼiaşi adresi iktirinu do ağani adresi [[$2]] butʼkʼaşa niçinu',
 'movelogpage'      => 'Coxo oktirobaşi kʼayitʼepe',
 'movereason'       => 'Muşen:',
 'revertmove'       => 'komoiği',
@@ -622,6 +628,9 @@ Mu iqʼven başka coxo doçʼari.',
 # Export
 'export' => 'Butʼkʼa ikʼayitʼi',
 
+# Namespace 8 related
+'allmessagesname' => 'Coxo',
+
 # Thumbnails
 'thumbnail-more' => 'Didi qʼvi',
 
@@ -686,7 +695,7 @@ Mu iqʼven başka coxo doçʼari.',
 
 # Media information
 'file-info-size' => '$1 × $2 pikseli, dosyaşi didinoba: $3, MIME type: $4',
-'file-nohires'   => '<small>Çkva kʼai ozʼiramuşis na uğun versiyoni va ren.</small>',
+'file-nohires'   => 'Çkva kʼai ozʼiramuşis na uğun versiyoni va ren.',
 'svg-long-desc'  => 'SVG dosya, coxoten $1 × $2 pʼikʼseli, dosyaşi didinoba: $3',
 'show-big-image' => 'Tam ozʼiramuşi',
 
