@@ -61,9 +61,9 @@ $messages = array(
 'tog-previewontop'            => 'Bontšha Ponopele pele ga lepokisi la diphetogo',
 'tog-previewonfirst'          => 'Bontšha Ponopeleka phetogo ya pele',
 'tog-nocache'                 => "Thibela go tsenya matlakala go segakolodi (''cache'')",
-'tog-enotifwatchlistpages'    => 'Nromele molaetša ge letlaka leo ke le tlhapetšego le eba le diphetogo',
+'tog-enotifwatchlistpages'    => 'Nthomele molaetša ge letlaka leo ke le tlhapetšego le eba le diphetogo',
 'tog-enotifusertalkpages'     => 'Nromele molaetša ge letlakala la Dipoledišano laka le fetoga',
-'tog-enotifminoredits'        => 'Nromele email ge goba le diphetogo tše nnyenyane go matlakala',
+'tog-enotifminoredits'        => 'Ethomele e-mail ge goba le diphetogo tše nnyenyane go matlakala',
 'tog-enotifrevealaddr'        => 'Bonagatša email atrese go temošo tša poso',
 'tog-shownumberswatching'     => 'Laetša palo bašomiši bao ba tlhapetšego',
 'tog-fancysig'                => 'Tsaeno ya gose fihliwe',
@@ -196,8 +196,8 @@ $messages = array(
 'protect'           => 'Lota',
 'protect_change'    => 'Fetola go lotega',
 'protectthispage'   => 'Lota letlakala le',
-'unprotect'         => 'Tloša go lota',
-'unprotectthispage' => 'Tloša go lota letlakaleng',
+'unprotect'         => 'Fetola go lota',
+'unprotectthispage' => 'Fetola go lota letlakaleng',
 'newpage'           => 'Letlakala le lempsha',
 'talkpage'          => 'Rêrišana ka letlakala le',
 'talkpagelinktext'  => 'Bolela',
@@ -225,6 +225,7 @@ $messages = array(
 'jumpto'            => 'Taboga go:',
 'jumptonavigation'  => 'Tšweletšo',
 'jumptosearch'      => 'fetleka',
+'pool-errorunknown' => 'Phošo yago setsebege',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => 'Mabapi le {{SITENAME}}',
@@ -455,7 +456,8 @@ oka [[Special:Search/{{PAGENAME}}|fetleka leina la letlakala]] matlakaleng a man
 <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} fetleka "logs"],
  goba [{{fullurl:{{FULLPAGENAME}}|action=edit}} wa fetola letlakala le]</span>.',
 'note'                             => "'''Ela hloko:'''",
-'previewnote'                      => "'''Ye ke Taetšo ya sebopego sa letlakala fela; diphetogo ga di ya bolokwa!'''",
+'previewnote'                      => "'''Elelwa gore ye ke taetšo ya sebopego sa letlakala fela.'''
+Diphetogo tša gago ga šetšo di bolokwa!",
 'editing'                          => 'O fetola $1',
 'editingsection'                   => 'Phetolo ya $1 (sekgoba)',
 'editingcomment'                   => 'O fetola $1 (sekgao se sempsha)',
@@ -542,7 +544,7 @@ fetola tshenolo',
 'revertmerge' => 'Tloša kopaganyo',
 
 # Diffs
-'history-title'           => 'Histori ya diphetogo tša "$1"',
+'history-title'           => 'Poeletšo ya diphetogo tša "$1"',
 'difference'              => '(Phapang magareng ga dipoeletšo)',
 'lineno'                  => 'Mothalo $1:',
 'compareselectedversions' => 'Bapetša diphapang tšeo di kgethilwego',
@@ -836,10 +838,10 @@ Matlakala ago ba [[Special:Watchlist|lenanong la gago la matlakala ditlhapetšo]
 'booksources-go'            => 'Sepela',
 
 # Special:Log
-'specialloguserlabel'  => 'Mošomiši:',
-'speciallogtitlelabel' => 'Thaetlele:',
+'specialloguserlabel'  => 'Modiri:',
+'speciallogtitlelabel' => 'Thaetlele (goba mošumiši):',
 'log'                  => "Di-''log''",
-'all-logs-page'        => "Di-''log'' kamoka",
+'all-logs-page'        => "Di-''log'' tša bohle ka moka",
 
 # Special:AllPages
 'allpages'       => 'Matlakala ka moka',
@@ -860,7 +862,7 @@ Matlakala ago ba [[Special:Watchlist|lenanong la gago la matlakala ditlhapetšo]
 'deletedcontributions-title' => 'Diabe tša mošomiši tšeo di phumutšwego',
 
 # Special:LinkSearch
-'linksearch'      => 'Dihlomaganyo tša ntle',
+'linksearch'      => 'Fehleka dihlomaganyo tša ntle',
 'linksearch-ok'   => 'Fetleka',
 'linksearch-line' => '$1 e kgokaganywa gotšwa $2',
 
@@ -873,13 +875,13 @@ Matlakala ago ba [[Special:Watchlist|lenanong la gago la matlakala ditlhapetšo]
 # Special:ListGroupRights
 'listgrouprights-members' => '(Lenano la ditho)',
 
-# E-mail user
+# Email user
 'emailuser'      => 'Romela mošomiši yo molaetša',
 'emailpage'      => 'Romela email go mošomiši',
 'noemailtitle'   => 'Gago email atrese',
-'emailfrom'      => 'Go tšwa go',
-'emailsubject'   => 'Sebolelwa',
-'emailmessage'   => 'Molaetša',
+'emailfrom'      => 'Go tšwa go:',
+'emailsubject'   => 'Sebolelwa:',
+'emailmessage'   => 'Molaetša:',
 'emailsend'      => 'Romela',
 'emailccme'      => 'Nromela kopi ya melaetša.',
 'emailccsubject' => 'Kopi ya molaetša wa gago goya go $1: $2',
@@ -933,7 +935,7 @@ Lebelela $2 go hweetša sedi ka diphulo tša bjale.',
 
 # Rollback
 'rollbacklink' => 'bošetša morago',
-'editcomment'  => "Ahlaahlo ya phetogo ke : \"''\$1''\".",
+'editcomment'  => "Ahlaahlo ya phetogo e bile : \"''\$1''\".",
 
 # Protect
 'protectlogpage'              => "''Log'' yago lota",
@@ -957,7 +959,7 @@ Seemo sa go lota ga letlakala '''$1''':",
 'protect-expiring'            => 'fetatšatši ke $1 (UTC)',
 'protect-cascade'             => 'Lota matlakala, akaretša le letlakala le (go lota ka kakaretšo)',
 'protect-cantedit'            => 'Ga o kgone go fetola tekano ya bolotego letlakaleng le, ka ge o sena tumello yago bofetola.',
-'protect-expiry-options'      => '2 diiri:2 hours,1 letšatši:1 day,3 matšatši:3 days,1 beke:1 week,2 dibeke:2 weeks,1 kgwedi:1 month,3 digkwedi:3 months,6 dikgwedi:6 months,1 ngwaga:1 year,ga efele:infinite',
+'protect-expiry-options'      => 'iri:1 hour, letšatš1:1 day,beke:1 week,dibeke tše 2:2 weeks,kgwedi:1 month,dikgwedi tše 3:3 months,dikgwedi tše 6:6 months,ngwaga:1 year,gosefele (infinite):infinite',
 'restriction-type'            => 'Tumello:',
 'restriction-level'           => 'Seemo sago Lota:',
 
@@ -993,7 +995,7 @@ Seemo sa go lota ga letlakala '''$1''':",
 'sp-contributions-newbies'     => 'Laetša diabe tša bašumiši ba bafsa fela',
 'sp-contributions-newbies-sub' => 'Tša tšhupaleloko tše mphsa',
 'sp-contributions-blocklog'    => "''Log'' yago thiba",
-'sp-contributions-deleted'     => 'Diabe tša mošomiši tšeo di phumutšwego',
+'sp-contributions-deleted'     => 'diabe tša mošomiši tšeo di phumutšwego',
 'sp-contributions-uploads'     => 'di-"upload"',
 'sp-contributions-logs'        => "Di-''log''",
 'sp-contributions-talk'        => 'Poledišano',
