@@ -28,20 +28,20 @@ $messages = array(
 'tog-editsectiononrightclick' => "Pérmet l'édichion del sekchion par un droé buke su ch'tite del sekchion (i feut JavaScript)",
 'tog-showtoc'                 => "Aficher l'tabe ed ches étnus (pou ches paches aveuc plu ed 3 intétes)",
 'tog-rememberpassword'        => "Warder min lodjine su chl'ordinateu-lo (pour un maximum éd $1 {{PLURAL:$1|jour|jours}})",
-'tog-watchcreations'          => "Ajouter chés paches qu'éj crée dseu em lisse",
-'tog-watchdefault'            => "Ajouter chés paches qu'éj édite dseu em lisse.",
-'tog-watchmoves'              => "Ajouter chés paches qu'éj déplache dseu m'lisse.",
-'tog-watchdeletion'           => "Ajouter chés paches qu'éj déface dseur m'lisse.",
+'tog-watchcreations'          => "Ajouter chés paches qu'éj crée et pi chés fichiés qu'éj téléquertche édseur em lisse à suire",
+'tog-watchdefault'            => "Ajouter chés paches pi chés fichiés qu'éj cange édseur em lisse à suire.",
+'tog-watchmoves'              => "Ajouter chés paches pi chés fichiés qu'éj déplache édseur m'lisse à suire.",
+'tog-watchdeletion'           => "Ajouter chés paches pi chés fichiés qu'éj déface édseur m'lisse à suire.",
 'tog-previewontop'            => "Aficher l'prévue édvint el bouéte édite",
 'tog-previewonfirst'          => "Aficher l'prévue au preumié édite.",
-'tog-enotifwatchlistpages'    => "Éspédier din m'boéte un imèle quante eune pache su m'lisse est candgée",
+'tog-enotifwatchlistpages'    => "M'éspédier un imèle quante eune pache su m'lisse à suire est cangée",
 'tog-enotifusertalkpages'     => 'Éspédier un imèle su em bouéte quante m\'pache "Dvise Uzeu" est candgée.',
-'tog-enotifminoredits'        => 'Éspédier à mi étous un imèle pou ches tiots édites éd ches paches',
+'tog-enotifminoredits'        => "M'éspédier étou un imèle pou chés tiots canjemints d'chés paches o d'chés fichiés",
 'tog-shownumberswatching'     => "Aficher ch'nombe ed gins qu'ont vu.",
-'tog-watchlisthideown'        => 'Muche mes édites dseur el lisse',
-'tog-watchlisthidebots'       => 'Muche ches robots édites su el lisse',
-'tog-watchlisthideminor'      => 'Muche ches tiots édites su el lisse.',
-'tog-watchlisthideliu'        => 'Muche ches édites ed ches lodjés gins su el lisse.',
+'tog-watchlisthideown'        => 'Muche ems édicions dseur el lisse à suire',
+'tog-watchlisthidebots'       => 'Muche chés édicions des robots su el lisse à suire',
+'tog-watchlisthideminor'      => 'Muche chés tiotes édicions su el lisse à suire.',
+'tog-watchlisthideliu'        => 'Muche chés édicions ed ches lodjés gins su el lisse.',
 'tog-watchlisthideanons'      => 'Muche ches édites ed ches gins annonimes su el lisse.',
 'tog-watchlisthidepatrolled'  => 'Muche ches édites pormenés su el lisse.',
 'tog-ccmeonemails'            => "Éspédier din m'bouéte ches copies ed ches imèles éq j'éspédie à ches autes uzeus",
@@ -114,13 +114,14 @@ $messages = array(
 'category-empty'                 => "''Din l'catégorie-lo, i n'y o poin d'paches ou d'média.''",
 'hidden-categories'              => '{{PLURAL:$1|Catégorie muchée|Catégories muchées}}',
 'hidden-category-category'       => 'Catégouries muchées',
-'category-subcat-count'          => "{{PLURAL:$2|Chol catégorie o seulemint el sou-catégorie-lo.|Chol catégorie o  {{PLURAL:$1|l'sou-catégorie-lo|$1 sou-catégories}}, pou un total éd $2.}}",
+'category-subcat-count'          => "{{PLURAL:$2|Chol catégorie ale o seulemint el dsou-catégorie-lo:|Chol catégorie ale o  {{PLURAL:$1|l'dsou-catégorie-lo|chés $1 dsou-catégories suivantes}}, pou un total éd $2.}}",
 'category-subcat-count-limited'  => "L'catégorie-lo ale o {{PLURAL:$1|el dsous-catégorie|chés $1 dsous-catégories}} -lo:",
-'category-article-count'         => "{{PLURAL:$2|Chol catégorie o seulemint chol pache-lo.|{{PLURAL:$1|El pache-lo est|$1 Chés paches-lo sont}} din l'catégorie-lo, pou un total éd $2 .}}",
+'category-article-count'         => "Chol catégorie ale o {{PLURAL:$2|seulemint l'pache-lo:|$2 paches, dont{{PLURAL:$1|chelle-chi:|chés $1 paches chi:}} }}",
 'category-article-count-limited' => "{{PLURAL:$1|L' pache d'apré ale est|Chés $1 paches d'apré sont}} dins l'catégorie-lo.",
-'category-file-count'            => "{{PLURAL:$2|Chol catégorie o seulemint chol fichié-lo.|{{PLURAL:$1|Ech fichier-lo est|$1 Chés fichiés-lo sont}} din l'catégorie-lo, pou un total éd $2 fichiés.}}",
+'category-file-count'            => 'Chol catégorie ale o  {{PLURAL:$2|seulemint ech fichié-lo:|$2 fichiés dont chés $1 fichiés suivants:}}',
 'category-file-count-limited'    => "{{PLURAL:$1|Ech fichié d'apré est|Chés $1 fichiés d'apré sont}} dins l'catégorie-lo.",
 'listingcontinuesabbrev'         => 'cont.',
+'noindex-category'               => 'Paches nin indécsées',
 'broken-file-category'           => "Paches aveuc des loïens d'fichiés bérzillés",
 
 'about'         => 'À pérpos',
@@ -128,8 +129,8 @@ $messages = array(
 'newwindow'     => '(ouvrir din eune nouvèle fernéte)',
 'cancel'        => 'Canchler',
 'moredotdotdot' => 'Plu...',
-'mypage'        => 'Em pache',
-'mytalk'        => 'Mi bavouér',
+'mypage'        => 'Pache',
+'mytalk'        => 'Min bavouér',
 'anontalk'      => "Bavouér pou chl'IP-lo",
 'navigation'    => 'Navigachon',
 'and'           => '&#32;pi',
@@ -152,7 +153,7 @@ $messages = array(
 'vector-action-protect'          => 'Garantir',
 'vector-action-undelete'         => "N'poin défacher",
 'vector-action-unprotect'        => "Canger l'garantie",
-'vector-simplesearch-preference' => "Déhousser chés avanches d'ércherche améliorées (seulemint pour Vector)",
+'vector-simplesearch-preference' => "Actionner l'barette pour chés traches simpes (seulemint pour l'habillure Vector)",
 'vector-view-create'             => 'Créer',
 'vector-view-edit'               => 'Éditer',
 'vector-view-history'            => "Vir l'histoère",
@@ -314,10 +315,15 @@ Si s'n'est poin ch'cas-lo, pététe éq ch'est un bogue din ch'businkillache. <b
 'virus-unknownscanner' => 'intivirus poin connu:',
 
 # Login and logout pages
+'welcomecreation'         => "== Binv'nute, $1 ! ==
+
+Vote compte o té créé.
+N'obliez poin d'parsonnaliser vos [[Special:Preferences|préférinches édseur {{SITENAME}}]].",
 'yourname'                => "nom d'uzeu:",
 'yourpassword'            => "Mot d'passe:",
 'yourpasswordagain'       => "Intrer à nouvieu ch'mot d'passe:",
 'remembermypassword'      => "Intrer oùtonmatiquemint l'prochaine fouos (pour un maximum éd $1 {{PLURAL:$1|jour|jours}})",
+'securelogin-stick-https' => "Réster connécté in HTTPS apré l'connécsion",
 'yourdomainname'          => 'Vote donmène:',
 'login'                   => 'Intrer',
 'nav-login-createaccount' => 'Intrer / créer vote conpte',
@@ -331,6 +337,7 @@ Si s'n'est poin ch'cas-lo, pététe éq ch'est un bogue din ch'businkillache. <b
 'createaccount'           => 'Créer un conpte',
 'gotaccount'              => "Jou qu'os avez piécha un conpte? '''$1'''.",
 'gotaccountlink'          => 'Intrer',
+'userlogin-resetlink'     => "Vos avez oblié vous détals d'connécsion ?",
 'createaccountmail'       => 'par imèle',
 'badretype'               => "Chés mots d'passe intrés, is sont poin bon.",
 'userexists'              => "Nom d’utilisateur entré déjà utilisé.
@@ -356,6 +363,12 @@ j'm'escuse mais i feut prinde un aute nom.",
 'resetpass_forbidden'       => "Chés mots d'passe is n'peu'te poin ète cangés",
 'resetpass-submit-loggedin' => "Canger ch'mot d'passe",
 
+# Special:PasswordReset
+'passwordreset' => "Ortreuver ch'mot d'passe",
+
+# Special:ChangeEmail
+'changeemail' => "Canger l'adrèche du imèle",
+
 # Edit page toolbar
 'bold_sample'     => 'Cros teske',
 'bold_tip'        => 'Cros teske',
@@ -409,11 +422,22 @@ Os prométtez auchi éq vos avez écrit ch'teske vous-méme, ou éq vos l’avez
 'template-semiprotected'           => '(semi-garanti)',
 'hiddencategories'                 => '{{PLURAL:$1|Catégorie muchée|Catégories muchées}} pou chol pache:',
 'permissionserrorstext-withaction' => "Vos n’avez poin l'pérmichon éd $2, pou {{PLURAL:$1|ch'motif suivant|chés motifs suivants}}:",
+'recreate-moveddeleted-warn'       => "'''Afute ! : Os ètes in route à ércréer eune pache qu'o té abolie édvant.'''
+
+Controler qu'ch'est pértinint d' porsuire chés modificacions édseur chol pache. L'jornal des défacions pi des déplachemints l'est affiké chi-édsous :",
+'moveddeleted-notice'              => "Chol pache ale o té abolie. L'jornal des défacions pi des déplachemints il est affiké chi-édsous pour référinche.",
+
+# Parser/template warnings
+'post-expand-template-inclusion-warning'  => "Affute : Chèle pache ale a trop d’modèles. Des inclusions n'sront poin foaites.",
+'post-expand-template-inclusion-category' => "Paches aveuc granmint d'modèles",
+'post-expand-template-argument-warning'   => "Afute : Chol pache ale o au moins un paramète d'modèle dont l'inclusion est rindue impossibe. Apré éstinsion, chti-chi il éroait produit un résultat trop long, i n'a donc poin té inclus.",
+'post-expand-template-argument-category'  => "Paches aveuc des paramètes d'modèle mie évalués",
 
 # History pages
 'viewpagelogs'           => 'Vir chés gasètes del pache-lo',
 'currentrev-asof'        => 'Coursaule vérchon in date du $1',
 'revisionasof'           => 'Ércordé conme $1',
+'revision-info'          => 'Version du $1 pèr $2',
 'previousrevision'       => '← érvue dvant',
 'nextrevision'           => 'Cangemint pu nouvieu →',
 'currentrevisionlink'    => 'Érvision éd qhére',
@@ -424,56 +448,83 @@ Os prométtez auchi éq vos avez écrit ch'teske vous-méme, ou éq vos l’avez
 'histlegend'             => "Diff séléccion: buke chés boétes d'chés canjemints à comparète pi détriquer intrer ou ch'bouton édsou.<br />
 Léginde : ({{MediaWiki:Cur}}) = différinches aveuc el vérchon à ch'momint-chi, ({{MediaWiki:Last}}) = différinches aveuc el vérchon édvant, <b>m</b> = tiot canjemint.",
 'history-fieldset-title' => "S'déplacher din l'historique",
+'history-show-deleted'   => 'Défacés seulemint',
 'histfirst'              => 'preumières paches',
 'histlast'               => 'Darin',
 
+# Revision feed
+'history-feed-item-nocomment' => '$1 à $2',
+
 # Revision deletion
-'rev-delundel'   => 'montrer/mucher',
-'revdel-restore' => 'cange écmint vir',
-'pagehist'       => 'Histoère del pache',
+'rev-delundel'           => 'montrer/mucher',
+'revdel-restore'         => 'cange écmint vir',
+'revdel-restore-deleted' => 'canjemints abolis',
+'revdel-restore-visible' => 'canjemints visibes',
+'pagehist'               => 'Histoère del pache',
 
 # Merge log
 'revertmerge' => "N'poin mélinger",
 
 # Diffs
-'history-title'           => 'Histoère des cangemints éd "$1"',
+'history-title'           => 'Historike des canjemints éd "$1"',
 'difference'              => '(Diférinche intre chés érvisions)',
 'lineno'                  => 'Line $1:',
 'compareselectedversions' => 'Compérer chés couésies contérbuchons',
 'editundo'                => "n'poin foaire",
+'diff-multi'              => '({{PLURAL:$1|Un canjemint intarmédiaire|$1 canjemints intarmédiaires}} par {{PLURAL:$2|un uzeu|$2 uzeus}} {{PLURAL:$1|est muché|sont muchées}})',
 
 # Search results
-'searchresults'             => 'Tracher chés résultats',
-'searchresults-title'       => 'Tracher chés résultats pou "$1"',
-'searchresulttext'          => "Pou pus d'informachons quant qu'vos trachez {{SITENAME}}, vir [[{{MediaWiki:Helppage}}|{{int:help}}]].",
-'searchsubtitle'            => "Vos trachez  « '''[[:$1]]''' » ([[Special:Prefixindex/$1|toutes chés paches aroutant pèr « $1 »]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|toutes chés paches qu'ont un loïen dsus « $1 »]])",
-'searchsubtitleinvalid'     => "vos trachez apreu '''$1'''",
-'notitlematches'            => "Éj déniche mie d'pache aveuc ch'tite-lo",
-'textmatches'               => 'Teske del pache déniché',
-'notextmatches'             => "I n'y o poin d'pache aveuc ch'teske-lo",
-'prevn'                     => 'dvant {{PLURAL:$1|$1}}',
-'nextn'                     => 'apreu {{PLURAL:$1|$1}}',
-'prevn-title'               => 'Dvant $1 {{PLURAL:$1|résultat|résultats}}',
-'viewprevnext'              => 'Vir ($1 {{int:pipe-separator}} $2) ($3)',
-'search-result-size'        => '$1 ({{PLURAL:$2|1 mot|$2 mots}})',
-'search-redirect'           => '(érdirection $1)',
-'search-section'            => '(sekchon $1)',
-'search-suggest'            => 'Cha vo ti dire: $1',
-'search-interwiki-caption'  => 'Proujé analocq',
-'search-interwiki-default'  => '$1 résultats:',
-'search-interwiki-more'     => '(pus)',
-'search-mwsuggest-enabled'  => 'aveuc avanches',
-'search-mwsuggest-disabled' => "mie d'avanches",
-'nonefound'                 => "'''Note''': il y o tasseulemint quéques éspaces éd noms éq sont trachés pèr défeut. <br /> Pou tracher din tous chés contnus (paches éd pérlache, modéles, etc... comprins) insséyer in imploéyant ch'préfixe ''all:'' o bin imploéyer echl éspace éd noms édmindé conme préfixe.",
-'powersearch'               => 'Érvue avanchée',
-'powersearch-legend'        => 'Érvue avanchée',
-'powersearch-ns'            => 'Tracher din chés éspaches éd chés noms:',
-'powersearch-redir'         => "Lisse d'chés érdirécchons",
-'powersearch-field'         => 'Tracher pou',
+'searchresults'                    => 'Tracher chés résultats',
+'searchresults-title'              => 'Tracher chés résultats pou "$1"',
+'searchresulttext'                 => "Pou pus d'informachons quant qu'vos trachez {{SITENAME}}, vir [[{{MediaWiki:Helppage}}|{{int:help}}]].",
+'searchsubtitle'                   => "Vos trachez  « '''[[:$1]]''' » ([[Special:Prefixindex/$1|toutes chés paches aroutant pèr « $1 »]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|toutes chés paches qu'ont un loïen dsus « $1 »]])",
+'searchsubtitleinvalid'            => "vos trachez apreu '''$1'''",
+'notitlematches'                   => "Éj déniche mie d'pache aveuc ch'tite-lo",
+'textmatches'                      => 'Teske del pache déniché',
+'notextmatches'                    => "I n'y o poin d'pache aveuc ch'teske-lo",
+'prevn'                            => 'dvant {{PLURAL:$1|$1}}',
+'nextn'                            => 'apreu {{PLURAL:$1|$1}}',
+'prevn-title'                      => 'Dvant $1 {{PLURAL:$1|résultat|résultats}}',
+'nextn-title'                      => "$1 {{PLURAL:$1|résultat d'apré|résultats d'apré}}",
+'shown-title'                      => 'Montrer $1 résultat{{PLURAL:$1||s}} pèr pache',
+'viewprevnext'                     => 'Vir ($1 {{int:pipe-separator}} $2) ($3)',
+'searchmenu-exists'                => "'''Il y o eune pache lonmée « [[:$1]] » édseur ch'wiki'''",
+'searchmenu-new'                   => "'''Créer l'pache « [[:$1|$1]] » édseur ech wiki !'''",
+'searchprofile-articles'           => "Paches d'étnu",
+'searchprofile-project'            => "Paches d’aïude et pi d'prodjé",
+'searchprofile-images'             => 'Multimédia',
+'searchprofile-everything'         => 'Tout',
+'searchprofile-advanced'           => 'Értrache avanchée',
+'searchprofile-articles-tooltip'   => 'tracher dins $1',
+'searchprofile-project-tooltip'    => 'Tracher dins $1',
+'searchprofile-images-tooltip'     => 'Tracher des fichiés multimédias',
+'searchprofile-everything-tooltip' => "Tracher dins tout ch'wikipédia (et ochi dins chés paches éd distchucion)",
+'searchprofile-advanced-tooltip'   => "Couésir chés éspaches d'noms pour l'értrache",
+'search-result-size'               => '$1 ({{PLURAL:$2|1 mot|$2 mots}})',
+'search-result-category-size'      => '$1 mimbe{{PLURAL:$1||s}} ($2 édsous-catégorie{{PLURAL:$2||s}}, $3 fichié{{PLURAL:$3||s}})',
+'search-redirect'                  => '(érdirection $1)',
+'search-section'                   => '(sekchon $1)',
+'search-suggest'                   => 'Cha vo ti dire: $1',
+'search-interwiki-caption'         => 'Proujé analocq',
+'search-interwiki-default'         => '$1 résultats:',
+'search-interwiki-more'            => '(pus)',
+'search-mwsuggest-enabled'         => 'aveuc avanches',
+'search-mwsuggest-disabled'        => "mie d'avanches",
+'searchrelated'                    => 'relaté',
+'searchall'                        => 'tout',
+'showingresultsheader'             => "{{PLURAL:$5|Résultat '''$1'''|Résultats '''$1–$2'''}} éd '''$3''' pour '''$4'''",
+'nonefound'                        => "'''Note''': il y o tasseulemint quéques éspaces éd noms éq sont trachés pèr défeut. <br /> Pou tracher din tous chés contnus (paches éd pérlache, modéles, etc... comprins) insséyer in imploéyant ch'préfixe ''all:'' o bin imploéyer echl éspace éd noms édmindé conme préfixe.",
+'search-nonefound'                 => 'Y a autchun résultat pour chol dmanne.',
+'powersearch'                      => 'Érvue avanchée',
+'powersearch-legend'               => 'Érvue avanchée',
+'powersearch-ns'                   => 'Tracher din chés éspaches éd chés noms:',
+'powersearch-redir'                => "Lisse d'chés érdirécchons",
+'powersearch-field'                => 'Tracher pou',
 
 # Preferences page
 'preferences'               => 'Préférinches',
 'mypreferences'             => 'Mes préférinches',
+'changepassword'            => "Canger ch'mot d'passe",
 'timezoneregion-europe'     => 'Urope',
 'youremail'                 => 'Imèle:',
 'username'                  => "Nom d'uzeu:",
@@ -486,14 +537,18 @@ Ale doét mie éte pu longue éq $1 {{PLURAL:$1|caracter|caractéres}}.',
 'gender-male'               => 'Marle',
 'gender-female'             => 'Femelle',
 'email'                     => 'Imèle',
+'prefs-help-email'          => "L’adrèche du courrièl est facultative, mais ale est nécessaire pour artreuver vote mot d'passe, si vos vnoète à l’oblier.",
+'prefs-help-email-others'   => "Os pouvez auchi couésir d'laicher les eutes vos contacter par imèle aveuc un loïen édseur vote pache éd distchussion d'uzeu sans qu'i soèche nécessaire ed révéler vote idintité.",
 'prefs-help-email-required' => 'I feut eune iméle adérche',
 
 # User rights
 'userrights-groupsmember' => 'Mimbe éd:',
 
 # Groups
-'group-sysop'      => 'Aménistrateus',
-'group-bureaucrat' => 'Buroécrates',
+'group-user'          => 'Uzeus',
+'group-autoconfirmed' => 'Uzeus inrégistrés',
+'group-sysop'         => 'Aménistrateus',
+'group-bureaucrat'    => 'Buroécrates',
 
 'group-sysop-member'      => '{{GENDER:$1|aménistrateu|aménistratriche}}',
 'group-bureaucrat-member' => '{{GENDER:$1|buroécrate}}',
@@ -504,47 +559,86 @@ Ale doét mie éte pu longue éq $1 {{PLURAL:$1|caracter|caractéres}}.',
 'rightslog' => "Jornal d'chés droés dechl uzeu",
 
 # Associated actions - in the sentence "You do not have permission to X"
-'action-read' => "Vir l'pache-lo",
-'action-edit' => "édite l'pache-lo",
+'action-read'               => "Vir l'pache-lo",
+'action-edit'               => "édite l'pache-lo",
+'action-createpage'         => 'créer des paches',
+'action-createtalk'         => 'créer des paches éd dichtchussion',
+'action-createaccount'      => "créer ech compte d'uzeu",
+'action-minoredit'          => 'mértcher chol canjemint conme mineur',
+'action-move'               => "érlonmer l'pache-lo",
+'action-move-subpages'      => 'érlonmer chol pache et pi ses dsous-paches',
+'action-move-rootuserpages' => "érlonmer l' pache princhipale d’un uzeu",
+'action-movefile'           => "érlonmer ch'fichié-lo",
+'action-upload'             => 'téléquértcher ech fichié',
+'action-reupload'           => "écatir l'anchien fichié",
+'action-upload_by_url'      => "téléquértcher ch' fichié à partir d’eune URL",
+'action-writeapi'           => "foaire aveuc l'écrivure API",
+'action-delete'             => "Défacer l'pache-lo",
+'action-deleterevision'     => "défacer ch'canjemint-lo",
+'action-deletedhistory'     => 'vir l’histoère muchée éd chol pache',
+'action-browsearchive'      => 'tracher des paches défacées',
+'action-undelete'           => "n'poin défacer chol pache",
+'action-suppressrevision'   => 'vir pi érfoaire chol version muchée',
+'action-suppressionlog'     => 'vir ech jornal privé',
+'action-block'              => "blotcher l'écrivure éd chol uzeu-lo",
+'action-import'             => 'téléquértcher chol pache à partir d’un eute wiki',
+'action-importupload'       => "téléquértcher chol pache à partir d'un fichié",
 
 # Recent changes
-'nchanges'                       => '$1 {{PLURAL:$1|cange|canges}}',
-'recentchanges'                  => 'Darins canjemints',
-'recentchanges-legend'           => 'Opchons éd chés nouvieus canjemints',
-'recentchanges-feed-description' => 'Tracher chés pus darins cangemints du wiki din chol alimintachon.',
-'rcnote'                         => "Vlo {{PLURAL:$1|ech darin canjemint foait|chés $1 darins canjemints foaits}} din {{PLURAL:$2|l'darinne jornèe|chés <b>$2</b> darins jours}} dusque  l' $4 à $5.",
-'rclistfrom'                     => "Montrer chés nouvieus cangemints d'puis $1",
-'rcshowhideminor'                => '$1 tiotes éditions',
-'rcshowhidebots'                 => '$1 bots',
-'rcshowhideliu'                  => '$1 lodjés uzeus',
-'rcshowhideanons'                => '$1 uzeus anonimes',
-'rcshowhidemine'                 => '$1 ems éditions',
-'rclinks'                        => 'Afiqher chés $1 darins canjemints din chés $2 darins jours<br />$3',
-'diff'                           => 'dif',
-'hist'                           => 'hist',
-'hide'                           => 'Mucher',
-'show'                           => 'Montrer',
-'minoreditletter'                => 'm',
-'newpageletter'                  => 'N',
-'boteditletter'                  => 'b',
-'rc-enhanced-expand'             => 'Montrer chés détals (i feut avoér JavaScript)',
-'rc-enhanced-hide'               => 'Mucher chés détals',
+'nchanges'                        => '$1 {{PLURAL:$1|cange|canges}}',
+'recentchanges'                   => 'Darins canjemints',
+'recentchanges-legend'            => 'Opchons éd chés nouvieus canjemints',
+'recentchanges-feed-description'  => 'Tracher chés pus darins cangemints du wiki din chol alimintachon.',
+'recentchanges-label-newpage'     => 'Chol modificacion ale o créé eune nouvèle pache',
+'recentchanges-label-minor'       => "C'est un tiot canjemint",
+'recentchanges-label-bot'         => 'Chol modificacion ale o té foaite pèr un robot.',
+'recentchanges-label-unpatrolled' => 'Chol modificacion ale n’o poin coèr té controlée.',
+'rcnote'                          => "Vlo {{PLURAL:$1|ech darin canjemint foait|chés $1 darins canjemints foaits}} din {{PLURAL:$2|l'darinne jornèe|chés <b>$2</b> darins jours}} dusque  l' $4 à $5.",
+'rcnotefrom'                      => "Vlo chés modificacions foaites édpuis l' '''$2''' (dousqu'à '''$1''' au plus).",
+'rclistfrom'                      => "Montrer chés nouvieus cangemints d'puis $1",
+'rcshowhideminor'                 => '$1 tiotes éditions',
+'rcshowhidebots'                  => '$1 bots',
+'rcshowhideliu'                   => '$1 lodjés uzeus',
+'rcshowhideanons'                 => '$1 uzeus anonimes',
+'rcshowhidepatr'                  => '$1 chés modificacions wardées',
+'rcshowhidemine'                  => '$1 ems éditions',
+'rclinks'                         => 'Afiqher chés $1 darins canjemints din chés $2 darins jours<br />$3',
+'diff'                            => 'dif',
+'hist'                            => 'hist',
+'hide'                            => 'Mucher',
+'show'                            => 'Montrer',
+'minoreditletter'                 => 'm',
+'newpageletter'                   => 'N',
+'boteditletter'                   => 'b',
+'rc-enhanced-expand'              => 'Montrer chés détals (i feut avoér JavaScript)',
+'rc-enhanced-hide'                => 'Mucher chés détals',
 
 # Recent changes linked
-'recentchangeslinked'         => 'Darins canjemints érliés',
-'recentchangeslinked-title'   => 'Cangemints à pérpos éd "$1"',
-'recentchangeslinked-summary' => "Ch'est eune lisse d'chés darins canjemints su chés paches qu'ont un loïen aveuc l'pache-lo. Chés paches din vote [[Special:Watchlist|''lisse à suire'']] il sont in '''cros'''.",
-'recentchangeslinked-page'    => 'Nom del pache:',
-'recentchangeslinked-to'      => "Vir putot chés canjemints d'chés paches aveuc un loïen su l'pache-lo",
+'recentchangeslinked'          => 'Darins canjemints érliés',
+'recentchangeslinked-toolbox'  => 'Suivi des paches loïées',
+'recentchangeslinked-title'    => 'Cangemints à pérpos éd "$1"',
+'recentchangeslinked-noresult' => "I n’y a poin d' modificacion des paches loïées pindant l'période couésie.",
+'recentchangeslinked-summary'  => "Ch'est eune lisse d'chés darins canjemints su chés paches qu'ont un loïen aveuc l'pache-lo. Chés paches din vote [[Special:Watchlist|''lisse à suire'']] il sont in '''cros'''.",
+'recentchangeslinked-page'     => 'Nom del pache:',
+'recentchangeslinked-to'       => "Vir putot chés canjemints d'chés paches aveuc un loïen su l'pache-lo",
 
 # Upload
 'upload'        => 'Quértcher chés fichiés',
 'uploadlogpage' => 'Jornal éd chés quértchémints',
+'filedesc'      => 'Résumè',
 'uploadedimage' => '"[[$1]]" quértchée',
 
+'license'        => 'Licince',
+'license-header' => 'Licince',
+
+# Special:ListFiles
+'listfiles' => 'Lisse des fichiés',
+
 # File description page
+'file-anchor-link'          => 'Fichié',
 'filehist'                  => 'Histoère dech fichié',
 'filehist-help'             => "Buke su eune date/heure pou vir ch'fichié conme il étoait ach momint-lo.",
+'filehist-revert'           => 'invérser',
 'filehist-current'          => 'courant',
 'filehist-datetime'         => 'Date/Tans',
 'filehist-thumb'            => 'Tiote image',
@@ -552,26 +646,73 @@ Ale doét mie éte pu longue éq $1 {{PLURAL:$1|caracter|caractéres}}.',
 'filehist-user'             => 'Uzeu',
 'filehist-dimensions'       => 'Diminsions',
 'filehist-comment'          => 'Fichié éd chés conmints',
-'imagelinks'                => 'Loïens dech fichié',
+'imagelinks'                => 'Usage dech fichié',
 'linkstoimage'              => "{{PLURAL:$1|L'pache d'apreu est liée|Chés $1 paches d'apreu sont liées}} à ch'fichié-lo :",
-'sharedupload'              => "Cht'fichié vient éd $1 pi i put ète imploïé par d'eutes proujés.",
+'nolinkstoimage'            => "Autchune pache n'est loïée aveuc ch'fichié-lo",
+'sharedupload'              => "Ch'fichié i vient éd $1. I put ète imploïé par d'eutes proujés.",
+'sharedupload-desc-there'   => "Ch'fichié i vient éd $1. I put ète uzé pèr d’eutes prodjés. Vir l'pache [$2 édseur Commons].",
+'sharedupload-desc-here'    => "Ch'fichié i vient éd $1. I put ète uzé pèr d’eutes prodjés.
+Vir l'pache [$2 édseur Commons].",
 'uploadnewversion-linktext' => 'Quértcher eune novèle vérchion del pache-lo',
+'shared-repo-from'          => 'à : $1',
+'shared-repo'               => 'un dépôt partagé',
+
+# MIME search
+'mimesearch' => 'Tracher pèr type éd contenu MIME',
+
+# Unwatched pages
+'unwatchedpages' => 'Paches poin suivies',
+
+# List redirects
+'listredirects' => 'Lisse des érdiréccions',
+
+# Unused templates
+'unusedtemplates' => 'Modèles poin implouéyés',
 
 # Random page
 'randompage' => "Pache à l'bérlure",
 
 # Statistics
-'statistics' => 'Éstatistikes',
+'statistics'       => 'Éstatistikes',
+'statistics-users' => '[[Special:ListUsers|Uzeus]] inrégistrés',
+
+'disambiguations'     => 'Paches aveuc des loïens vers des paches du meume nom',
+'disambiguationspage' => 'Template:Omonymie',
+
+'doubleredirects' => 'Doubes érdireccions',
+
+'brokenredirects' => 'Érdireccions bérzillées',
+
+'withoutinterwiki' => 'Paches sans loïens intar-langues',
+
+'fewestrevisions' => 'Paches les moins canjées',
 
 # Miscellaneous special pages
-'nbytes'        => '$1 {{PLURAL:$1|octé|octés}}',
-'nmembers'      => '$1 {{PLURAL:$1|mimbe|mimbes}}',
-'prefixindex'   => 'Tertous chés paches aveuc préfix',
-'newpages'      => 'Novèles paches',
-'move'          => 'Déplacher',
-'movethispage'  => "Déplacher l'pache-lo",
-'pager-newer-n' => '{{PLURAL:$1|pu nouvieu 1|pu nouvieus $1}}',
-'pager-older-n' => '{{PLURAL:$1|pus viu 1|pus vius $1}}',
+'nbytes'              => '$1 {{PLURAL:$1|octé|octés}}',
+'nmembers'            => '$1 {{PLURAL:$1|mimbe|mimbes}}',
+'lonelypages'         => 'Paches orfelines',
+'uncategorizedpages'  => 'Paches sans catégories',
+'uncategorizedimages' => 'Fichiés sans catégories',
+'unusedcategories'    => 'Catégories poin implouéyées',
+'unusedimages'        => 'Fichiés orfelins',
+'wantedcategories'    => 'Catégories granmint écmindées',
+'wantedpages'         => 'Paches les pus écmindés',
+'wantedfiles'         => 'Fichiés les pus écmindés',
+'wantedtemplates'     => 'Modèles écmindés',
+'prefixindex'         => 'Tertous chés paches aveuc préfix',
+'shortpages'          => 'Courtes paches',
+'longpages'           => 'Paches longues',
+'deadendpages'        => "Paches in tchul d'so",
+'protectedpages'      => 'Paches défènnées',
+'protectedtitles'     => 'Tites défènnés',
+'listusers'           => 'Lisse des uzeus',
+'usercreated'         => '{{GENDER:$3|Créé}} ech $1 à $2',
+'newpages'            => 'Novèles paches',
+'ancientpages'        => 'Paches les pus vieilles',
+'move'                => 'Déplacher',
+'movethispage'        => "Déplacher l'pache-lo",
+'pager-newer-n'       => '{{PLURAL:$1|pu nouvieu 1|pu nouvieus $1}}',
+'pager-older-n'       => '{{PLURAL:$1|pus viu 1|pus vius $1}}',
 
 # Book sources
 'booksources'               => 'Sources dech live',
@@ -595,22 +736,35 @@ Ale doét mie éte pu longue éq $1 {{PLURAL:$1|caracter|caractéres}}.',
 'allpagessubmit'    => 'Aler',
 'allpagesprefix'    => "Foaire vir chés paches aveuc ch'préfix:",
 
+# Special:Categories
+'categories' => 'Lisse des catégories',
+
+# Special:DeletedContributions
+'deletedcontributions'       => 'Contérbuchons abolies',
+'deletedcontributions-title' => 'Contérbuchons abolies',
+
 # Special:LinkSearch
-'linksearch' => 'Loïens éstérieurs',
+'linksearch'      => 'Loïens éstérieurs',
+'linksearch-line' => '$1 est loïé édpuis $2',
+
+# Special:ActiveUsers
+'activeusers' => 'Lisse des ouvreus uzeus',
 
 # Special:Log/newusers
 'newuserlogpage' => "Jornal éd chés créachons d'comptes d'uzeu",
 
 # Special:ListGroupRights
+'listgrouprights-summary' => "L'pache-lo ch'est ène lisse d'chés groupes d'uzeus définis édseur ech wiki aveuc chés drouots d'intrèe achuchonnés.<br />I put y avoèr ichi d'eutes [[MediaWiki:Listgrouprights-helppage|informacions]] édseur chés drouots individuèls. ([[{{MediaWiki:Listgrouprights-helppage}}|vir]])",
 'listgrouprights-members' => '(lisse éd chés mimbes)',
 
-# E-mail user
+# Email user
 'emailuser' => "Imèle echl'uzeu-lo",
 'emailpage' => 'Imèle dech uzeu',
 
 # Watchlist
 'watchlist'         => 'Em lisse à suire',
 'mywatchlist'       => "M'lisse à suire",
+'watchlistfor2'     => 'Pour $1 $2',
 'addedwatchtext'    => "L' pache « [[:$1]] » o té rajoutée à vote [[Special:Watchlist|lisse à suire]].<br /> Chés  canjemints à vnir del pache-lo pi del page éd pérlache sront mis din l'lisse. L'pache sro '''in cros''' din el [[Special:RecentChanges|lisse d'chés darins canjemints]] pou les értreuver fachilmint. Pou értirer chol pache del ''lisse à suire'', bukez su « {{MediaWiki:Unwatch}} ».",
 'removedwatchtext'  => "L'pache « [[:$1]] » o té értirée éd vote [[Special:Watchlist|lisse à suire]].",
 'watch'             => 'Suire',
@@ -627,7 +781,8 @@ Ale doét mie éte pu longue éq $1 {{PLURAL:$1|caracter|caractéres}}.',
 # Delete
 'deletepage'            => "Défacer l'pache",
 'confirmdeletetext'     => "Vos alez défacer eune pache ou un fichié aveuc toutes chés antieusses vérchons.<br /> Confreumer éq ch'est cho éq vos voulez foaire, éq vos conprindez chés consécanches et pi éq ch'est bin s'lon el [[{{MediaWiki:Policy-url}}|politique éd MédiaWiki]].",
-'actioncomplete'        => 'Plònne acchon',
+'actioncomplete'        => 'Accion toute piéte',
+'actionfailed'          => "L’action n'a poin réussi",
 'deletedtext'           => "« $1 » o té défacé.
 Vir $2 pou eune lisse d'chés darinnes défachons.",
 'dellogpage'            => 'jornal éd chés défacions',
@@ -669,7 +824,10 @@ Vlo chés réglages del pache '''$1''' à ch'momint-chi:",
 'restriction-level'           => 'Nivieu éd réstricchon:',
 
 # Undelete
-'undeletelink' => 'vir/érfoaire',
+'undelete'         => 'Vir chés paches abolies',
+'viewdeletedpage'  => 'Vir chés paches abolies',
+'undeletelink'     => 'vir/érfoaire',
+'undeleteviewlink' => 'Vir',
 
 # Namespace form on various pages
 'namespace'      => 'Éspace du nom:',
@@ -679,7 +837,7 @@ Vlo chés réglages del pache '''$1''' à ch'momint-chi:",
 # Contributions
 'contributions'       => 'Contérbuchons dechl uzeu',
 'contributions-title' => 'Contérbuchons dechl uzeu à pérpos éd $1',
-'mycontris'           => 'Ems contérbuchons',
+'mycontris'           => 'Mes contérbuchons',
 'contribsub2'         => 'Pou $1 ($2)',
 'uctop'               => '(darin)',
 'month'               => "Dpuis ch'moés (pi édvant)",
@@ -687,6 +845,10 @@ Vlo chés réglages del pache '''$1''' à ch'momint-chi:",
 
 'sp-contributions-newbies'  => 'Montrer chés contérbuchons éd chés nouvieus conptes seulemint',
 'sp-contributions-blocklog' => 'jornal éd chés blotcåjhes',
+'sp-contributions-deleted'  => 'Contérbuchons abolies',
+'sp-contributions-uploads'  => "téléquértch'mints",
+'sp-contributions-logs'     => 'Gasètes',
+'sp-contributions-talk'     => 'Dviser',
 'sp-contributions-search'   => 'Tracher pou chés contérbuchons',
 'sp-contributions-username' => "Adérche IP ou nom d'uzeu",
 'sp-contributions-toponly'  => "n'montrer qu'chés darins canjemints",
@@ -701,7 +863,7 @@ Vlo chés réglages del pache '''$1''' à ch'momint-chi:",
 'nolinkshere-ns'           => "i n'y o poin d'pache aveuc un loïen vers '''[[:$1]]''' dins echl'éspace d'noms coési.",
 'isredirect'               => 'pache érdirigée',
 'istemplate'               => 'transclusion',
-'isimage'                  => "Loïen aveuc l'imache",
+'isimage'                  => "Loïen aveuc l'fichié",
 'whatlinkshere-prev'       => '{{PLURAL:$1|édvant|édvants $1}}',
 'whatlinkshere-next'       => "{{PLURAL:$1|d'apreu|d'apreu $1}}",
 'whatlinkshere-links'      => '← loïens',
@@ -712,6 +874,7 @@ Vlo chés réglages del pache '''$1''' à ch'momint-chi:",
 'whatlinkshere-filters'    => 'Filtes',
 
 # Block/unblock
+'block'                    => "Blotcher l'uzeu",
 'blockip'                  => "Blotcher l'uzeu",
 'blockip-title'            => "Blotcher l'uzeu",
 'blockip-legend'           => "Blotcher l'uzeu",
@@ -720,6 +883,7 @@ I feut l'foaire seleumint pour inréyer ech vindalime et pi i feut ète acordant
 Donner apré ch'motif  (pèr egzimpe chiter chés paches qu'ont té vindalisées).",
 'ipboptions'               => '2 heures:2 hours,1 jour:1 day,3 jours:3 days,1 ésminne:1 week,2 ésminnes:2 weeks,1 moés:1 month,3 moés:3 months,6 moés:6 months,1 an:1 year,infini:infinite',
 'ipbotheroption'           => 'eute',
+'blocklist'                => 'Uzeus blotchés',
 'ipblocklist'              => 'Uzeus blotchés',
 'blocklink'                => 'blotcher',
 'unblocklink'              => 'déblotcher',
@@ -759,8 +923,13 @@ Din chés cas-lo, I feut érlonmer ou ratatouiller l'pache aveuc l'main.",
 # Export
 'export' => 'Ésporter chés paches',
 
+# Namespace 8 related
+'allmessagesname'    => 'Nom',
+'allmessagesdefault' => 'Messache pèr défeut',
+
 # Thumbnails
-'thumbnail-more' => 'Pu grand',
+'thumbnail-more'  => 'Pu grand',
+'thumbnail_error' => "Bérlurage tandir l'créachon éd la miniature : $1",
 
 # Tooltip help for the actions
 'tooltip-pt-userpage'             => 'Vote pache éd uzeu',
@@ -820,6 +989,7 @@ Os pouvez vir l'source",
 'tooltip-rollback'                => '« Racacher » cancéle aveuc un clic el (ou chés) modificachon(s) del pache-lo pèr sin darin contérbucheu.',
 'tooltip-undo'                    => "« Undo » ( ''démangler'' ) értire ch'canjemint-lo pi ouvre l' fénéte d'édichon din ch'mode ''prévir''. <br /> In put mette un motif din ch'résumé.",
 'tooltip-preferences-save'        => 'Warder chés préférinches.',
+'tooltip-summary'                 => 'Intrer un tiot résumè',
 
 # Browsing diffs
 'previousdiff' => '← Pu vieille édition',
@@ -831,6 +1001,9 @@ Os pouvez vir l'source",
 'svg-long-desc'  => 'Fichié SVG, résoluchon éd $1 × $2 picsels, diminchon: $3',
 'show-big-image' => 'Plinne résoluchon',
 
+# Special:NewFiles
+'newimages' => "Galerie d'chés nouvieus fichiés",
+
 # Bad image list
 'bad_image_list' => "Ch'format ch'est:
 
@@ -879,26 +1052,60 @@ Chés eutes cans is s'ront muchés pèr défeut.
 'watchlisttools-edit' => "Vir pi éditer l'lisse à suire",
 'watchlisttools-raw'  => 'Éditer eune brute lisse à suire',
 
+# Core parser functions
+'duplicate-defaultsort' => "Afute : él cleu d'tri pèr défeut « $2 » écrase l'précédinte « $1 ».",
+
 # Special:Version
 'version-specialpages' => 'Paches éspéchiales',
 
 # Special:FilePath
 'filepath-page' => 'Fichié :',
 
+# Special:FileDuplicateSearch
+'fileduplicatesearch' => 'Dénicher chés doublons',
+
 # Special:SpecialPages
-'specialpages'             => 'Paches éspéchiales',
-'specialpages-group-users' => 'Uzeus pi leus droués',
-'specialpages-group-pages' => "Lisses d'chés paches",
+'specialpages'                   => 'Paches éspéchiales',
+'specialpages-note'              => '----
+* Paches éspéchiales conformes.
+* <span class="mw-specialpagerestricted">Paches éspéchiales réstrintes.</span>
+* <span class="mw-specialpagecached">Paches éspéchiales seulemint in muche (pétète des viuseries).</span>',
+'specialpages-group-maintenance' => "Rapports d'maintenanche",
+'specialpages-group-other'       => 'Eutes paches éspéchiales',
+'specialpages-group-changes'     => 'Darins canjemints pi gazètes',
+'specialpages-group-media'       => "Rapports pi imports d'chés fichiés médias",
+'specialpages-group-users'       => 'Uzeus pi leus droués',
+'specialpages-group-highuse'     => 'Paches bougrémint implouéyées',
+'specialpages-group-pages'       => "Lisses d'chés paches",
+'specialpages-group-pagetools'   => 'Otis pour chés paches',
+'specialpages-group-wiki'        => 'Donnèes pi otis dech Wiki',
+'specialpages-group-redirects'   => 'Paches éspéchiales ardirigées',
 
 # Special:BlankPage
 'blankpage' => 'Blanke pache',
 
+# External image whitelist
+'external_image_whitelist' => " #Laicher chol line egzactemint telle quelle.<pre>
+#Dire chés bérlukes d’éspressions rationnelles (juste l'partie désignée inte chés //) chi-édsous.
+#I correspondront aveuc chés URL des images éstérnes.
+#Chelles qui corresponde'te s’affikeront conme des images, sinon seul un loïen vers l’image i s'ra affiké.
+#Les lines conmençant par un # s'ront considérées conme des conmintaires.
+#Chol lisse n’est mie sensibe à la casse.
+
+#Mettez tous chés bérlukes d’éspressions rationnelles au-d'sus éd chol line. Laichez chol darin.ne line telle quelle.</pre>",
+
+# Special:Tags
+'tags'       => 'Balises des canjemints valides',
+'tag-filter' => 'Filtrer chés [[Special:Tags|balises]] :',
+
 # Special:ComparePages
-'compare-page1'  => 'Pache 1',
-'compare-page2'  => 'Pache 2',
-'compare-rev1'   => 'Canjemint 1',
-'compare-rev2'   => 'Canjemint 2',
-'compare-submit' => 'Aconparer',
+'comparepages'     => 'Compérer dés paches',
+'compare-selector' => 'Compérer chés vèrsions dés paches',
+'compare-page1'    => 'Pache 1',
+'compare-page2'    => 'Pache 2',
+'compare-rev1'     => 'Canjemint 1',
+'compare-rev2'     => 'Canjemint 2',
+'compare-submit'   => 'Aconparer',
 
 # Database error messages
 'dberr-header' => 'Ech wiki-lo il o dés problémes',
