@@ -138,7 +138,7 @@ $messages = array(
 'cancel'        => 'Zerick',
 'moredotdotdot' => 'Mehner…',
 'mypage'        => 'Mei Blatt',
-'mytalk'        => 'Mei Gschwetz-Blatt',
+'mytalk'        => 'Mei Dischbedutt',
 'anontalk'      => 'Gschwetz-Blatt fer die IP',
 'navigation'    => 'Faahre-Gnepp',
 'and'           => '&#32;unn',
@@ -188,7 +188,7 @@ $messages = array(
 'protectthispage'  => 'Des Blatt schitze',
 'newpage'          => 'Neies Blatt',
 'talkpage'         => 'Sell Blatt dischbediere',
-'talkpagelinktext' => 'Gschwetz',
+'talkpagelinktext' => 'Dischbedutt',
 'specialpage'      => 'Besunneres Blatt',
 'personaltools'    => 'Paerseenlich Gscharr',
 'articlepage'      => 'Inhalt vun dem Blatt aagucke',
@@ -429,7 +429,7 @@ Paesswatt fer nau: $2',
 
 # Preferences page
 'preferences'              => 'Paerseenlich Profil',
-'mypreferences'            => 'Mei Uffschtelling',
+'mypreferences'            => 'Uffschtellinge',
 'changepassword'           => 'Paesswatt ennere',
 'skin-preview'             => 'Aagucke',
 'prefs-personal'           => 'Yuuser Profile',
@@ -684,7 +684,7 @@ Paesswatt fer nau: $2',
 'listgrouprights-addgroup'     => 'Yuuser zu {{PLURAL:$2|daer Druppe|denne Druppe}} dezu duh: $1',
 'listgrouprights-addgroup-all' => 'Yuuser zu alle Druppe dezu duh',
 
-# E-mail user
+# Email user
 'emailuser'       => 'E-Poschd fer den Yuuser',
 'defemailsubject' => '{{SITENAME}} - E-Poschde vun Yuuser „$1“',
 'emailusername'   => 'Yuuser-Naame:',
@@ -695,7 +695,7 @@ Paesswatt fer nau: $2',
 
 # Watchlist
 'watchlist'         => 'Mei Watsch-Lischt',
-'mywatchlist'       => 'Mei Watsch-Lischt',
+'mywatchlist'       => 'Watsch-Lischt',
 'watchlistfor2'     => 'Vun $1 $2',
 'watch'             => 'watsche',
 'watchthispage'     => 'watsch des Blatt',
@@ -768,7 +768,7 @@ Guck $2 fer e Lischt vun de letscht Leschunge.',
 'month'               => 'unn Munet:',
 'year'                => 'bis Yaahr:',
 
-'sp-contributions-talk'     => 'Gschwetz',
+'sp-contributions-talk'     => 'Dischbedutt',
 'sp-contributions-search'   => 'Guck fer Ardickel',
 'sp-contributions-username' => 'IP-Adress odder Yuusernaame:',
 'sp-contributions-submit'   => 'Guck uff',
