@@ -12,9 +12,70 @@
  * @author Sylvain2803
  */
 
-$fallback = 'qu';
+$fallback = 'qu, es';
+
+$namespaceNames = array(
+	NS_MEDIA            => 'Midya',
+	NS_SPECIAL          => 'Sapak',
+	NS_TALK             => 'Rimanakuy',
+	NS_USER             => 'Rurak',
+	NS_USER_TALK        => 'Rurakpa_rimanakuy',
+	NS_PROJECT_TALK     => '$1-pa_rimanakuy',
+	NS_FILE             => 'Rikcha',
+	NS_FILE_TALK        => 'Rikchapa_rimanakuy',
+	NS_MEDIAWIKI        => 'MediaWiki',
+	NS_MEDIAWIKI_TALK   => 'MediaWikipa_rimanakuy',
+	NS_TEMPLATE         => 'Plantilla',
+	NS_TEMPLATE_TALK    => 'Plantillapa_rimanakuy',
+	NS_HELP             => 'Yanapa',
+	NS_HELP_TALK        => 'Yanapapak_rimanakuy',
+	NS_CATEGORY         => 'Samiyachiy',
+	NS_CATEGORY_TALK    => 'Samiyachiy_rimanakuy',
+);
 
 $messages = array(
+# User preference toggles
+'tog-underline'              => 'Tinkikunana uraypi aspishpa rikuchina',
+'tog-highlightbroken'        => 'Pakishka tinkikuna <a href="" class="new">kashna</a> (mana kashna munakpika, kashnami<a href="" class="internal">?</a>rikuchinata munapankimi)',
+'tog-justify'                => 'Aspinakunata alli paktachina',
+'tog-hideminor'              => 'mushuk killkaykunapak kamupi, uchilla killkaykunata pakana',
+'tog-hidepatrolled'          => 'mushuk killkaykunapak kamupi, ña rikushka killkaykunata pakana',
+'tog-newpageshidepatrolled'  => 'Mushuk pankakunapak kamupi, ña rikushka pankakunata pakana',
+'tog-extendwatchlist'        => 'Rikushka pankakunapak mushuk killkaykunapak kamupi, ama yallik mushuk killkaykunatalla rikuchina, tukuykunatami rikuchina',
+'tog-usenewrc'               => 'Mushuk killkaykunata chapashka pankakunapak killkaykunatapash ashtawan alli rikuchina (Javascriptwanlla)',
+'tog-numberheadings'         => 'Uma killkaykunata yupayta churak antawata llankachina',
+'tog-showtoolbar'            => 'Llamkana antakunata rikuchina (Javascriptwanlla)',
+'tog-editondblclick'         => 'Ishkayta klik rurashpa pankapi killkanata kallarina (JavaScriptwanlla)',
+'tog-editsection'            => 'Rakikunata [Killkana] tinkiwan killkankapak arinina',
+'tog-rememberpassword'       => 'Ñukapak shuti, yaykuna yupaytapash kay wampunapi kipaka churankapak yuyana ({{PLURAL:$1|puncha|punchakuna}}kamanlla)',
+'tog-watchcreations'         => 'Ñukapak wacharishka pankakunata rikuna',
+'tog-watchdefault'           => 'Ñukapak shukchishka pankakunata rikuna',
+'tog-watchmoves'             => 'Ñukapak shuk shutiman apakushka pankakunata rikuna',
+'tog-watchdeletion'          => 'Ñukapak pichashka pankakunata rikuna',
+'tog-minordefault'           => 'Nimata nikpika, ñukapak killkaykunata uchillami nina',
+'tog-previewontop'           => 'Ñauwpak rikuchik pankata killkana pankapak hawapi churana',
+'tog-nocache'                => 'Wampunapi ama rikushka pankakunata yuyana',
+'tog-enotifwatchlistpages'   => 'Shuk rikushka pankata shukchishka kakpika, e-chaskita kachamushpami willaway',
+'tog-enotifusertalkpages'    => 'Ñukapak rimana pankapi mushuk killkayta tiyakpi, e-chaskiwan willaway',
+'tog-enotifminoredits'       => 'Mushuk killkayta uchilla kakpipash e-chaskiwan willaway',
+'tog-shownumberswatching'    => 'Mashna rurakkunaka chay pankata rikukuncha rikuchina',
+'tog-oldsig'                 => 'Kunan pachapak aspina:',
+'tog-fancysig'               => 'aspinata Wiki-killkay shina rikuchina (mana ñapash tinkita churashpa)',
+'tog-showjumplinks'          => '"chayman kallpana" tinkikunata sakina',
+'tog-forceeditsummary'       => 'Mana uchilla willayta churashpa killkakpi willaway',
+'tog-watchlisthideown'       => 'Rikushka pankakunapak mushuk killkaykunapi, ñukapak killkaykunata mana rikuchina',
+'tog-watchlisthidebots'      => 'Rikushka pankakunapak mushuk killkaykunapi, antawakunapak killkaykunata mana rikuchina',
+'tog-watchlisthideminor'     => 'Rikushka pankakunapak mushuk killkaykunapi, uchilla killkaykunata mana rikuchina',
+'tog-watchlisthideliu'       => 'Rikushka pankakunapak mushuk killkaykunapi, shutiyuk rurakkunapak killkaykunata mana rikuchina',
+'tog-watchlisthideanons'     => 'Rikushka pankakunapak mushuk killkaykunapi, shuti illak rurakkunapak killkaykunata mana rikuchina',
+'tog-watchlisthidepatrolled' => 'Rikushka pankakunapak mushuk killkaykunapi, ña rikushka killkaykunata mana rikuchina',
+'tog-ccmeonemails'           => 'ñuka shuk rurakman e-chaskita kachakpi, ñukapakmanpash kachamuna',
+'tog-diffonly'               => 'Mushuk killkaykunapak uraypi, pankata ama rikuchiychu',
+'tog-showhiddencats'         => 'Pakashka katikuriyakunata rikuchina',
+
+'underline-always' => 'Wiñay',
+'underline-never'  => 'Nimamanta',
+
 # Dates
 'sunday'        => 'Hawkay',
 'monday'        => 'Sullka',
@@ -68,78 +129,129 @@ $messages = array(
 'dec'           => 'Kap',
 
 # Categories related messages
-'pagecategories'         => '{{PLURAL:$1|Katiguriya|Katiguriyakuna}}',
-'category_header'        => '"$1" katiguriyapi tiyak pankakuna',
-'subcategories'          => 'Uchilla katikuriyakuna',
-'category-media-header'  => '"$1" katiguriyapi tiyak archiwukuna',
-'category-empty'         => "''Kay katiguriyapi nimata tiyanchu.''",
-'hidden-categories'      => '{{PLURAL:$1|Pakashka katiguriya|Pakashka katiguriyakuna}}',
-'category-subcat-count'  => '{{PLURAL:$2|Kay katikuriyaka shuklla ushi katikuriyata charin :|Kay katiguriyaka kay katik {{PLURAL:$1|ushi katikuriyata|$1 ushi katikuriyakunata}} charinmi, $2-pura.}}',
-'category-article-count' => '{{PLURAL:$2|Kay katiguriyapi shuklla pankaka tiyanmi.|Kay katiguriyapi kay katik {{PLURAL:$1|panka|$1 pankakunaka}} tiyanmi, $2-pura.}}',
-'category-file-count'    => '{{PLURAL:$2|Kay katiguriyapi shuklla archiwuka tiyanmi.|Kay katiguriyapi kay katik {{PLURAL:$1|archiwu|$1 archiwukunaka}} tiyanmi, $2-pura.}}',
-'listingcontinuesabbrev' => 'katiy',
-'noindex-category'       => 'Googlepak pakashka pankakuna (__NOINDEX__ charik pankakuna)',
+'pagecategories'                 => '{{PLURAL:$1|Katiguriya|Katiguriyakuna}}',
+'category_header'                => '"$1" katiguriyapi tiyak pankakuna',
+'subcategories'                  => 'Uchilla katikuriyakuna',
+'category-media-header'          => '"$1" katiguriyapi tiyak archiwukuna',
+'category-empty'                 => "''Kay katiguriyapi nimata tiyanchu.''",
+'hidden-categories'              => '{{PLURAL:$1|Pakashka katiguriya|Pakashka katiguriyakuna}}',
+'hidden-category-category'       => 'Pakashka katikuriyakuna',
+'category-subcat-count'          => '{{PLURAL:$2|Kay katikuriyaka shuklla ushi katikuriyata charin :|Kay katiguriyaka kay katik {{PLURAL:$1|ushi katikuriyata|$1 ushi katikuriyakunata}} charinmi, $2-pura.}}',
+'category-subcat-count-limited'  => 'Kay katikuriyaya {{PLURAL:$1|shuk ushi katikuriya|$1 ushi katikuriyakuna}} charinmi:',
+'category-article-count'         => '{{PLURAL:$2|Kay katiguriyapi shuklla pankaka tiyanmi.|Kay katiguriyapi kay katik {{PLURAL:$1|panka|$1 pankakunaka}} tiyanmi, $2-pura.}}',
+'category-article-count-limited' => 'Kay katiguriyapika, kay katik {{PLURAL:$1|pankami|$1 pankakunami}} tiyan.',
+'category-file-count'            => '{{PLURAL:$2|Kay katiguriyapi shuklla archiwuka tiyanmi.|Kay katiguriyapi kay katik {{PLURAL:$1|archiwu|$1 archiwukunaka}} tiyanmi, $2-pura.}}',
+'category-file-count-limited'    => 'Kay katiguriyapika, kay katik {{PLURAL:$1|archivumi|$1 archivukunami}} tiyan.',
+'listingcontinuesabbrev'         => 'katiy',
+'noindex-category'               => 'Googlepak pakashka pankakuna (__NOINDEX__ charik pankakuna)',
+'broken-file-category'           => 'Pakishka archivukunaman tinkiyuk pankakuna',
 
-'about'      => 'Pankamanta',
-'newwindow'  => '(Shuk mushuk wintanapi pakan)',
-'cancel'     => 'Ama nina',
-'mytalk'     => 'Ñukapak rimanakuy',
-'navigation' => 'Wampuna',
+'about'         => 'Pankamanta',
+'article'       => 'Yachaykunayuk panka',
+'newwindow'     => '(Shuk mushuk wintanapi pakan)',
+'cancel'        => 'Ama nina',
+'moredotdotdot' => 'Ashtawan...',
+'mypage'        => 'Ñukapak panka',
+'mytalk'        => 'Ñukapak rimanakuy',
+'anontalk'      => 'Kay IP yupaypak rimana',
+'navigation'    => 'Wampuna',
 
 # Cologne Blue skin
-'qbfind' => 'Maskana',
-'faq'    => 'Ashtawan tapushkaka tapunakuna',
+'qbfind'         => 'Maskana',
+'qbbrowse'       => 'Maskana',
+'qbedit'         => 'Killkana',
+'qbpageoptions'  => 'Pankapak akllanakuna',
+'qbpageinfo'     => 'Pankamanta willaykuna',
+'qbmyoptions'    => 'Ñukapak pankakuna',
+'qbspecialpages' => 'mans shukkunashina pankakuna',
+'faq'            => 'Ashtawan tapushkaka tapunakuna',
+'faqpage'        => 'Project:ashta ministishka tapuykuna',
 
 # Vector skin
-'vector-action-addsection' => 'Shuk mushuk rimanakuyta kallarina',
-'vector-action-delete'     => 'Pichana',
-'vector-action-move'       => 'Apakuna',
-'vector-action-protect'    => 'Harkana',
-'vector-view-create'       => 'Kamarina',
-'vector-view-edit'         => 'Killkana',
-'vector-view-history'      => 'Wiñay kawsayta rikuna',
-'vector-view-view'         => 'Killkakatina',
-'vector-view-viewsource'   => 'Pukyu killkata rikuna',
-'actions'                  => 'Ruraykuna',
-'namespaces'               => 'Shutipak kitikuna',
-'variants'                 => 'Shuk rikuchiy shinakuna',
+'vector-action-addsection'       => 'Shuk mushuk rimanakuyta kallarina',
+'vector-action-delete'           => 'Pichana',
+'vector-action-move'             => 'Apakuna',
+'vector-action-protect'          => 'Harkana',
+'vector-action-undelete'         => 'Kutin wacharichina',
+'vector-action-unprotect'        => 'Harkayta shukchina',
+'vector-simplesearch-preference' => 'Ashtawan alli maskankapak imakunata arinina (Vectorwanlla)',
+'vector-view-create'             => 'Kamarina',
+'vector-view-edit'               => 'Killkana',
+'vector-view-history'            => 'Wiñay kawsayta rikuna',
+'vector-view-view'               => 'Killkakatina',
+'vector-view-viewsource'         => 'Pukyu killkata rikuna',
+'actions'                        => 'Ruraykuna',
+'namespaces'                     => 'Shutipak kitikuna',
+'variants'                       => 'Shuk rikuchiy shinakuna',
 
-'errorpagetitle'   => 'Pantay',
-'returnto'         => '$1-man tikramuna.',
-'tagline'          => '{{SITENAME}}manta',
-'help'             => 'Yanapa',
-'search'           => 'Maskana',
-'searchbutton'     => 'Maskana',
-'searcharticle'    => 'Rina',
-'history'          => 'Wiñay kawsay',
-'history_short'    => 'Wiñay kawsay',
-'printableversion' => 'Impresoraman pankakuna',
-'permalink'        => 'Enlace permanente',
-'edit'             => 'killkana',
-'create'           => 'Kamarina',
-'editthispage'     => 'Kay pankapi killkana',
-'delete'           => 'pichay',
-'protect'          => 'Wichkana',
-'protect_change'   => 'Shukchina',
-'newpage'          => 'Mushuk panka',
-'talkpage'         => 'Kay pankamanta rimanakuna',
-'talkpagelinktext' => 'Rimanakuy',
-'personaltools'    => 'Kikinpak llankanaman yanapanakuna',
-'talk'             => 'Rimanakuna',
-'views'            => 'Rikunakuna',
-'toolbox'          => 'Llankanakuna',
-'otherlanguages'   => 'Shuk shimikunapi',
-'redirectedfrom'   => '($1-manta pushashka)',
-'redirectpagesub'  => 'pushashka panka',
-'lastmodifiedat'   => 'Kay pankata $1 punchapi, $2 pachapi kutin llankashkami karka',
-'jumpto'           => 'Chayman rina',
-'jumptonavigation' => 'Wampuna',
-'jumptosearch'     => 'Maskana',
+'errorpagetitle'    => 'Pantay',
+'returnto'          => '$1-man tikramuna.',
+'tagline'           => '{{SITENAME}}manta',
+'help'              => 'Yanapa',
+'search'            => 'Maskana',
+'searchbutton'      => 'Maskana',
+'go'                => 'Rina',
+'searcharticle'     => 'Rina',
+'history'           => 'Wiñay kawsay',
+'history_short'     => 'Wiñay kawsay',
+'updatedmarker'     => 'Ñukapak yallik kipak shamushka kipa shukchishka',
+'printableversion'  => 'Impresoraman pankakuna',
+'permalink'         => 'Enlace permanente',
+'print'             => 'Papelpi llukshina',
+'view'              => 'Rikuna',
+'edit'              => 'killkana',
+'create'            => 'Kamarina',
+'editthispage'      => 'Kay pankapi killkana',
+'create-this-page'  => 'Kay pankata kallarina',
+'delete'            => 'pichay',
+'deletethispage'    => 'Kay pankata pichana',
+'undelete_short'    => 'Kutin chay {{PLURAL:$1|killkayta|$1 killkaykunata}} churana',
+'viewdeleted_short' => '{{PLURAL:$1|shuk pichashka killkayta|$1 pichashka killkaykunata}} rikuna',
+'protect'           => 'Wichkana',
+'protect_change'    => 'Shukchina',
+'protectthispage'   => 'Kay pankata harkana',
+'unprotect'         => 'Harkayta shukchina',
+'unprotectthispage' => 'Kay pankapak harkayta shukchina',
+'newpage'           => 'Mushuk panka',
+'talkpage'          => 'Kay pankamanta rimanakuna',
+'talkpagelinktext'  => 'Rimanakuy',
+'specialpage'       => 'Mana shukkunashina panka',
+'personaltools'     => 'Kikinpak llankanaman yanapanakuna',
+'postcomment'       => 'Mushuk raki',
+'articlepage'       => 'Pankata rikuna',
+'talk'              => 'Rimanakuna',
+'views'             => 'Rikunakuna',
+'toolbox'           => 'Llankanakuna',
+'userpage'          => 'Chay rurakpa pankata rikuna',
+'projectpage'       => 'Ruraykamay pankata rikuna',
+'imagepage'         => 'Kay archivupak pankata rikuna',
+'mediawikipage'     => 'Willay pankata rikuna',
+'templatepage'      => 'Plantillapak pankata rikuna',
+'viewhelppage'      => 'Ayudana pankata rikuna',
+'categorypage'      => 'Katiguriya pankata rikuna',
+'viewtalkpage'      => 'Rimanakuyta rikuna',
+'otherlanguages'    => 'Shuk shimikunapi',
+'redirectedfrom'    => '($1-manta pushashka)',
+'redirectpagesub'   => 'pushashka panka',
+'lastmodifiedat'    => 'Kay pankata $1 punchapi, $2 pachapi kutin llankashkami karka',
+'viewcount'         => 'Kay pankaka ñami  {{PLURAL:$1|una vezta|$1 vecesta}} rikushkami karka',
+'protectedpage'     => 'Harkashka panka',
+'jumpto'            => 'Chayman rina',
+'jumptonavigation'  => 'Wampuna',
+'jumptosearch'      => 'Maskana',
+'view-pool-error'   => 'Atatay, kunan ratupi pankayuk antawakuna yapa trabajuta charinmi. 
+Yapa runakuna kay pankata rikukunmi.
+Ama shinachu kapay, ashakuta shuyapay, kipalla kutin pankata rikunkapak shamupay.
+
+$1',
+'pool-timeout'      => 'Harkankapak tiempota ña tukurishka',
+'pool-queuefull'    => 'Lankankapak suyana uku ña huntashkami',
+'pool-errorunknown' => 'Na riksishka pantay',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => '{{SITENAME}}manta',
 'aboutpage'            => 'Project:{{SITENAME}}manta',
-'copyright'            => 'Kay panka hawapi, $1$ killkakunapak hayñikunaka tiyanmi',
+'copyright'            => 'Kay panka hawapi, $1 killkakunapak hayñikunaka tiyanmi',
 'copyrightpage'        => '{{ns:project}}:Killkakpa hayñikuna',
 'currentevents'        => 'Kunan pacha',
 'currentevents-url'    => 'Project:Kunan pacha',
@@ -150,47 +262,94 @@ $messages = array(
 'helppage'             => 'Help:Yanapa',
 'mainpage'             => 'Kapak Panka',
 'mainpage-description' => 'Kapak panka',
+'policy-url'           => 'Project:Kamachiykuna',
 'portal'               => 'Ayllupak panka',
 'portal-url'           => 'Project:Ayllupak panka',
 'privacy'              => 'Willakunata amachaynin',
 'privacypage'          => 'Project:Kampak willaykunawan imata ruranchik ?',
 
-'retrievedfrom'       => '$1 pankamanta hapishka',
-'youhavenewmessages'  => '$1 charipanki ($2).',
-'newmessageslink'     => 'Mushuk willaymi',
-'newmessagesdifflink' => 'yalli mushuk killkay',
-'editsection'         => 'Killkana',
-'editold'             => 'Killkana',
-'viewsourceold'       => 'Pukyu killkata rikuna',
-'editlink'            => 'Killkana',
-'viewsourcelink'      => 'Pukyu killkata rikuna',
-'editsectionhint'     => '$1 Seccionpi llankana',
-'toc'                 => 'Tiyakkuna',
-'showtoc'             => 'Rikuchina',
-'hidetoc'             => 'Pakana',
-'site-rss-feed'       => '$1 RSS pukyu',
-'site-atom-feed'      => "$1 ''Atom'' pukuy",
-'page-rss-feed'       => '$1 RSS pukyu',
-'page-atom-feed'      => '$1 Atom feed',
-'red-link-title'      => '$1 (illakmi panka)',
+'badaccess'        => 'Pita sakina nishka pantay tiyarka',
+'badaccess-group0' => 'Shuk imata ruranata munapanki, kayta rurankapak na sakinata ushanchikchu.',
+'badaccess-groups' => 'Ima kanka ruranata munanki, {{PLURAL:$2|Kay grupopak|Kay $2 grupokunapak}} runakunalla ruranata ushan: $1',
+
+'versionrequired'     => 'Kayta Mediawiki $1 nishkawanlla ruranata ushapanki.',
+'versionrequiredtext' => 'Kayta Mediawiki $1 nishkawanlla ruranata ushapanki. Ashtawan yachakunkapak, [[Special:Version|version page]] pankata rikukripay.',
+
+'ok'                      => 'Ari nina',
+'retrievedfrom'           => '$1 pankamanta hapishka',
+'youhavenewmessages'      => '$1 charipanki ($2).',
+'newmessageslink'         => 'Mushuk willaymi',
+'newmessagesdifflink'     => 'yalli mushuk killkay',
+'youhavenewmessagesmulti' => '$1-pi mushuk chaskikunata charipankimi.',
+'editsection'             => 'Killkana',
+'editold'                 => 'Killkana',
+'viewsourceold'           => 'Pukyu killkata rikuna',
+'editlink'                => 'Killkana',
+'viewsourcelink'          => 'Pukyu killkata rikuna',
+'editsectionhint'         => '$1 Seccionpi llankana',
+'toc'                     => 'Tiyakkuna',
+'showtoc'                 => 'Rikuchina',
+'hidetoc'                 => 'Pakana',
+'collapsible-collapse'    => 'Allichina',
+'collapsible-expand'      => 'Rikuchina',
+'thisisdeleted'           => '$1-ta rikunallacha, kutin ruranapashcha munapanki ?',
+'viewdeleted'             => '$1 pankata rikunata munapanki ?',
+'restorelink'             => '{{PLURAL:$1|shuk pichashka killkayta|$1 pichashka killkaykunata}} rikuna',
+'feedlinks'               => 'Mikuchiy',
+'feed-invalid'            => 'Willaykunata mikuchik antawapak llankachinkapak, nallita akllarkapankichu.',
+'site-rss-feed'           => '$1 RSS pukyu',
+'site-atom-feed'          => "$1 ''Atom'' pukuy",
+'page-rss-feed'           => '$1 RSS pukyu',
+'page-atom-feed'          => '$1 Atom feed',
+'red-link-title'          => '$1 (illakmi panka)',
+'sort-descending'         => 'Hawamanta urayman imakunata tiyachina',
+'sort-ascending'          => 'Uraymanta hawaman imakunata tiyachina',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
-'nstab-main'     => 'Panka',
-'nstab-user'     => 'Rurakpa panka',
-'nstab-special'  => 'Sapak pankakuna',
-'nstab-project'  => 'Ruraykamaypa panka',
-'nstab-image'    => 'Archivu',
-'nstab-template' => 'Plantilla',
-'nstab-category' => 'Uwarullkay',
+'nstab-main'      => 'Panka',
+'nstab-user'      => 'Rurakpa panka',
+'nstab-media'     => 'Media',
+'nstab-special'   => 'Sapak pankakuna',
+'nstab-project'   => 'Ruraykamaypa panka',
+'nstab-image'     => 'Archivu',
+'nstab-mediawiki' => 'Willay',
+'nstab-template'  => 'Plantilla',
+'nstab-help'      => 'Ayuda',
+'nstab-category'  => 'Uwarullkay',
+
+# Main script and global functions
+'nosuchaction' => 'Kay rurayta illanmi',
 
 # General errors
-'missing-article'    => "Hatun kamupi shuk killkayta mana tarin, shinapash chay killkayta tiyanami kan. Paypa chay shutima kan : «$1» $2.
+'error'                => 'Pantay',
+'databaseerror'        => 'Yachayyuk ukupi pantay',
+'laggedslavemode'      => "'''Rikupay''': Kay pankapi, shina kakpi, mushuk killkaykuna illankacha.",
+'missing-article'      => "Hatun kamupi shuk killkayta mana tarin, shinapash chay killkayta tiyanami kan. Paypa chay shutima kan : «$1» $2.
 Icha shuk ñawpak pachamanta ''diff'' ñamana tiyanchu, icha kay tinkika shuk pichashka pankapa shutimi kan. 
 Mana shina kakpi, shuk [[Special:ListUsers/sysop|kamachyik]]man willapay, payta URL killkata willapay.",
-'missingarticle-rev' => '(Killkay#: $1)',
-'badtitle'           => 'Pankapa shutika mana allichu',
-'badtitletext'       => 'Kay pankapa shutika mana allichu, icha illakmi kan. Icha mana alli llikata charin.',
-'viewsource'         => 'Pukyu killkata rikuna',
+'missingarticle-rev'   => '(Killkay#: $1)',
+'internalerror'        => 'Antawa ukupi pantay tiyarka',
+'internalerror_info'   => 'Antawa ukupi pantay tiyarka: $1',
+'fileappenderrorread'  => 'Pankata wiñachishpa $1-ta na tarinata usharkanchikchu',
+'fileappenderror'      => '$1-ta $2-man yapanata na atirkanchikchu',
+'filecopyerror'        => '$1-ta $2-man ishkachanata na atirkanchikchu',
+'filerenameerror'      => '$1-man $2 shutita karana na atirkanchikchu',
+'filedeleteerror'      => '"$1" archivuta pichanata na atirkanchikchu.',
+'directorycreateerror' => '$1 allichina ukuta na wachachinata atirkanchikchu',
+'filenotfound'         => '"$1" archivuta tarinata na atirkanchikchu.',
+'fileexistserror'      => '$1 archivupi na killkanata ushapankichu: shuk shina shutiyuk archivuta ñami tiyan',
+'unexpected'           => 'Chayta na shuyashkachu karka: "$1"="$2".',
+'badarticleerror'      => 'Kay pankapi chayta na ruranachu.',
+'cannotdelete'         => '$1 shutiyuk pankata (archivucha) na pichanata atirkanchikchu.
+Shina kakpika, shuk rurakka ña pankata pichankacha.',
+'badtitle'             => 'Pankapa shutika mana allichu',
+'badtitletext'         => 'Kay pankapa shutika mana allichu, icha illakmi kan. Icha mana alli llikata charin.',
+'viewsource'           => 'Pukyu killkata rikuna',
+'actionthrottled'      => 'Rurayta harkashka',
+'actionthrottledtext'  => 'Spam rurashpa nalli runakunaka ama yapata chaskikuna kachankapak, mana chayta kutin ñapash rurana ushapankichu. Ama shinachu kapay, ashata shuyashpa  (wakin minutoskuna) kutin rurapay.',
+'protectedpagetext'    => 'Kay pankaka ama shukchinkapak harkashkami kan.',
+'viewsourcetext'       => 'Kay pankapak wiki killkayta rikunata, ishkachinatapash ushapankimi.',
+'protectedinterface'   => 'Kay pankaka kapak willaykunata charinmi, ama nalli runakunaka kaypi killkankapak harkashkami kapan.',
 
 # Login and logout pages
 'yourname'                => 'Rurak shuti:',
@@ -245,7 +404,7 @@ Mana shina kakpi, shuk [[Special:ListUsers/sysop|kamachyik]]man willapay, payta
 'noarticletext'                    => 'Kunan pachapi, kay pankaka mana killkaykunata charin.
 Pakpak shutita [[Special:Search/{{PAGENAME}}|shuk pankakunapi maskanata]], <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} registroskunapi maskanata]pash ushankimi, kutin [{{fullurl:{{FULLPAGENAME}}|action=edit}} kay pankata kamarinata] ushankimi',
 'noarticletext-nopermission'       => 'Kunan pachapi kay pankaka mana killkashkakunata charinchu. Paypak shutita [[Special:Search/{{PAGENAME}}|shuk pankakunapi maskanata]] ushapankimi, shinalla <span class="plainlinks">pankakunapa wiñay kawsay kamupi [{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} tinkishka shukchiykunaka] maskana</span>',
-'previewnote'                      => 'Rikupay: kay killkaykunata mana churapankichu !',
+'previewnote'                      => 'Rikupay: kay killkaykunata nara allichipashkankichu !',
 'editing'                          => '$1 pankapi killkashpa',
 'editingsection'                   => '$1 rakipi killkashpa',
 'templatesused'                    => 'Kay pankaka {{PLURAL:$1|plantilla|plantillakuna}}ta llankachin:',
@@ -291,13 +450,9 @@ Kay (kaykunachu) kachashkakunaka cunkashkami kashka.",
 
 # Revision deletion
 'rev-delundel'           => 'Rikuchiy/pakay',
-'revdelete-logentry'     => 'Pita [[$1]] ñawpa killkaykunata rikunata ushanchu kutin kamachirka.',
 'revdel-restore'         => 'Rikuyukkunata shukchina',
 'revdel-restore-deleted' => 'pichashka shukchiykuna',
 'revdel-restore-visible' => 'Mana pakashka shukchiykuna',
-'revdelete-content'      => 'Tiyakkuna',
-'revdelete-hid'          => '$1-ta pakarka',
-'revdelete-log-message'  => '$1, $2 {{PLURAL:$2|mushuk killkay|mushuk killkaykuna}}pak',
 
 # Merge log
 'revertmerge' => 'Shukllachiyta kutichina',
@@ -418,7 +573,7 @@ Shuk rurakkunaka kikinpa e-chaski ''dirección''ta mana yachankachu.",
 'recentchangeslinked-to'       => 'Ama pankata rikuchina, ranti tukuy kay pankaman tinkiyuk pankakunapi mushuk killkaykunatalla rikuchina',
 
 # Upload
-'upload'        => 'Aichivutu apakuna',
+'upload'        => 'Archivuta apamuna',
 'uploadlogpage' => 'Apamushka archiwukunapa kamu',
 'filedesc'      => 'Uchilla rimay',
 'uploadedimage' => '«[[$1]]» apakushka.',
@@ -456,7 +611,7 @@ Shuk rurakkunaka kikinpa e-chaski ''dirección''ta mana yachankachu.",
 'nbytes'        => '$1 {{PLURAL:$1|byte|byte}}',
 'nmembers'      => '$1 {{PLURAL:$1|panka|pankakuna}}',
 'prefixindex'   => 'Tukuy kallarikshutiyuk pankakunaka',
-'usercreated'   => '$1 punchapi $2 pachapi kamashka',
+'usercreated'   => '{{GENDER:$3|}}$1 punchapi $2 pachapi kamashka',
 'newpages'      => 'Mushuk pankakuna',
 'move'          => 'Apakuy',
 'movethispage'  => 'Kay pankaman shuk mushuk shutita karana',
@@ -488,18 +643,17 @@ Shuk rurakkunaka kikinpa e-chaski ''dirección''ta mana yachankachu.",
 'linksearch-line' => '$1 pankaka $2-manta tinkishkami kan',
 
 # Special:Log/newusers
-'newuserlogpage'          => 'Rurakkununata kamaykunapa kamu',
-'newuserlog-create-entry' => 'Mushuk rurak',
+'newuserlogpage' => 'Rurakkununata kamaykunapa kamu',
 
 # Special:ListGroupRights
 'listgrouprights-members' => '(Kay tantanakuypa rurakkunapa shutikuna)',
 
-# E-mail user
+# Email user
 'emailuser' => 'Kay rurakman e-chaskita kachana',
 
 # Watchlist
 'watchlist'         => 'Rikukushka pankakuna',
-'mywatchlist'       => 'Imata rikukuni',
+'mywatchlist'       => 'Imata chapakuni',
 'watchlistfor2'     => '$1-pak $2',
 'watch'             => 'rikupay',
 'watchthispage'     => 'Kay pankata rikukuna',
@@ -518,7 +672,6 @@ Shuk rurakkunaka kikinpa e-chaski ''dirección''ta mana yachankachu.",
 'actionfailed'          => 'Mana ushanchu',
 'deletedtext'           => '"$1" ñami pichashkami kan.
 $2 rikpika, ima pankakunaka pichashkami kan yachakupanki.',
-'deletedarticle'        => '"[[$1]]" pankata picharka',
 'dellogpage'            => 'Pichaykunapa kamu',
 'deletecomment'         => 'Imashpa:',
 'deleteotherreason'     => 'Yapa imashpa:',
@@ -535,16 +688,15 @@ $2 rikpika, ima pankakunaka pichashkami kan yachakupanki.',
 'protect_expiry_invalid'      => "''Ima pachakaman'' mana alli nishkami.",
 'protect_expiry_old'          => "''Ima pachakaman'' mana alli nishkami : kay pachaka ñawpak pachapi kapanmi !",
 'protect-default'             => 'Rukuy runakunaman ari nipay',
-'protect-fallback'            => '«$1» hayñita mutsupanki',
-'protect-level-autoconfirmed' => 'Mushuk rurakkunata mana shutiyuk rurakkunatapash wichkana',
-'protect-level-sysop'         => 'Kipukamayukkunalla',
+'protect-fallback'            => '«$1» hayñiyuk rurakkunallapak',
+'protect-level-autoconfirmed' => 'Kikin shutiyuk rurakkunallapak',
+'protect-level-sysop'         => 'Kipukamayukkunallapak',
 'protect-expiring'            => '$1 (UTC) pachakaman',
 'restriction-type'            => 'Hayñi:',
 
 # Undelete
 'undeletelink'     => 'Rikuna/pakarina',
 'undeleteviewlink' => 'rikuna',
-'undeletedarticle' => '«[[$1]]» kutin kamarka',
 
 # Namespace form on various pages
 'namespace'      => 'Shutipak kiti',
@@ -602,22 +754,20 @@ $2 rikpika, ima pankakunaka pichashkami kan yachakupanki.',
 'block-log-flags-nocreate' => 'Mushuk rurak shutipa kamayta wichkashkami',
 
 # Move page
-'movearticle'     => 'Kay pankama mushuk shutita karapana:',
-'newtitle'        => 'Kay mushuk shutiman',
-'move-watch'      => 'Kay ishkay pankakunata rikukuna',
-'movepagebtn'     => 'Kay pankaman mushuk shutita karapana:',
-'pagemovedsub'    => 'Shutita ñami shukchishka',
-'movepage-moved'  => '\'\'\'"$1" pankaka "$2"shutiman apakushka\'\'\'',
-'articleexists'   => 'Shuk pankaka ñami kay shutita charin, icha kay shutiyuk man alli kan.
+'movearticle'    => 'Kay pankama mushuk shutita karapana:',
+'newtitle'       => 'Kay mushuk shutiman',
+'move-watch'     => 'Kay ishkay pankakunata rikukuna',
+'movepagebtn'    => 'Kay pankaman mushuk shutita karapana:',
+'pagemovedsub'   => 'Shutita ñami shukchishka',
+'movepage-moved' => '\'\'\'"$1" pankaka "$2"shutiman apakushka\'\'\'',
+'articleexists'  => 'Shuk pankaka ñami kay shutita charin, icha kay shutiyuk man alli kan.
 Shuk shutita akllapay.',
-'talkexists'      => 'Kay pankapa shutita ñami shukchishkami kan, shinapash paypa rimanakuyta shuk rimanakuyka ñami tiyakpika mana apamushkami kan : makillawan kay ishkay rimanakuykunata tantachipay.',
-'movedto'         => 'Kayman apakushka :',
-'movetalk'        => 'Tinkishka rimanakuyta shinalla apakuna',
-'1movedto2'       => '«[[$1]]» «[[$2]]»-man apakushka',
-'1movedto2_redir' => '[[$1]] [[$2]]-man shuk pushayta pichashpami apakushka',
-'movelogpage'     => 'Shutikunata shukchiykunapa kamu',
-'movereason'      => 'Imashpa:',
-'revertmove'      => 'Kutichina',
+'talkexists'     => 'Kay pankapa shutita ñami shukchishkami kan, shinapash paypa rimanakuyta shuk rimanakuyka ñami tiyakpika mana apamushkami kan : makillawan kay ishkay rimanakuykunata tantachipay.',
+'movedto'        => 'Kayman apakushka :',
+'movetalk'       => 'Tinkishka rimanakuyta shinalla apakuna',
+'movelogpage'    => 'Shutikunata shukchiykunapa kamu',
+'movereason'     => 'Imashpa:',
+'revertmove'     => 'Kutichina',
 
 # Export
 'export' => 'Pankakunata apakuna',
@@ -686,17 +836,13 @@ Shuk shutita akllapay.',
 'tooltip-undo'                    => '"Kutichina" nikpika, kay hapishka killkayta kutichipanki, shinalla killkana pankapa "ñawpak rikuchiy" rikupanki : chaymanta, imashpa kay killkayta kutichipankichu rimanata ushapanki',
 'tooltip-summary'                 => 'Uchilla willayta killkana',
 
-# Patrol log
-'patrol-log-line' => '$1 $2 pankamanta alli kachirka $3',
-'patrol-log-diff' => '$1 mushuk killkata',
-
 # Browsing diffs
 'previousdiff' => 'Yallik ñawpakmi killkay',
 'nextdiff'     => 'Yalli mushukmi killkay',
 
 # Media information
 'file-info-size' => '$1 × $2 tawakukuna (pixelkuna); $3 llashakmi kan; MIME sami: $4',
-'file-nohires'   => '<small>Kay rikchapa shuk yallik hatun rikuchiyka mana tiyanchu.</small>',
+'file-nohires'   => 'Kay rikchapa shuk yallik hatun rikuchiyka mana tiyanchu.',
 'svg-long-desc'  => 'SVG archiwuka, $1 × $2 tawakukunayuk rimashka, $3 llashakmi.',
 'show-big-image' => 'Yallik hatun rikuchipay',
 
