@@ -1,5 +1,5 @@
 <?php
-/** Sardinian (Sardu)
+/** Sardinian (sardu)
  *
  * See MessagesQqq.php for message documentation incl. usage of parameters
  * To improve a translation please visit http://translatewiki.net
@@ -381,7 +381,6 @@ Podet èsser stadu burradu dae calicunu àteru.',
 'badtitle'            => 'Tìtulu malu',
 'badtitletext'        => "Su tìtulu de sa pàgina ch'as pediu est bùidu, isballiau, o iscritu in is cullegamentus inter-wiki in manera non currègia o cun caràteres no amìtius.",
 'viewsource'          => 'Càstia mitza',
-'viewsourcefor'       => 'pro $1',
 'actionthrottled'     => 'Atzione rimandada',
 'sqlhidden'           => '(Consulta SQL cuada)',
 'namespaceprotected'  => "Non tenes su permissu de acontzare is pàginas in su nùmene-lugu '''$1'''.",
@@ -519,7 +518,6 @@ Nota ca sa funtzione 'Ispedi un'e-mail a custu usuàriu' no est ativa ki no est
 S'indiritzu IP atuale est $3, su nùmeru ID de su bloccu est #$5.
 Pro praxere spetzìfica totu is particulares in antis in carche siat pregunta de acrarimentu.",
 'blockednoreason'                  => 'perunu motivu indicadu',
-'whitelistedittitle'               => "Esigit s'identificatzione pro acontzare is pàginas",
 'loginreqtitle'                    => 'Identificatzione rekesta',
 'loginreqlink'                     => 'identifica·ti',
 'loginreqpagetext'                 => 'Depes èsser $1 pro bìer àteras pàginas.',
@@ -607,13 +605,6 @@ Cosas de ammentare: '''({{int:cur}})''' = diferèntzias cun sa versione currente
 'revdel-restore-visible'     => 'revisiones visìbiles',
 'pagehist'                   => 'Istòria de sa pàgina',
 'deletedhist'                => 'Istòria fuliada',
-'revdelete-content'          => 'cuntènnidu',
-'revdelete-summary'          => "ogetu de s'acontzu",
-'revdelete-uname'            => 'nùmene usuàriu',
-'revdelete-hid'              => 'cua $1',
-'revdelete-unhid'            => 'ammustra $1',
-'revdelete-log-message'      => '$1 pro $2 {{PLURAL:$2|revisione|revisiones}}',
-'logdelete-log-message'      => '$1 pro $2 {{PLURAL:$2|eventu|eventos}}',
 'revdelete-reasonotherlist'  => 'Àteru motivu',
 
 # History merging
@@ -834,15 +825,14 @@ Prova a seberare ''totu:'' pro chircare in totu su cuntènnidu (inclùdidas pàg
 'rc-enhanced-hide'               => 'Cua particulares',
 
 # Recent changes linked
-'recentchangeslinked'          => 'Mudàntzias ligadas',
-'recentchangeslinked-feed'     => 'Mudàntzias ligadas',
-'recentchangeslinked-toolbox'  => 'Mudàntzias ligadas',
-'recentchangeslinked-title'    => 'Mudàntzias ligadas a "$1"',
-'recentchangeslinked-backlink' => '← $1',
-'recentchangeslinked-summary'  => "Custa est una lista de is mudàntzias fatas dae pagu a is pàginas ligadas a cussa spetzificada.
+'recentchangeslinked'         => 'Mudàntzias ligadas',
+'recentchangeslinked-feed'    => 'Mudàntzias ligadas',
+'recentchangeslinked-toolbox' => 'Mudàntzias ligadas',
+'recentchangeslinked-title'   => 'Mudàntzias ligadas a "$1"',
+'recentchangeslinked-summary' => "Custa est una lista de is mudàntzias fatas dae pagu a is pàginas ligadas a cussa spetzificada.
 Is pàginas de sa [[Special:Watchlist|watchlist tua]] sunt in '''grassu'''.",
-'recentchangeslinked-page'     => 'Nùmene pàgina:',
-'recentchangeslinked-to'       => 'Ammustra feti mudàntzias a pàginas ligadas a cussa spetzificada',
+'recentchangeslinked-page'    => 'Nùmene pàgina:',
+'recentchangeslinked-to'      => 'Ammustra feti mudàntzias a pàginas ligadas a cussa spetzificada',
 
 # Upload
 'upload'              => 'Càrriga file',
@@ -855,9 +845,9 @@ Is pàginas de sa [[Special:Watchlist|watchlist tua]] sunt in '''grassu'''.",
 Pro castiare o chircare is files giai carrigaus, bae a sa [[Special:FileList|lista de is files carrigaus]]. Carrigamentos de files e de noas versiones de files sunt registradas in su [[Special:Log/upload|registru de carrigamentu]], is burraduras in su [[Special:Log/delete|registru burraduras]].
 
 Pro insertare unu file aintru de una pàgina, tocat a faghere unu cullegamentu tipu custu:
-* '''<tt><nowiki>[[</nowiki>{{ns:file}}<nowiki>:File.jpg]]</nowiki></tt>''' pro impreare sa versione cumpleta de su file
-* '''<tt><nowiki>[[</nowiki>{{ns:file}}<nowiki>:File.png|200px|thumb|left|testo alternativo]]</nowiki></tt>''' pro impreare una versione lada 200 pixel insertada in d'unu box, allinniada a manca e cun 'testu alternativu' comente didascalia
-* '''<tt><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></tt>''' pro ingenerare unu cullegamentu a su file chentza de du biri",
+* '''<code><nowiki>[[</nowiki>{{ns:file}}<nowiki>:File.jpg]]</nowiki></code>''' pro impreare sa versione cumpleta de su file
+* '''<code><nowiki>[[</nowiki>{{ns:file}}<nowiki>:File.png|200px|thumb|left|testo alternativo]]</nowiki></code>''' pro impreare una versione lada 200 pixel insertada in d'unu box, allinniada a manca e cun 'testu alternativu' comente didascalia
+* '''<code><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></code>''' pro ingenerare unu cullegamentu a su file chentza de du biri",
 'uploadlogpage'       => 'Carrigadas',
 'uploadlogpagetext'   => 'A suta ddoi est sa lista de is files carrigados de reghente.
 Càstia sa [[Special:NewFiles|galleria de files nous]] pro una presentada prus bisuale.',
@@ -919,12 +909,10 @@ Càstia sa [[Special:NewFiles|galleria de files nous]] pro una presentada prus b
 'shared-repo-from'          => 'dae $1',
 
 # File reversion
-'filerevert-backlink' => '← $1',
-'filerevert-comment'  => 'Motivu:',
+'filerevert-comment' => 'Motivu:',
 
 # File deletion
 'filedelete'                  => 'Cantzella $1',
-'filedelete-backlink'         => '← $1',
 'filedelete-legend'           => 'Cantzella su file',
 'filedelete-submit'           => 'Cantzella',
 'filedelete-success'          => "Su file '''$1''' est istadu fuliau.",
@@ -1032,15 +1020,13 @@ Dia podent essere immàgines impreadas dae àteros giassos cun unu ligàmine dir
 'activeusers-hidesysops' => 'Cua amministradores',
 
 # Special:Log/newusers
-'newuserlogpage'          => 'Usuàrios nous',
-'newuserlog-byemail'      => 'password imbiada via e-mail',
-'newuserlog-create-entry' => 'Account usuàriu nou',
+'newuserlogpage' => 'Usuàrios nous',
 
 # Special:ListGroupRights
 'listgrouprights-group'   => 'Grupu',
 'listgrouprights-members' => '(lista de is cumponentes)',
 
-# E-mail user
+# Email user
 'mailnologintext' => "Depes èsser [[Special:UserLogin|identificadu (login)]] e àer registradu un'indiritzu e-mail vàlidu in is [[Special:Preferences|preferèntzias tuas]] pro imbiare e-mail a àteros usuàrios.",
 'emailuser'       => 'E-mail a custu usuàriu',
 'emailpage'       => "Ispedi una missada a s'usuàriu",
@@ -1096,7 +1082,6 @@ Is mudàntzias de custa pàgina e de sa pàgina de cuntierras sua ant a bennere
 'excontentauthor'       => "su cuntènnidu fiat: '$1' (e s'ùnicu contribudori fiat '[[Special:Contributions/$2|$2]]')",
 'exblank'               => 'sa pàgina fiat bùida',
 'delete-confirm'        => 'Fùlia "$1"',
-'delete-backlink'       => '← $1',
 'delete-legend'         => 'Fuliare',
 'confirmdeletetext'     => "Ses acanta de burrare una pàgina cun totu su stòria sua.
 Pro praxere, cunfirma ca est intentzione tua fàgher custu, ca connosches is cosseguèntzias de s'atzione tua, a ca custa est cunforma a is [[{{MediaWiki:Policy-url}}|lìnias polìticas]].",
@@ -1104,7 +1089,6 @@ Pro praxere, cunfirma ca est intentzione tua fàgher custu, ca connosches is cos
 'actionfailed'          => 'Atzione faddida',
 'deletedtext'           => 'Sa pàgina "$1" est istada fuliada.
 Càstia su log $2 pro unu registru de is ùrtimas fuliaduras.',
-'deletedarticle'        => 'at fuliadu "[[$1]]"',
 'dellogpage'            => 'Burraduras',
 'dellogpagetext'        => 'A sighire una lista de is prus reghentes burraduras.',
 'reverted'              => 'Torrada a sa versione in antis',
@@ -1124,7 +1108,6 @@ s'ùrtimu contribuidore est s'ùnicu autore de custa pàgina.",
 'protectlogpage'              => 'Amparaduras',
 'protectedarticle'            => 'at amparau "[[$1]]"',
 'modifiedarticleprotection'   => 'at cambiau su livellu de amparadura pro "[[$1]]"',
-'protect-backlink'            => '← $1',
 'protectcomment'              => 'Motivu:',
 'protectexpiry'               => 'Iscadèntzia:',
 'protect_expiry_invalid'      => "S'iscadèntzia est imbàlida.",
@@ -1172,7 +1155,6 @@ Chi est istada creada una pàgina cun su matessi tìtulu, is revisiones recupera
 'undeleteviewlink'          => 'abbista',
 'undeleteinvert'            => 'Fùrria sa seletzione',
 'undeletecomment'           => 'Motivu:',
-'undeletedarticle'          => 'at restauradu "$1"',
 'undeletedrevisions'        => '{{PLURAL:$1|1 revisione restaurada|$1 revisiones restauradas}}',
 'undeletedrevisions-files'  => '{{PLURAL:$1|1 revisione|$1 revisiones}} e {{PLURAL:$2|1 file|$2 files}} restaurados',
 'undeletedfiles'            => '{{PLURAL:$1|1 file restauradu|$1 files restaurados}}',
@@ -1207,7 +1189,6 @@ Chi est istada creada una pàgina cun su matessi tìtulu, is revisiones recupera
 'whatlinkshere'            => 'Pàginas chi ligant a custa',
 'whatlinkshere-title'      => 'Pàginas chi ligant a "$1"',
 'whatlinkshere-page'       => 'Pàgina:',
-'whatlinkshere-backlink'   => '← $1',
 'linkshere'                => "Sas pàginas chi sighint ligant a '''[[:$1]]''':",
 'nolinkshere'              => "Peruna pàgina ligat a '''[[:$1]]'''.",
 'nolinkshere-ns'           => "Peruna pàgina ligat a '''[[:$1]]''' in su nùmene-logu seberadu.",
@@ -1239,7 +1220,7 @@ Scrivi un motivo specifico per il quale questo indirizzo IP dovrebbe a tuo avvis
 'badipaddress'             => "S'indiritzu IP indicadu non est currègidu.",
 'blockipsuccesssub'        => 'Bloccu esecutivu',
 'blockipsuccesstext'       => '[[Special:Contributions/$1|$1]] è stadu bloccadu. <br />
-Abbàida sa [[Special:IPBlockList|lista de IP bloccados]] pro bìder sas bloccaduras.',
+Abbàida sa [[Special:BlockList|lista de IP bloccados]] pro bìder sas bloccaduras.',
 'ipb-edit-dropdown'        => 'Acontza su motivu de su bloccu',
 'ipb-unblock-addr'         => 'Sblocca $1',
 'ipb-blocklist-contribs'   => 'Contributziones de $1',
@@ -1314,8 +1295,6 @@ Pro praxere sèbera un'àteru nùmene.",
 'talkexists'              => "'''Su movimentu de sa pàgina est andadu bene, ma no est stadu possìbile mòver sa pàgina de cuntierras pro ite nde esistit giai un'àtera cun su matessi tìtulu. Pro praxere giunghe tue su cuntestu de sa pàgina betza.'''",
 'movedto'                 => 'mòvida a',
 'movetalk'                => 'Move sa pàgina de cuntierra galu',
-'1movedto2'               => 'at mòvidu [[$1]] a [[$2]]',
-'1movedto2_redir'         => 'at mòvidu [[$1]] a [[$2]] subra redirect',
 'movelogpage'             => 'Moviduras',
 'movereason'              => 'Motivu:',
 'revertmove'              => 'fùrria',
@@ -1418,7 +1397,7 @@ Podes agiùnger unu motivu in s\'ogetu de s\'acontzu.',
 
 # Media information
 'file-info-size' => '$1 × $2 pixels, mannesa de su file: $3, tipu de MIME: $4',
-'file-nohires'   => '<small>Non si tenent risolutziones prus artas.</small>',
+'file-nohires'   => 'Non si tenent risolutziones prus artas.',
 'svg-long-desc'  => 'file in formadu SVG, mannesa nominale $1 × $2 pixel, mannesa de su file: $3',
 'show-big-image' => 'Versione a risolutzione arta',
 
@@ -1429,9 +1408,9 @@ Podes agiùnger unu motivu in s\'ogetu de s\'acontzu.',
 
 # Video information, used by Language::formatTimePeriod() to format lengths in the above messages
 'video-dims'     => '$1, $2×$3',
-'seconds-abbrev' => 's',
-'minutes-abbrev' => 'm',
-'hours-abbrev'   => 'h',
+'seconds-abbrev' => '$1s',
+'minutes-abbrev' => '$1m',
+'hours-abbrev'   => '$1h',
 
 # Bad image list
 'bad_image_list' => 'Su formau est su chi sighit:
@@ -1505,7 +1484,7 @@ Is acàpius chi sighint in sa matessi lìnia sunt cunsideraus comente eccetzione
 'monthsall'     => 'totu',
 'limitall'      => 'totu',
 
-# E-mail address confirmation
+# Email address confirmation
 'confirmemail' => "Cunfirma s'indiritzu e-mail",
 
 # action=purge
@@ -1580,4 +1559,7 @@ Is acàpius chi sighint in sa matessi lìnia sunt cunsideraus comente eccetzione
 # HTML forms
 'htmlform-selectorother-other' => 'Àteru',
 
+# New logging system
+'newuserlog-byemail' => 'password imbiada via e-mail',
+
 );
