@@ -7,6 +7,7 @@
  * @ingroup Language
  * @file
  *
+ * @author Abshirdheere
  * @author Maax
  * @author Mimursal
  * @author Yariiska
@@ -138,6 +139,7 @@ $messages = array(
 'listingcontinuesabbrev'         => 'kont',
 'index-category'                 => 'Maqaalada indeksed',
 'noindex-category'               => 'Maqaalada noindeksed',
+'broken-file-category'           => 'Bog ka samaysan file aan jirin.',
 
 'about'         => 'Ku saabsan',
 'article'       => 'Qoraalka bogga oo kooban',
@@ -176,6 +178,7 @@ $messages = array(
 'vector-view-viewsource'         => 'Itusi xogta',
 'actions'                        => 'Waxa dhacaayo',
 'namespaces'                     => 'Xarun magaceedyada',
+'variants'                       => 'Isbedelada',
 
 'errorpagetitle'    => 'Qalad',
 'returnto'          => 'Ku noqo $1.',
@@ -256,8 +259,8 @@ $1',
 'mainpage'             => 'Bogga Hore',
 'mainpage-description' => 'Bogga Hore',
 'policy-url'           => 'Project: Xeerka',
-'portal'               => 'Bortaalka jaaliyada',
-'portal-url'           => 'Project:Bortaalka jaaliyada',
+'portal'               => 'Albaabka Bulshada',
+'portal-url'           => 'Project:Albaabka bulshada',
 'privacy'              => 'Xeerka Wiki',
 'privacypage'          => 'Project:Xeerka Wiki',
 
@@ -290,11 +293,15 @@ fiiri [[Special:Version|nooca bogga]].',
 'viewdeleted'             => 'Fiiri $1?',
 'restorelink'             => '{{PLURAL:$1|halxabo oo bedelkii la tirtiray|$1 bedelyadii la tirtiray}}',
 'feedlinks'               => 'Quudinta wararka:',
+'feed-invalid'            => 'Habka aad uga soo qayb gashay masaxna.',
+'feed-unavailable'        => 'Faallo diyaar maaha.',
 'site-rss-feed'           => '$1 RSS quudiye',
 'site-atom-feed'          => '$1 Atom quudiye',
 'page-rss-feed'           => '"$1" RSS quudiye',
 'page-atom-feed'          => '"$1" Atom quudiye',
 'red-link-title'          => '$1 (Bogga ma jiro)',
+'sort-descending'         => 'Habka hoos udhaca.',
+'sort-ascending'          => 'Habka kor u kaca.',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'Bog',
@@ -302,7 +309,7 @@ fiiri [[Special:Version|nooca bogga]].',
 'nstab-media'     => 'Bogga wararka',
 'nstab-special'   => 'Bogga khaaska ah',
 'nstab-project'   => 'Bogga mashruuca',
-'nstab-image'     => 'Fayl',
+'nstab-image'     => 'Gal',
 'nstab-mediawiki' => 'Fariin',
 'nstab-template'  => 'Tusmo',
 'nstab-help'      => 'Bogga caawinaada',
@@ -310,6 +317,9 @@ fiiri [[Special:Version|nooca bogga]].',
 
 # Main script and global functions
 'nosuchaction'      => 'Wax shaqo oo saas ah kama jiro',
+'nosuchactiontext'  => 'Waxaad soo raacday URL aan sax ahayn.
+waxaa laga yaabaa URL inaad u qortay hab aan sax ahayn, ama aad soo raacday mid aan jirin.
+waxaa laga yaabaa inuu kani tilmaamayo cilad jirta  {{SITENAME}}.',
 'nosuchspecialpage' => 'Wax bog oo sidaas khaas u ah ma jirto.',
 'nospecialpagetext' => '<strong>Waxaana weydiisay bog khaas ah oosan jirin.</strong>
 
@@ -339,6 +349,7 @@ Fadlan u sheek [[Special:ListUsers/sysop|maamulaha]], kana digtooneesii URL-ka.'
 'filenotfound'         => 'Ma oo san helin  faylka "$1".',
 'fileexistserror'      => 'Ma ku qori karin faylka "$1": faylkan wuu jiraa.',
 'unexpected'           => 'Qiimo loo maleeneenin: "$1"="$2".',
+'formerror'            => 'Qalad: suura gal maaha in la diraa qoraalkaan',
 'badarticleerror'      => 'Shaqadaan ma lagu sameyn karo boggaan.',
 'cannotdelete'         => 'Boggaan ama file\'ka "$1" mala tirtiri karo.
 waxaa laga yaabaa in oo qof kale tirtiray .',
@@ -352,6 +363,9 @@ Waxaa ku jiri kara xuruufo aanan loo isticmaalikarin cinwaan ahaan.',
 fadlan waxyar kadib ku soo noqo.',
 'protectedpagetext'    => 'Boggaan  waala difaacay si aan wax looga bedelin.',
 'viewsourcetext'       => 'Waad fiirin kartaa waana koobi gareen kartaa xogta boggaan:',
+'editinginterface'     => "'''Digniin:''' Waxaad guda gashay inaad badesho bogga lawada arkayo wajiga hore ee qoraalka softwareka.
+Waxa uu saameeyn ku yeelan doonaa boggaan habka uu wax u arko adeegsadaha iyo dhamaan adeegsadayaasha ee wikgaan.
+Si aad wax ugu kordhiso ama aad uga dhinto turjumaadda mashaariicda wikiga , fadlan adeegso [//translatewiki.net/ translatewiki.net], mashruuca gaarka ah ee MediaWiki.",
 'cascadeprotected'     => 'Boggaan waxaa laga difaacay in wax laga bedelo, sababtoo ah wuxuu ka midyahay  {{PLURAL:$1|bog, oo ah |bogyaalo ah, waana}}  kuwa laga difaacay "qoraalada kaskadka ah" dooqyada woo u furanyahay:
 $2',
 'namespaceprotected'   => "Ma laguu ogolo in aad wax ka bedesho maqaalada ku jirto '''$1''' xarun magaceedka.",
@@ -419,6 +433,7 @@ Sax hingaada, ama  [[Special:UserLogin/signup|samayso magac gudagale ah]].',
 'wrongpasswordempty'         => 'Erayga sirta aad qortay wuxuu ahaa ebar. Fadlan iskuday markale.',
 'passwordtooshort'           => 'Erayada sirta ah waa in oo ahaadaa ugu yaraan  {{PLURAL:$1|1 xaraf|$1 xarfood}} .',
 'password-name-match'        => 'Eraygaaga sirta ah waa in oo ka badalnaadaa magacaaga gudagale',
+'password-login-forbidden'   => 'Waxaa laga joojiyey adeegsiga magacaan iyo nambar sirtiisaba.',
 'mailmypassword'             => 'E-mail iigu soo dir ereysir cusub',
 'passwordremindertitle'      => 'Eraysir ku meelgaar ah oo loogu talagalay {{SITENAME}}',
 'passwordremindertext'       => 'Qof (laga yaabo in aad adiga tahay, kana soo galay cinwaanka-IP-ka  $1) ayaa eraysir oo cusub u codsaday  {{SITENAME}}  ($4).
@@ -455,7 +470,7 @@ Fadlan waxyar sug intii aadan soo gelin.',
 'login-abort-generic'        => 'Ma u soo gali karin gudaha - waa la noqay',
 'loginlanguagelabel'         => 'Luqada: $1',
 
-# E-mail sending
+# Email sending
 'user-mail-no-addy' => "Isku dayday in aa dirto e-mail ayada oo ciwaan e-mail la'aan ah.",
 
 # Change password dialog
@@ -505,6 +520,7 @@ Ereysirka kumeelgaarka ah: $2',
 'changeemail-newemail' => 'Ciwaan e-mail oo cusub:',
 'changeemail-none'     => '(waxna)',
 'changeemail-submit'   => 'Bedel e-mailka',
+'changeemail-cancel'   => 'Ka noqo',
 
 # Edit page toolbar
 'bold_sample'     => 'Far butac ah',
@@ -563,6 +579,7 @@ fadlan ku soo dar faahfaahinta ku qoran kor su'aalo kasto oo sameyso.",
 'whitelistedittext'                => 'Waa in aad $1 si aad wax uga bedeshid boggaga.',
 'confirmedittext'                  => 'Waa in aad xaqiijisaa e-mailkaada inta aadan bogaga wax ka bedelin.
 fadlan ku dar kuna xaqiiji e-mailkaada meesha  [[Special:Preferences|dooqyada gudagalahaaga]].',
+'nosuchsectiontitle'               => 'Qaybtaan lama heli karo',
 'nosuchsectiontext'                => 'Waxaa baroobeysay in aad wax ka bedesho maqaal jirin.
 Waxaa laga yaabaa in la wareejiyay ama la tirtiray adiga oo fiirinaayo bogga.',
 'loginreqtitle'                    => 'Waxaa loo baahanyahay gudagalid',
@@ -605,9 +622,9 @@ Fadlan markale isku day. Hadii aysan weli shaqaynin, ka bax ee markale soo gudag
 ''Sababtoo ah {{SITENAME}}han wuxuu leeyahay HTML ceyriin ah, horfiirintiisa waxaa loo qariyey si looga hortago weerar ka yimaada JavaScriptga.''
 
 '''Hadii wax ka bedlkaan uu yahay mid xaq ah, fadlan markale isku day. Hadii aysan weli shaqaynin, is kuday inaad  ka baxdo ee markale soo gudagal.'''",
-'editing'                          => 'Waxaa badaloosaa $1',
-'editingsection'                   => 'Waxaa wax ka badaloosaa $1 (qeyb yar)',
-'editingcomment'                   => 'Waxaa wax ka badaloosaa $1 (qeyb yar)',
+'editing'                          => 'Waxaad badalaysaa $1',
+'editingsection'                   => 'Waxaad wax ka bedelaysaa $1 (qeyb yar)',
+'editingcomment'                   => 'Waxaad wax ka bedelaysaa $1 (qeyb yar)',
 'editconflict'                     => 'Isku dhac badalaadka: $1',
 'yourtext'                         => 'Qoraalkaaga',
 'editingold'                       => "'''DIGNIIN: Waxaad wax ka bedeli rabtaa boggan caddadkiisa duqoobay.
@@ -633,11 +650,13 @@ Tirtiraha iyo wareejinta gudagalaha boggaan waxaad ka arki kartaa meeshaan:",
 'moveddeleted-notice'              => 'Boggaan waa la tirtiray.
 Tirtiraha iyo wareejinta gudagalaha boggaan waxaad ka arki kartaa hoostaan.',
 'edit-conflict'                    => 'Wax bedel isku dhacay',
+'edit-already-exists'              => 'Bog cusub lama samayn karo, wuu jiraa bogaan.',
 
 # Parser/template warnings
 'post-expand-template-inclusion-warning'  => "'''Digniin:''' Aad oo u weyn yahay tusmo'da aad ku dartay.
 Tusmooyinka qaar lagumo dari doono.",
 'post-expand-template-inclusion-category' => "Boggaga ku xad gudbay weyninka tusmo'da",
+'post-expand-template-argument-warning'   => "'''Digniin:'''Boggaan waxaa ku jira ugu yaraan hal iyo wixii ka badan oo template ah, waxaana ku xiran kuwa kale.",
 
 # "Undo" feature
 'undo-summary' => 'Noqay bedelaadka $1 ee sameeyay  [[Special:Contributions/$2|$2]] ([[User talk:$2|hadal]])',
@@ -707,9 +726,9 @@ sababteeda neh waxaa laga heli kartaa  [{{fullurl:{{#Special:Log}}/delete|page={
 'editundo'                 => 'ka noqo',
 
 # Search results
-'searchresults'                    => 'Raadi natiijooyinka',
-'searchresults-title'              => 'Raadi natiijoojika "$1"',
-'searchsubtitle'                   => 'Waxaad raadisay \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|dhamaan boggaga ka bilaawdo "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|dhamaan boggaga la xiriiro "$1"]])',
+'searchresults'                    => 'Natiijada raadinta (Baaris)',
+'searchresults-title'              => 'Raadinta natiijooyinka "$1"',
+'searchsubtitle'                   => 'Waxaad raadisay \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|dhamaan bogaaga ka bilaawdo "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|dhamaan bogagga la xiriiro "$1"]])',
 'searchsubtitleinvalid'            => "Waxaa raadisay '''$1'''",
 'prevn'                            => 'Ka horeeya {{PLURAL:$1|$1}}',
 'nextn'                            => 'Ku xiga {{PLURAL:$1|$1}}',
@@ -735,7 +754,8 @@ sababteeda neh waxaa laga heli kartaa  [{{fullurl:{{#Special:Log}}/delete|page={
 'search-result-category-size'      => '{{PLURAL:$1|1 ka mid ah|$1 ka mid ah}} ({{PLURAL:$2|1 qeybta hoose|$2 qeybaha hoose}}, {{PLURAL:$3|1 fayl|$3 fayl-yo}})',
 'search-redirect'                  => '(waxaa loo toosiyay $1)',
 'search-section'                   => '(maqaalka $1)',
-'search-suggest'                   => 'Waxaa ka waday miyaa: $1',
+'search-suggest'                   => 'Ma waxaad ulajeeday: $1',
+'search-interwiki-caption'         => 'Mashaariicda walaalaha',
 'search-interwiki-default'         => '$1 natiijooyinka:',
 'search-interwiki-more'            => '(wax kale)',
 'search-mwsuggest-enabled'         => 'soojeedin',
@@ -743,6 +763,8 @@ sababteeda neh waxaa laga heli kartaa  [{{fullurl:{{#Special:Log}}/delete|page={
 'search-relatedarticle'            => 'La xiriiro',
 'searchrelated'                    => 'La xiriiro',
 'searchall'                        => 'Dhamaan',
+'showingresults'                   => "Waxaa hoos laga heley{{PLURAL:$1|'''1''' natiijo|'''$1''' natiijooyin}} ka biloow #'''$2'''.",
+'showingresultsnum'                => "Hoos waxaa laga helay {{PLURAL:$3|'''1''' Natiijo|'''$3''' Natiijooyin}} Ka billow #'''$2'''.",
 'showingresultsheader'             => "{{PLURAL:$5|Natiijada  '''$1''' ee '''$3'''|Natiijooyinka '''$1 - $2'''  oo ah  '''$3'''}} ee '''$4'''",
 'search-nonefound'                 => 'Wax natiijo oo ka soo baxay ma jirto wixii aad raadisay',
 'powersearch'                      => 'Sidii aad wax uugu raadin laheed',
@@ -807,20 +829,23 @@ E-mailkaada mala sheegaayo markii ee dadka kale kula soo xiriirayaan.',
 # User rights
 'saveusergroups'          => 'Kaydi kooxaha isticmaalayaasha',
 'userrights-groupsmember' => 'Ka mid ah:',
+'userrights-reason'       => 'Sababta:',
 
 # Groups
-'group'       => 'Koox:',
-'group-user'  => 'Isticmaalada',
-'group-bot'   => 'botyada',
-'group-sysop' => 'Maamulada',
-'group-all'   => '(dhamaan)',
+'group'               => 'Koox:',
+'group-user'          => 'Isticmaalada',
+'group-autoconfirmed' => 'Gude galayaasha la hubiyey si iskeed ah',
+'group-bot'           => 'botyada',
+'group-sysop'         => 'Maamulada',
+'group-all'           => '(dhamaan)',
 
 'group-user-member'  => '{{GENDER:$1|isticmaale}}',
 'group-bot-member'   => '{{GENDER:$1|bot}}',
 'group-sysop-member' => '{{GENDER:$1|maamulaha}}',
 
-'grouppage-user'  => '{{ns:project}}:Isticmaalada',
-'grouppage-sysop' => '{{ns:project}}:Maamulada',
+'grouppage-user'          => '{{ns:project}}:Isticmaalada',
+'grouppage-autoconfirmed' => '{{ns:project}}:Adeegsade la hubiyey',
+'grouppage-sysop'         => '{{ns:project}}:Maamulada',
 
 # Rights
 'right-read'          => 'Akhri maqaalada',
@@ -950,6 +975,7 @@ ku saabsan: $1',
 'filehist-thumb'         => 'Sawir yar',
 'filehist-thumbtext'     => 'Sawirka yar nuuciisa ahaa $1',
 'filehist-user'          => 'Isticmaale',
+'filehist-dimensions'    => 'Cabirka',
 'filehist-comment'       => 'Ka hadalka',
 'imagelinks'             => 'Faylka lagu isticmaalay',
 'linkstoimage'           => 'Boggagaan soo socota ee  {{PLURAL:$1|ah waxey la xiriiraan|$1 ah waxey la xiriiraan}} faylkan:',
@@ -980,24 +1006,26 @@ Tafaasiishiisa waxee ku qorantahay [$2 bogga tafaasiisha faylka] oo ka arki kart
 'brokenredirects-delete' => 'tirtir',
 
 # Miscellaneous special pages
-'nbytes'             => '$1 {{PLURAL:$1|bayt|bayt}}',
-'nmembers'           => ' $1 {{PLURAL:$1|ka mid ah|ka mid ah}}',
-'lonelypages'        => 'Boggaga agoonta ah',
-'uncategorizedpages' => 'Maqaalada aan la aruurin',
-'popularpages'       => 'Boggaga caanka ah',
-'prefixindex'        => 'Dhamaan boggaga leh qoraalka hore',
-'shortpages'         => 'Boggaga gaaban',
-'longpages'          => 'Boggaga dhaadheer',
-'deadendpages'       => 'Boggaga aanan la daba joogin',
-'deadendpagestext'   => 'Boggagaan soo socota lama xiriiraan boggaga kale ee {{SITENAME}}.',
-'protectedpages'     => "Boggag la'difaacay",
-'usercreated'        => '{{GENDER:$3|Sameeyay}} marka ee eheed $1 saacada $2',
-'newpages'           => 'Bogyaalo cusub',
-'newpages-username'  => 'Magaca gudagalka:',
-'ancientpages'       => 'Boggaga duqoobay',
-'move'               => 'Wareeji',
-'pager-newer-n'      => '{{PLURAL:$1|ka cusub 1|ka cusub $1}}',
-'pager-older-n'      => '{{PLURAL:$1|ka duqsan 1|ka duqsan $1}}',
+'nbytes'                 => '$1 {{PLURAL:$1|bayt|bayt}}',
+'nmembers'               => ' $1 {{PLURAL:$1|ka mid ah|ka mid ah}}',
+'lonelypages'            => 'Boggaga agoonta ah',
+'uncategorizedpages'     => 'Maqaalada aan la aruurin',
+'popularpages'           => 'Boggaga caanka ah',
+'prefixindex'            => 'Dhamaan bogagga leh qoraalka hore',
+'shortpages'             => 'Boggaga gaaban',
+'longpages'              => 'Boggaga dhaadheer',
+'deadendpages'           => 'Boggaga aanan la daba joogin',
+'deadendpagestext'       => 'Boggagaan soo socota lama xiriiraan boggaga kale ee {{SITENAME}}.',
+'protectedpages'         => "Boggag la'difaacay",
+'listusers-editsonly'    => 'Itus adeegsede yaasha sameeyey bedalka oo kaliya',
+'listusers-creationsort' => 'Ka dhig si ah taariikhdii la sameeyey',
+'usercreated'            => '{{GENDER:$3|Sameeyay}} marka ee eheed $1 saacada $2',
+'newpages'               => 'Bogyaalo cusub',
+'newpages-username'      => 'Magaca gudagalka:',
+'ancientpages'           => 'Boggaga duqoobay',
+'move'                   => 'Wareeji',
+'pager-newer-n'          => '{{PLURAL:$1|ka cusub 1|ka cusub $1}}',
+'pager-older-n'          => '{{PLURAL:$1|ka duqsan 1|ka duqsan $1}}',
 
 # Book sources
 'booksources'               => 'Xogta buuga',
@@ -1008,14 +1036,14 @@ Tafaasiishiisa waxee ku qorantahay [$2 bogga tafaasiisha faylka] oo ka arki kart
 'log' => 'Guda galayaasha',
 
 # Special:AllPages
-'allpages'          => 'Dhamaan boggaga',
+'allpages'          => 'Dhamaan bogagga',
 'alphaindexline'    => '$1 ilaa $2',
 'nextpage'          => 'Bogga ku xiga ($1)',
 'prevpage'          => 'Bogga ka horeeyo ($1)',
 'allpagesfrom'      => 'Soosaar boggaga ka bilaawda:',
-'allarticles'       => 'Dhamaan boggaga',
-'allinnamespace'    => 'Dhamaan boggaga ($1 namespace)',
-'allnotinnamespace' => 'Dhamaan boggaga (aan ku jirin xarun magaceedka $1)',
+'allarticles'       => 'Dhamaan bogagga',
+'allinnamespace'    => 'Dhamaan bogagga ($1 namespace)',
+'allnotinnamespace' => 'Dhamaan bogagga (aan ku jirin xarun magaceedka $1)',
 'allpagesprev'      => 'ka hore',
 'allpagesnext'      => 'Ku xiga',
 'allpagessubmit'    => 'Soco',
@@ -1043,7 +1071,7 @@ Tafaasiishiisa waxee ku qorantahay [$2 bogga tafaasiisha faylka] oo ka arki kart
 # Special:ListGroupRights
 'listgrouprights-members' => '(Inta ka mid ah liiskooda)',
 
-# E-mail user
+# Email user
 'mailnologin'     => "Ma'jiro cinwaan wax lagu diro",
 'mailnologintext' => 'Waa in aad [[Special:UserLogin|gudaha ku jirtaa]]
 kuna haysatid E-boosto sax ah [[Special:Preferences|dooqyadaada]],
@@ -1087,6 +1115,10 @@ Hadii aad rabootid in aad boggan ka saartid wardiyeynta, dhagsii \"Ha' wardiyeyn
 # Displayed when you click the "watch" button and it is in the process of watching
 'watching' => 'Daawasho...',
 
+'enotif_lastvisited' => 'Eeg $1 Dhamaan isbedeleda ilaa goortii kuugu dambaysay.',
+'enotif_lastdiff'    => 'Eeg $1 si aad u aragto bedelkaan.',
+'enotif_anon_editor' => 'Aan la qoon $1',
+
 # Delete
 'confirm'        => 'Xaqiiji',
 'excontent'      => "qoraalka wuxuu ahaa: '$1'",
@@ -1108,24 +1140,27 @@ Hadii aad rabootid in aad boggan ka saartid wardiyeynta, dhagsii \"Ha' wardiyeyn
 Wuxuu ku badalay bedelkii ka danbeeyay oo sameeyay $2.',
 
 # Protect
-'protectlogpage'         => 'Difaacida gudagalaheeda',
-'protectedarticle'       => 'la difaacay "[[$1]]"',
-'protect-title'          => 'Ka badal heerka difaacida   "$1"',
-'prot_1movedto2'         => '[[$1]] waxaa loo wareejiyey [[$2]]',
-'protect-legend'         => 'Xaqiiji difaacida',
-'protectcomment'         => 'Sababta:',
-'protectexpiry'          => 'wuxuu dhacaa:',
-'protect_expiry_invalid' => "Wakhtiga dhicitaanka sax ma'aha.",
-'protect_expiry_old'     => 'Wakhtiga dhictaanka waa mid laga soo dhaafay.',
-'protect-default'        => 'U ogolaaw isticmaalada oo dhan',
-'protect-fallback'       => 'waxaa loo baahanyahay "$1"  ogolaasho',
-'protect-level-sysop'    => 'Maamulada kaliya',
-'protect-expiring'       => 'wuxuu dhacaa  $1 (UTC)',
-'protect-cascade'        => 'Is daba dhiga difaacida - difaac bogga walba oo lagu daro boggaan.',
-'protect-othertime'      => 'Waqti kale:',
-'protect-othertime-op'   => 'waqti kale',
-'restriction-type'       => 'Ogolaasho:',
-'restriction-level'      => 'Xadka xadidaada:',
+'protectlogpage'            => 'Difaacida gudagalaheeda',
+'protectlogtext'            => 'Hoos waxaa ku qoran isbedelada ilaaliya bogagga.
+eeg [[Special:ProtectedPages|Liiska bogagga dhowrsoon]] liiska bogagga howlaha dhowrista ee hadda.',
+'protectedarticle'          => 'la difaacay "[[$1]]"',
+'modifiedarticleprotection' => 'Ka badal heerka difaacida "[[$1]]"',
+'protect-title'             => 'Ka badal heerka difaacida   "$1"',
+'prot_1movedto2'            => '[[$1]] waxaa loo wareejiyey [[$2]]',
+'protect-legend'            => 'Xaqiiji difaacida',
+'protectcomment'            => 'Sababta:',
+'protectexpiry'             => 'wuxuu dhacaa:',
+'protect_expiry_invalid'    => "Wakhtiga dhicitaanka sax ma'aha.",
+'protect_expiry_old'        => 'Wakhtiga dhictaanka waa mid laga soo dhaafay.',
+'protect-default'           => 'U ogolaaw isticmaalada oo dhan',
+'protect-fallback'          => 'waxaa loo baahanyahay "$1"  ogolaasho',
+'protect-level-sysop'       => 'Maamulada kaliya',
+'protect-expiring'          => 'wuxuu dhacaa  $1 (UTC)',
+'protect-cascade'           => 'Is daba dhiga difaacida - difaac bogga walba oo lagu daro boggaan.',
+'protect-othertime'         => 'Waqti kale:',
+'protect-othertime-op'      => 'waqti kale',
+'restriction-type'          => 'Ogolaasho:',
+'restriction-level'         => 'Xadka xadidaada:',
 
 # Restrictions (nouns)
 'restriction-edit' => 'Wax ka bedel',
@@ -1137,6 +1172,7 @@ Wuxuu ku badalay bedelkii ka danbeeyay oo sameeyay $2.',
 # Undelete
 'undelete'                 => "Fiiri boggaga la'tirtiray",
 'undeletepage'             => "Fiiri dibna u sooceli boggaga la'tirtiray",
+'undeletepagetitle'        => "'''Meeshaan waxa ay ka koobatahay raadka wixii laga tiray[[:$1|$1]]'''.",
 'viewdeletedpage'          => "Fiiri boggaga la'tirtiray",
 'undeletebtn'              => 'Sooceli',
 'undeletelink'             => 'fiiri/mar kale sameey',
@@ -1203,6 +1239,9 @@ Wuxuu ku badalay bedelkii ka danbeeyay oo sameeyay $2.',
 'autoblocker'              => 'Waxaa automaatik u xirista keenay in mudo dhow uu cinwaanka IP:ga isticmaalay "[[User:$1|$1]]". Sababta keentay in loo xiro $1 waa: "\'\'\'$2\'\'\'"',
 'blocklogpage'             => 'Mamnuucida guda galaheeda',
 'blocklogentry'            => 'la mamnuucay  [[$1]] Waqtiga uu dhacaayo neh waa $2 $3',
+'blocklogtext'             => 'Halkaan waa  liiska lagu muujiyo manuuca iyo mamnuuc ka qaadista.
+Ciwaanka IP ga ee la mamnuucay so iskeedka ee aan la soo ban dhigin.
+Eeg [[Special:BlockList|Mamnuucyada]] si aad u aragto liiska mamnuucyada ee hadda shaqaynaua.',
 'unblocklogentry'          => 'lama mamnuucin $1',
 'block-log-flags-anononly' => "Isticmaalayaasha aanan la'aqoonsanin oo kaliya",
 'block-log-flags-nocreate' => 'sameynta gudagalah lamaogola',
@@ -1239,64 +1278,66 @@ Fadlan booqo [//www.mediawiki.org/wiki/Localisation MediaWiki Localisation] iyo
 'thumbnail_error' => 'Qalad sameynta thumbnail: $1',
 
 # Tooltip help for the actions
-'tooltip-pt-userpage'             => 'Boggaaga isticmaalaha',
-'tooltip-pt-mytalk'               => 'Bogaaga wadahadalka',
-'tooltip-pt-preferences'          => 'Dooqyadeyda',
-'tooltip-pt-watchlist'            => 'Liiska bogga aad adiga ka waardiyeeyneyso isbedelada',
-'tooltip-pt-mycontris'            => 'Liiska intii aad ku darsatay',
-'tooltip-pt-login'                => 'Waxaa loo baahanyahay in aad gudaha gashid; laakiin,  laasim ma ahan',
-'tooltip-pt-logout'               => 'Ka bax',
-'tooltip-ca-talk'                 => 'Wadahadal ku saabsan bogga qoraalka',
-'tooltip-ca-edit'                 => 'Boggaan wax waad ka bedelikartaa. Intii aadan kaydinin fadlan isticmaal batoonka horfiirinta.',
-'tooltip-ca-addsection'           => 'Bilaaw qeyb cusub',
-'tooltip-ca-viewsource'           => 'Boggaan waa la difaacay.
+'tooltip-pt-userpage'              => 'Boggaaga isticmaalaha',
+'tooltip-pt-mytalk'                => 'Bogaaga wadahadalka',
+'tooltip-pt-preferences'           => 'Dooqyadeyda',
+'tooltip-pt-watchlist'             => 'Liiska bogga aad adiga ka waardiyeeyneyso isbedelada',
+'tooltip-pt-mycontris'             => 'Liiska intii aad ku darsatay',
+'tooltip-pt-login'                 => 'Waxaa loo baahanyahay in aad gudaha gashid; laakiin,  laasim ma ahan',
+'tooltip-pt-logout'                => 'Ka bax',
+'tooltip-ca-talk'                  => 'Wadahadal ku saabsan bogga qoraalka',
+'tooltip-ca-edit'                  => 'Boggaan wax waad ka bedelikartaa. Intii aadan kaydinin fadlan isticmaal batoonka horfiirinta.',
+'tooltip-ca-addsection'            => 'Bilaaw qeyb cusub',
+'tooltip-ca-viewsource'            => 'Boggaan waa la difaacay.
 Waxaa fiiri kartaa cadaadkiisa',
-'tooltip-ca-history'              => 'Bedelyadii hore ee boggaan.',
-'tooltip-ca-protect'              => 'Difaac boggaan',
-'tooltip-ca-delete'               => 'Bogaan tirtir',
-'tooltip-ca-undelete'             => "Soo celi waxyaabihii laga badalay boggaan intii aanan la'tirtirin",
-'tooltip-ca-move'                 => 'Wareeji boggaan',
-'tooltip-ca-watch'                => 'Boggaan ku dar liiskaaga waardiyaha',
-'tooltip-ca-unwatch'              => 'Boggaan ka saar liiskaaga waardiyaha',
-'tooltip-search'                  => 'Ka raadi {{SITENAME}}',
-'tooltip-search-go'               => 'Aad bog oo magacaan ku qoran hadii oo jiro',
-'tooltip-search-fulltext'         => 'Qoraalkaan ka raadi bogyaasha',
-'tooltip-p-logo'                  => 'Bogga Hore',
-'tooltip-n-mainpage'              => 'Soo booqo bogga hore',
-'tooltip-n-mainpage-description'  => 'Booqo bogga hore',
-'tooltip-n-portal'                => 'Faahfaahinta mashruuca, waxaad ku caawinkartid, xageed ka helikartaa waxaad u baahantahay',
-'tooltip-n-currentevents'         => 'Soo raadi war ku saabsan hadda waxa dhacaayo',
-'tooltip-n-recentchanges'         => 'tirada Intii ugu danbeysay oo wax laga bedelay wiki',
-'tooltip-n-randompage'            => 'Ku nasiibso bog',
-'tooltip-n-help'                  => 'Meesha lagu ogaan karo',
-'tooltip-t-whatlinkshere'         => 'Liiska inta bog oo wiki ah oo meeshaan la xiriiro',
-'tooltip-t-recentchangeslinked'   => 'Isbedelada dhow ee boggaga oo laga soo xiriiriyay boggaan',
-'tooltip-feed-atom'               => 'Atom aa quudiyo boggaan',
-'tooltip-t-contributions'         => 'Itusi liiska inta wax oo ku darsaday isticmaalahaan',
-'tooltip-t-emailuser'             => 'E-mail u dir isticmaalahaan',
-'tooltip-t-upload'                => 'Soo geli fayl',
-'tooltip-t-specialpages'          => 'Liiska boggaga qaaska ah oo dhan',
-'tooltip-t-print'                 => 'Nuuca la soo daabici karo ee boggaan',
-'tooltip-t-permalink'             => 'Linkiga daaimka ah ee  bedelaadka boggaan',
-'tooltip-ca-nstab-main'           => 'Itusi bogga qoraaka kooban',
-'tooltip-ca-nstab-user'           => 'Fiiri bogga isticmaalaha',
-'tooltip-ca-nstab-media'          => 'Fiiri bogga saxaafada',
-'tooltip-ca-nstab-special'        => 'Kani bogg khaas ah, waxba kama bedelikartid boggaan',
-'tooltip-ca-nstab-project'        => 'Itusi bogga mashruuca',
-'tooltip-ca-nstab-image'          => 'Fiiri faylka bogga',
-'tooltip-ca-nstab-mediawiki'      => 'Fiiri bogga fariimaha sistamka',
-'tooltip-ca-nstab-template'       => 'Fiiri tusmada',
-'tooltip-ca-nstab-help'           => 'Fiiri bogga caawinaad',
-'tooltip-ca-nstab-category'       => 'Itusi qeybta bogga',
-'tooltip-minoredit'               => 'Calaamadeey kan in oo yahay bedel yar',
-'tooltip-save'                    => 'kaydso badalyadaada',
-'tooltip-preview'                 => 'Feerinta wixii aad bedeshay, fadlan kan isticmaal intii aadan kaydinin!',
-'tooltip-diff'                    => 'Fiiri waxa aad ka badashay qoraalka',
-'tooltip-compareselectedversions' => 'Fiiri sida ee u kala duwanyihiin  bedelaadka labada aad ka dooratay boggaan',
-'tooltip-watch'                   => 'Boggaan ku dar liiskaaga waardiyaha',
-'tooltip-rollback'                => '"Dib u soo celi" wuxuu dib boggaan ugu soo celinaa qofkii ugu danbeeyay wixii oo ku darsaday hal riix kaliya',
-'tooltip-undo'                    => '"Ka noqo" wuxuu dib u noqaa badalkaan wuxuuna furaa badalkii ka horeey.Wuxuu kuu fasaxaa in aad ku dartid sababta.',
-'tooltip-summary'                 => 'ku qor qoraal kooban',
+'tooltip-ca-history'               => 'Bedelyadii hore ee boggaan.',
+'tooltip-ca-protect'               => 'Difaac boggaan',
+'tooltip-ca-delete'                => 'Bogaan tirtir',
+'tooltip-ca-undelete'              => "Soo celi waxyaabihii laga badalay boggaan intii aanan la'tirtirin",
+'tooltip-ca-move'                  => 'Wareeji boggaan',
+'tooltip-ca-watch'                 => 'Boggaan ku dar liiskaaga waardiyaha',
+'tooltip-ca-unwatch'               => 'Boggaan ka saar liiskaaga waardiyaha',
+'tooltip-search'                   => 'Ka raadi {{SITENAME}}',
+'tooltip-search-go'                => 'Aad bog oo magacaan ku qoran hadii oo jiro',
+'tooltip-search-fulltext'          => 'Qoraalkaan ka raadi bogyaasha',
+'tooltip-p-logo'                   => 'Bogga Hore',
+'tooltip-n-mainpage'               => 'Soo booqo bogga hore',
+'tooltip-n-mainpage-description'   => 'Booqo bogga hore',
+'tooltip-n-portal'                 => 'Faahfaahinta mashruuca, waxaad ku caawinkartid, xageed ka helikartaa waxaad u baahantahay',
+'tooltip-n-currentevents'          => 'Soo raadi war ku saabsan hadda waxa dhacaayo',
+'tooltip-n-recentchanges'          => 'tirada Intii ugu danbeysay oo wax laga bedelay wiki',
+'tooltip-n-randompage'             => 'Ku nasiibso bog',
+'tooltip-n-help'                   => 'Meesha lagu ogaan karo',
+'tooltip-t-whatlinkshere'          => 'Liiska inta bog oo wiki ah oo meeshaan la xiriiro',
+'tooltip-t-recentchangeslinked'    => 'Isbedelada dhow ee boggaga oo laga soo xiriiriyay boggaan',
+'tooltip-feed-atom'                => 'Atom aa quudiyo boggaan',
+'tooltip-t-contributions'          => 'Itusi liiska inta wax oo ku darsaday isticmaalahaan',
+'tooltip-t-emailuser'              => 'E-mail u dir isticmaalahaan',
+'tooltip-t-upload'                 => 'Soo geli fayl',
+'tooltip-t-specialpages'           => 'Liiska boggaga qaaska ah oo dhan',
+'tooltip-t-print'                  => 'Nuuca la soo daabici karo ee boggaan',
+'tooltip-t-permalink'              => 'Linkiga daaimka ah ee  bedelaadka boggaan',
+'tooltip-ca-nstab-main'            => 'Itusi bogga qoraaka kooban',
+'tooltip-ca-nstab-user'            => 'Fiiri bogga isticmaalaha',
+'tooltip-ca-nstab-media'           => 'Fiiri bogga saxaafada',
+'tooltip-ca-nstab-special'         => 'Kani bogg khaas ah, waxba kama bedelikartid boggaan',
+'tooltip-ca-nstab-project'         => 'Itusi bogga mashruuca',
+'tooltip-ca-nstab-image'           => 'Fiiri faylka bogga',
+'tooltip-ca-nstab-mediawiki'       => 'Fiiri bogga fariimaha sistamka',
+'tooltip-ca-nstab-template'        => 'Fiiri tusmada',
+'tooltip-ca-nstab-help'            => 'Fiiri bogga caawinaad',
+'tooltip-ca-nstab-category'        => 'Itusi qeybta bogga',
+'tooltip-minoredit'                => 'Calaamadeey kan in oo yahay bedel yar',
+'tooltip-save'                     => 'kaydso badalyadaada',
+'tooltip-preview'                  => 'Feerinta wixii aad bedeshay, fadlan kan isticmaal intii aadan kaydinin!',
+'tooltip-diff'                     => 'Fiiri waxa aad ka badashay qoraalka',
+'tooltip-compareselectedversions'  => 'Fiiri sida ee u kala duwanyihiin  bedelaadka labada aad ka dooratay boggaan',
+'tooltip-watch'                    => 'Boggaan ku dar liiskaaga waardiyaha',
+'tooltip-watchlistedit-raw-submit' => 'Liska waardiyeha dib u howlageli',
+'tooltip-rollback'                 => '"Dib u soo celi" wuxuu dib boggaan ugu soo celinaa qofkii ugu danbeeyay wixii oo ku darsaday hal riix kaliya',
+'tooltip-undo'                     => '"Ka noqo" wuxuu dib u noqaa badalkaan wuxuuna furaa badalkii ka horeey.Wuxuu kuu fasaxaa in aad ku dartid sababta.',
+'tooltip-preferences-save'         => 'Kaydi isbedelada',
+'tooltip-summary'                  => 'ku qor qoraal kooban',
 
 # Attribution
 'anonymous'        => "{{PLURAL:$1|Isticmaalaha|Isticmaaleyaasa}} aanan la'aqoonsanin ee {{SITENAME}}",
@@ -1304,6 +1345,9 @@ Waxaa fiiri kartaa cadaadkiisa',
 'lastmodifiedatby' => 'Bogaan waxaa ugu dambeyntii wax laga bedelay $2, $1 kana bedelay $3.',
 'othercontribs'    => 'Waxay ku saleysantahay shaqada $1.',
 
+# Info page
+'pageinfo-title' => 'Macluumaad ku saabsan "$1"',
+
 # Browsing diffs
 'previousdiff' => '← bedelkii ka duqsanaa',
 'nextdiff'     => 'Bedelkii ugu cusbaa →',
@@ -1347,9 +1391,12 @@ Hadii faylka wax laga badalay sida oo markiisa hore ahaa, waxaa laga yaabaa in e
 'namespacesall' => 'dhamaan',
 'monthsall'     => 'Dhamaan',
 
-# E-mail address confirmation
+# Email address confirmation
 'confirmemail_noemail' => 'Kuma haysatid cinwaan E-boosto sax [[Special:Preferences|isticmaala dooqiisa]].',
 
+# action=watch/unwatch
+'confirm-unwatch-top' => 'Boggaan ka saar liiskaaga waardiyaha',
+
 # Multipage image navigation
 'imgmultigo' => 'Soco!',
 
@@ -1363,6 +1410,13 @@ Hadii faylka wax laga badalay sida oo markiisa hore ahaa, waxaa laga yaabaa in e
 'autosumm-replace' => 'Wuxuu qoraalka ku badalay "$1"',
 'autosumm-new'     => 'Bog cusub: $1',
 
+# Watchlist editor
+'watchlistedit-normal-legend'  => 'Ka saar ciwaanada liiska waardiyaha',
+'watchlistedit-normal-explain' => 'Ciwaanada ee liiskaada waardiyaha hoos ayaa lagu soo ban dhigay.
+Si aad u tirtito Ciwaanka, Godka udhow calaameey, ee guji "{{int:Watchlistedit-normal-submit}}".
+waxaad awoodaa [[Special:EditWatchlist/raw|Liiska wax ka bedel]].',
+'watchlistedit-raw-legend'     => 'Badal liiska waardiyeenta ceeriinka ah',
+
 # Watchlist editing tools
 'watchlisttools-view' => 'Itusi isbedelada jiro',
 'watchlisttools-edit' => 'Fiiri iyo wax ka badal liiska waardiyaha',
@@ -1380,12 +1434,15 @@ Hadii faylka wax laga badalay sida oo markiisa hore ahaa, waxaa laga yaabaa in e
 'fileduplicatesearch-submit' => 'Raadi',
 
 # Special:SpecialPages
-'specialpages'             => 'bogaga khaaska ah',
+'specialpages'             => 'bogagga khaaska ah',
 'specialpages-group-pages' => 'liiska maqaalada',
 
 # Special:BlankPage
 'blankpage' => 'Bog masaxan',
 
+# Special:Tags
+'tag-filter' => '[[Special:Tags|Filtaraha]] tag:',
+
 # Database error messages
 'dberr-usegoogle' => 'Waxaa baroobeen kartaa in aad ka raadiso google',
 
@@ -1393,6 +1450,9 @@ Hadii faylka wax laga badalay sida oo markiisa hore ahaa, waxaa laga yaabaa in e
 'htmlform-reset'               => 'Ka noqo wax bedelka',
 'htmlform-selectorother-other' => 'kuwa kale',
 
+# Feedback
+'feedback-message' => 'Fariinta:',
+
 # API errors
 'api-error-copyuploaddisabled' => 'Soo gelinta dhinaca URL-ka waa laga damiyay kombiyuutarkaan',
 'api-error-filename-tooshort'  => 'Magaca faylka aad oo u gaabanyahay',
