@@ -1,5 +1,5 @@
 <?php
-/** Tetum (Tetun)
+/** Tetum (tetun)
  *
  * See MessagesQqq.php for message documentation incl. usage of parameters
  * To improve a translation please visit http://translatewiki.net
@@ -8,6 +8,7 @@
  * @file
  *
  * @author MF-Warburg
+ * @author Nemo bis
  * @author Reedy
  */
 
@@ -72,22 +73,26 @@ $specialPageAliases = array(
 
 $messages = array(
 # User preference toggles
-'tog-underline'          => 'Subliña ligasaun sira:',
-'tog-highlightbroken'    => 'Formatu ligasaun sira-ne\'ebé bá pájina maka wiki la iha: <a href="" class="new">ne\'e</a> ka <a href="" class="internal">ne\'e</a>.',
-'tog-justify'            => 'Justifika parágrafu sira',
-'tog-hideminor'          => "Lá'os hatudu muda ki-ki'ik iha mudansa foufoun sira",
-'tog-usenewrc'           => 'Uza lista "Mudansa foufoun sira" di\'ak liu (JavaScript)',
-'tog-showtoolbar'        => 'Hatudu kaixa edita (presiza JavaScript)',
-'tog-watchcreations'     => "Hateke pájina sira-ne'ebé ha'u kria",
-'tog-watchdefault'       => "Hateke pájina sira-ne'ebé ha'u edita",
-'tog-watchmoves'         => "Hateke pájina sira-ne'ebé ha'u book",
-'tog-watchdeletion'      => "Hateke pájina sira-ne'ebé ha'u halakon",
-'tog-watchlisthideown'   => "La hatudu ha'u-nia edita iha lista hateke",
-'tog-watchlisthidebots'  => 'Hamsumik bot iha lista hateke',
-'tog-watchlisthideminor' => "Hamsumik muda ki-ki'ik iha lista hateke",
-'tog-watchlisthideliu'   => 'La hatudu edita ema rejista nian iha lista hateke',
-'tog-watchlisthideanons' => 'La hatudu edita ema anónimu nian iha lista hateke',
-'tog-showhiddencats'     => "Hatudu kategoria sira-ne'ebé subar",
+'tog-underline'              => 'Subliña ligasaun sira:',
+'tog-highlightbroken'        => 'Formatu ligasaun sira-ne\'ebé bá pájina maka wiki la iha: <a href="" class="new">ne\'e</a> ka <a href="" class="internal">ne\'e</a>.',
+'tog-justify'                => 'Justifika parágrafu sira',
+'tog-hideminor'              => "Lá'os hatudu muda ki-ki'ik iha mudansa foufoun sira",
+'tog-usenewrc'               => 'Iha lista "mudansa foufoun sira" no "lista hateke": Hatudu mudansa iha grupu sira - grupu ida ba pájina ida (presiza JavaScript)',
+'tog-showtoolbar'            => 'Hatudu kaixa edita (presiza JavaScript)',
+'tog-watchcreations'         => "Hateke pájina no imajen sira-ne'ebé ha'u kria/tau iha arkivu laran",
+'tog-watchdefault'           => "Hateke pájina sira-ne'ebé ha'u edita",
+'tog-watchmoves'             => "Hateke pájina sira-ne'ebé ha'u book",
+'tog-watchdeletion'          => "Hateke pájina sira-ne'ebé ha'u halakon",
+'tog-minordefault'           => 'Edita hotu-hotu "ki\'ik"',
+'tog-oldsig'                 => 'Asinatura atuál',
+'tog-watchlisthideown'       => "La hatudu ha'u-nia edita iha lista hateke",
+'tog-watchlisthidebots'      => 'Hamsumik bot iha lista hateke',
+'tog-watchlisthideminor'     => "Hamsumik muda ki-ki'ik iha lista hateke",
+'tog-watchlisthideliu'       => 'La hatudu edita ema rejista nian iha lista hateke',
+'tog-watchlisthideanons'     => 'La hatudu edita ema anónimu nian iha lista hateke',
+'tog-watchlisthidepatrolled' => 'Hamsumik muda patrolada iha lista hateke',
+'tog-ccmeonemails'           => "Haruka ba ha'u kopia korreiu eletróniku nian ne'ebé ha'u korreia",
+'tog-showhiddencats'         => "Hatudu kategoria sira-ne'ebé subar",
 
 'underline-always' => 'Sempre',
 'underline-never'  => 'Nunka',
@@ -156,7 +161,7 @@ $messages = array(
 'cancel'        => 'Para',
 'moredotdotdot' => 'Barak liu...',
 'mypage'        => "Ha'u-nia pájina",
-'mytalk'        => "Ha'u-nia diskusaun",
+'mytalk'        => 'Diskusaun',
 'anontalk'      => "Diskusaun ba IP ne'e",
 'navigation'    => 'Hatudu-dalan',
 'and'           => '&#32;ho',
@@ -171,9 +176,12 @@ $messages = array(
 'faqpage'        => 'Project:FAQ',
 
 # Vector skin
-'vector-view-create'  => 'Kria',
-'vector-view-edit'    => 'Edita',
-'vector-view-history' => 'Haree istória',
+'vector-action-protect' => 'Proteje',
+'vector-view-create'    => 'Kria',
+'vector-view-edit'      => 'Edita',
+'vector-view-history'   => 'Haree istória',
+'vector-view-view'      => 'Lee',
+'actions'               => 'Aksaun sira',
 
 'errorpagetitle'    => 'Sala',
 'returnto'          => 'Fali ba $1.',
@@ -345,7 +353,8 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'loginreqpagetext'                 => 'Ó tenke $1 ba haree pájina seluk.',
 'newarticle'                       => '(Foun)',
 'noarticletext'                    => "Iha momentu lá'os testu iha pájina ne'e, bele [[Special:Search/{{PAGENAME}}|buka naran pájina nian]] iha pájina seluk, <span class=\"plainlinks\">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} search the related logs], ka [{{fullurl:{{FULLPAGENAME}}|action=edit}} edita pájina ne'e]</span>.",
-'previewnote'                      => "'''Ne'e de'it pájina ba kontrola; Ita-nia mudansa la armazenadu seidauk!'''",
+'previewnote'                      => "'''Ne'e de'it pájina ba kontrola.'''
+Ita-nia mudansa la armazenadu seidauk!",
 'editing'                          => 'Edita $1',
 'editingsection'                   => 'Edita $1 (seksaun)',
 'editingcomment'                   => 'Edita $1 (seksaun foun)',
@@ -366,12 +375,13 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 # History pages
 'currentrev'          => 'Versaun atuál',
 'revisionasof'        => 'Versaun $1 nian',
+'revision-info'       => 'Revisaun loron $4, tempu $5, husi $2',
 'previousrevision'    => '←Versaun tuan liu',
 'nextrevision'        => 'Versaun foun liu→',
 'currentrevisionlink' => 'Versaun atuál',
 'cur'                 => 'atuál',
 'next'                => 'oinmai',
-'last'                => 'ikus',
+'last'                => 'molok',
 'page_first'          => 'uluk',
 'page_last'           => 'ikus',
 'histfirst'           => 'sedu liu hotu',
@@ -394,23 +404,32 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'lineno' => 'Liña $1:',
 
 # Search results
-'searchsubtitleinvalid'     => "Ita buka tiha ona '''$1'''",
-'prevn'                     => 'molok {{PLURAL:$1|$1}}',
-'nextn'                     => 'oinmai {{PLURAL:$1|$1}}',
-'viewprevnext'              => 'Haree ($1 {{int:pipe-separator}} $2) ($3)',
-'search-result-size'        => '$1 ({{PLURAL:$2|liafuan ida|liafuan $2}})',
-'search-section'            => '(seksaun $1)',
-'search-interwiki-caption'  => 'Projetu seluseluk sira',
-'search-mwsuggest-enabled'  => 'fó sujestaun',
-'search-mwsuggest-disabled' => 'la hatudu sujestaun',
-'searchall'                 => 'hotu',
-'powersearch'               => 'Buka',
-'powersearch-field'         => 'Buka',
-'powersearch-toggleall'     => 'Hotu',
+'searchresults'                  => 'Rezultadu sira',
+'searchresults-title'            => 'Rezultadu sira ba buka "$1"',
+'searchsubtitleinvalid'          => "Ita buka tiha ona '''$1'''",
+'prevn'                          => 'molok {{PLURAL:$1|$1}}',
+'nextn'                          => 'oinmai {{PLURAL:$1|$1}}',
+'shown-title'                    => 'Hatudu {{PLURAL:$1|rezultadu|rezultadu}} $1 kada pájina',
+'viewprevnext'                   => 'Haree ($1 {{int:pipe-separator}} $2) ($3)',
+'searchmenu-exists'              => "'''Iha pájina ho naran \"[[:\$1]]\".'''",
+'searchmenu-new'                 => "'''Kria pájina \"[[:\$1]]\" iha wiki ne'e!'''",
+'searchprofile-everything'       => 'Hotu',
+'searchprofile-articles-tooltip' => 'Buka iha $1',
+'searchprofile-project-tooltip'  => 'Buka iha $1',
+'search-result-size'             => '$1 ({{PLURAL:$2|liafuan ida|liafuan $2}})',
+'search-section'                 => '(seksaun $1)',
+'search-suggest'                 => 'Parese Ita buka: $1',
+'search-interwiki-caption'       => 'Projetu seluseluk sira',
+'search-mwsuggest-enabled'       => 'fó sujestaun',
+'search-mwsuggest-disabled'      => 'la hatudu sujestaun',
+'searchall'                      => 'hotu',
+'powersearch'                    => 'Buka',
+'powersearch-field'              => 'Buka',
+'powersearch-toggleall'          => 'Hotu',
 
 # Preferences page
 'preferences'               => 'Preferénsia',
-'mypreferences'             => "Ha'u-nia preferénsia",
+'mypreferences'             => 'Preferénsia',
 'prefs-rc'                  => 'Mudansa foufoun sira',
 'prefs-watchlist'           => 'Lista hateke',
 'prefs-editing'             => 'Edita',
@@ -423,7 +442,7 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'timezoneregion-europe'     => 'Europa',
 'youremail'                 => 'Korreiu eletróniku:',
 'username'                  => "Naran uza-na'in:",
-'uid'                       => "Uza-na'in ID:",
+'uid'                       => "Númeru uza-na'in:",
 'yourlanguage'              => 'Lian:',
 'gender-male'               => 'Mane',
 'gender-female'             => 'Feto',
@@ -435,6 +454,7 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'userrights-lookup-user'   => "Muda grupu uza-na'in",
 'userrights-user-editname' => "Fó naran uza-na'in ida:",
 'editusergroup'            => "Muda grupu uza-na'in",
+'editinguser'              => "Muda grupu '''[[User:$1|$1]]''' nian $2",
 'userrights-editusergroup' => "Muda grupu uza-na'in",
 'userrights-groupsmember'  => 'Membru iha:',
 'userrights-reason'        => 'Motivu:',
@@ -477,7 +497,7 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 # User rights log
 'rightslog'      => "Lista mudansa priviléjiu uza-na'in",
 'rightslogtext'  => "Ne'e lista mudansa priviléjiu uza-na'in sira nian.",
-'rightslogentry' => 'muda grupu $1 nian husi $2 ba $3',
+'rightslogentry' => 'muda grupu "$1" nian husi "$2" ba "$3"',
 'rightsnone'     => '(mamuk)',
 
 # Associated actions - in the sentence "You do not have permission to X"
@@ -493,21 +513,24 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'action-userrights-interwiki' => "edita priviléjiu uza-na'in iha wiki seluk sira",
 
 # Recent changes
-'nchanges'           => '$1 {{PLURAL:$1|diferensa|diferensa}}',
-'recentchanges'      => 'Mudansa foufoun sira',
-'rcshowhideminor'    => "$1 muda ki-ki'ik",
-'rcshowhidebots'     => '$1 bot sira',
-'rcshowhideliu'      => '$1 ema rejista',
-'rcshowhideanons'    => '$1 ema anónimu',
-'rcshowhidemine'     => "$1 ha'u-nia edita",
-'diff'               => 'diferensa',
-'hist'               => 'istória',
-'hide'               => 'Hamsumik',
-'show'               => 'Hatudu',
-'minoreditletter'    => 'k',
-'newpageletter'      => 'F',
-'boteditletter'      => 'b',
-'rc-enhanced-expand' => 'Hatudu detalle (presiza JavaScript)',
+'nchanges'                    => '$1 {{PLURAL:$1|diferensa|diferensa}}',
+'recentchanges'               => 'Mudansa foufoun sira',
+'recentchanges-label-newpage' => 'Pájina foun',
+'recentchanges-label-minor'   => "Ne'e mudansa ki'ik",
+'recentchanges-label-bot'     => 'Edita husi prosesu automátiku ("bot")',
+'rcshowhideminor'             => "$1 muda ki-ki'ik",
+'rcshowhidebots'              => '$1 bot sira',
+'rcshowhideliu'               => '$1 ema rejista',
+'rcshowhideanons'             => '$1 ema anónimu',
+'rcshowhidemine'              => "$1 ha'u-nia edita",
+'diff'                        => 'diferensa',
+'hist'                        => 'istória',
+'hide'                        => 'Hamsumik',
+'show'                        => 'Hatudu',
+'minoreditletter'             => 'k',
+'newpageletter'               => 'F',
+'boteditletter'               => 'b',
+'rc-enhanced-expand'          => 'Hatudu detalle (presiza JavaScript)',
 
 # Recent changes linked
 'recentchangeslinked'         => 'Muda sira',
@@ -532,14 +555,15 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'listfiles_user' => "Uza-na'in",
 
 # File description page
-'file-anchor-link'   => 'Fail',
-'filehist-deleteall' => 'halakon hotu',
-'filehist-deleteone' => 'halakon',
-'filehist-current'   => 'atuál',
-'filehist-datetime'  => 'Loron/Tempu',
-'filehist-user'      => "Uza-na'in",
-'filehist-comment'   => 'Komentáriu',
-'imagelinks'         => "Pájina iha ne'ebá fixeiru ne'e",
+'file-anchor-link'          => 'Fail',
+'filehist-deleteall'        => 'halakon hotu',
+'filehist-deleteone'        => 'halakon',
+'filehist-current'          => 'atuál',
+'filehist-datetime'         => 'Loron/Tempu',
+'filehist-user'             => "Uza-na'in",
+'filehist-comment'          => 'Komentáriu',
+'imagelinks'                => "Pájina iha ne'ebá fixeiru ne'e",
+'uploadnewversion-linktext' => 'Tau versaun foun imajen nian',
 
 # File reversion
 'filerevert-comment' => 'Razaun:',
@@ -625,7 +649,7 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'listgrouprights-rights'  => 'Priviléjiu',
 'listgrouprights-members' => '(lista membru nian)',
 
-# E-mail user
+# Email user
 'emailuser'       => "Haruka korreiu eletróniku ba uza-na'in ne'e",
 'defemailsubject' => '{{SITENAME}} - korreiu eletróniku husi uza-na\'in "$1"',
 'noemailtitle'    => "Lá'os diresaun korreiu eletróniku",
@@ -633,8 +657,8 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'emailsend'       => 'Haruka',
 
 # Watchlist
-'watchlist'         => "Ha'u-nia lista hateke",
-'mywatchlist'       => "Ha'u-nia lista hateke",
+'watchlist'         => 'Lista hateke',
+'mywatchlist'       => 'Lista hateke',
 'removedwatchtext'  => 'La hateke pájina "[[:$1]]" ona (haree [[Special:Watchlist|"lista hateke"]]).',
 'watch'             => 'Hateke',
 'watchthispage'     => "Hateke pájina ne'e",
@@ -659,6 +683,7 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'exblank'                => 'pájina mamuk',
 'delete-legend'          => 'Halakon',
 'actioncomplete'         => 'operasaun remata',
+'actionfailed'           => 'Asaun la konsege',
 'deletedtext'            => 'Ita foin halakon pájina "$1". Haree $2 ba "operasaun halakon" seluk.',
 'dellogpage'             => 'Lista halakon',
 'deletionlog'            => 'lista halakon',
@@ -707,7 +732,7 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 # Contributions
 'contributions'       => "Kontribuisaun uza-na'in",
 'contributions-title' => 'Kontribuisaun "$1" nian',
-'mycontris'           => "Ha'u-nia kontribuisaun",
+'mycontris'           => 'Kontribuisaun',
 'contribsub2'         => 'Ba $1 ($2)',
 'uctop'               => '(versaun atuál)',
 'month'               => 'Fulan (ho molok):',
@@ -731,24 +756,33 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'whatlinkshere-hidelinks' => '$1 ligasaun',
 
 # Block/unblock
-'blockip'                  => "Blokeiu uza-na'in",
-'blockip-legend'           => "Blokeiu uza-na'in",
-'ipbreason'                => 'Motivu:',
-'ipbreasonotherlist'       => 'Motivu seluk',
-'ipbsubmit'                => "Blokeiu uza-na'in ne'e",
-'ipbother'                 => 'Tempu seluk:',
-'ipboptions'               => '2 hours:2 hours,1 loron:1 day,3 Loron:3 days,1 semana:1 week,2 semana:2 weeks,1 fulan:1 month,3 fulan:3 months,6 fulan:6 months,1 tinan:1 year,infinite:infinite',
-'ipbotheroption'           => 'seluk',
-'ipblocklist'              => "Uza-na'in sira-ne'ebé la bele edita",
-'blocklist-reason'         => 'Razaun',
-'ipblocklist-submit'       => 'Buka',
-'anononlyblock'            => "ema anónimu de'it",
-'blocklink'                => 'blokeiu',
-'unblocklink'              => 'la blokeiu',
-'contribslink'             => 'kontribuisaun',
-'block-log-flags-nocreate' => 'la bele kria konta foun',
-'block-log-flags-noemail'  => 'korreiu eletróniku blokeiu',
-'ipb_already_blocked'      => 'Ema ruma blokeiu "$1" tiha ona',
+'block'                      => "Blokeiu uza-na'in",
+'blockip'                    => "Blokeiu uza-na'in",
+'blockip-legend'             => "Blokeiu uza-na'in",
+'ipadressorusername'         => "Diresaun IP ka naran uza-na'in:",
+'ipbexpiry'                  => 'Tempu:',
+'ipbreason'                  => 'Motivu:',
+'ipbreasonotherlist'         => 'Motivu seluk',
+'ipbcreateaccount'           => 'La bele kria konta foun',
+'ipbemailban'                => 'La bele haruka korreiu eletróniku',
+'ipbsubmit'                  => "Blokeiu uza-na'in ne'e",
+'ipbother'                   => 'Tempu seluk:',
+'ipboptions'                 => '2 hours:2 hours,1 loron:1 day,3 Loron:3 days,1 semana:1 week,2 semana:2 weeks,1 fulan:1 month,3 fulan:3 months,6 fulan:6 months,1 tinan:1 year,infinite:infinite',
+'ipbotheroption'             => 'seluk',
+'ipbhidename'                => "Subar naran uza-na'in (iha kontribuisaun no lista seluk)",
+'ipbwatchuser'               => "Hateke pájina uza-na'in nian (hamutuk ho pájina diskusaun)",
+'ipb-disableusertalk'        => 'La bele edita ninia pájina diskusaun',
+'ipblocklist'                => "Uza-na'in sira-ne'ebé la bele edita",
+'blocklist-reason'           => 'Razaun',
+'ipblocklist-submit'         => 'Buka',
+'anononlyblock'              => "ema anónimu de'it",
+'blocklink'                  => 'blokeiu',
+'unblocklink'                => 'la blokeiu',
+'contribslink'               => 'kontribuisaun',
+'block-log-flags-nocreate'   => 'la bele kria konta foun',
+'block-log-flags-noemail'    => 'korreiu eletróniku blokeiu',
+'block-log-flags-nousertalk' => 'la bele edita pájina diskusaun rasik',
+'ipb_already_blocked'        => 'Ema ruma blokeiu "$1" tiha ona',
 
 # Move page
 'move-page'               => 'Book $1',
@@ -804,6 +838,7 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'tooltip-ca-unwatch'             => 'Hasai pájina ne\'e husi Ita-nia "lista hateke"',
 'tooltip-search'                 => 'Buka iha {{SITENAME}}',
 'tooltip-search-go'              => "Bá pájina ho naran ne'e (se iha)",
+'tooltip-search-fulltext'        => "Buka pájina sira-ne'ebé iha testu ne'e iha laran",
 'tooltip-p-logo'                 => 'Pájina Mahuluk',
 'tooltip-n-mainpage'             => 'Vizita Pájina Mahuluk',
 'tooltip-n-mainpage-description' => 'Vizita Pájina Mahuluk',
@@ -847,6 +882,13 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'showhidebots' => '($1 bot sira)',
 'ilsubmit'     => 'Buka',
 
+# Bad image list
+'bad_image_list' => "Formatu:
+
+Liña hotu tenke komesa ho *
+Ligasaun uluk iha liña tenke ligasaun bá imajen aat.
+Ligasaun seluk iha liña - ne'e pájina sira iha ne'ebé bele inklui imajen aat.",
+
 # EXIF tags
 'exif-make'         => 'Fabrikante kámara nian',
 'exif-model'        => 'Kámara',
@@ -924,6 +966,7 @@ Check your spelling, ka [[Special:UserLogin/signup|kria konta foun]].',
 'version-other'            => 'Seluk',
 'version-version'          => '(Versaun $1)',
 'version-license'          => 'Lisensa',
+'version-poweredby-others' => 'ema seluk',
 'version-software-product' => 'Produtu',
 'version-software-version' => 'Versaun',
 
