@@ -3,12 +3,15 @@
  */
 
 mediaWiki.language.convertPlural = function( count, forms ) {
-	forms = mediaWiki.language.preConvertPlural( forms, 4 );
+	if ( !forms || forms.length === 0 ) {
+			return '';
+	}
+	forms = mediaWiki.language.preConvertPlural( forms, 3 );
 	if ( count == 1 ) {
-		return forms[1];
+		return forms[0];
 	}
 	if ( count == 2 ) {
-		return forms[2];
+		return forms[1];
 	}
-	return forms[3];
+	return forms[2];
 };
